@@ -1,19 +1,25 @@
-import { css } from '@emotion/css';
+import { css, cx } from '@emotion/css';
+import { HTMLAttributes } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { Icon, useStyles2 } from '@grafana/ui';
 
-export function OrangeBadge({ text }: { text: string }) {
-  const styles = useStyles2(getStyles);
+interface Props extends HTMLAttributes<HTMLDivElement> {
+  text?: string;
+  className?: string;
+}
+
+export function OrangeBadge({ text, className, ...htmlProps }: Props) {
+  const styles = useStyles2(getStyles, text);
   return (
-    <div className={styles.wrapper}>
+    <div className={cx(styles.wrapper, className)} {...htmlProps}>
       <Icon name="cloud" size="sm" />
       {text}
     </div>
   );
 }
 
-const getStyles = (theme: GrafanaTheme2) => {
+const getStyles = (theme: GrafanaTheme2, text: string | undefined) => {
   return {
     wrapper: css({
       display: 'inline-flex',
@@ -26,6 +32,11 @@ const getStyles = (theme: GrafanaTheme2) => {
       fontSize: theme.typography.bodySmall.fontSize,
       lineHeight: theme.typography.bodySmall.lineHeight,
       alignItems: 'center',
+      ...(text === undefined && {
+        svg: {
+          marginRight: 0,
+        },
+      }),
     }),
   };
 };
