@@ -1,22 +1,12 @@
+import { Team } from 'app/types/teams';
+
 import { reducerTester } from '../../../test/core/redux/reducerTester';
 import { initialTeamsState, teamsLoaded } from '../../features/teams/state/reducers';
-import { Team } from '../../types';
 import { StoreState } from '../../types/store';
 import { cleanUpAction } from '../actions/cleanUp';
 
 import { createRootReducer } from './root';
 
-jest.mock('@grafana/runtime', () => ({
-  ...jest.requireActual('@grafana/runtime'),
-  config: {
-    ...jest.requireActual('@grafana/runtime').config,
-    bootData: {
-      navTree: [],
-      user: {},
-    },
-  },
-}));
-
 describe('rootReducer', () => {
   const rootReducer = createRootReducer();
 
