@@ -3,11 +3,13 @@ import { useForm } from 'react-hook-form';
 import { useParams } from 'react-router-dom-v5-compat';
 import { useAsyncFn } from 'react-use';
 
-import { NavModelItem } from '@grafana/data';
+import { NavModelItem, OrgRole } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { Field, Input, Button, Legend, Alert } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import { contextSrv } from 'app/core/core';
-import { OrgUser, AccessControlAction, OrgRole } from 'app/types';
+import { AccessControlAction } from 'app/types/accessControl';
+import { OrgUser } from 'app/types/user';
 
 import { OrgUsersTable } from './Users/OrgUsersTable';
 import { getOrg, getOrgUsers, getUsersRoles, removeOrgUser, updateOrgName, updateOrgUserRole } from './api';
@@ -55,9 +57,14 @@ const AdminEditOrgPage = () => {
   };
 
   const renderMissingPermissionMessage = () => (
-    <Alert severity="info" title="Access denied">
-      You do not have permission to see users in this organization. To update this organization, contact your server
-      administrator.
+    <Alert
+      severity="info"
+      title={t('admin.admin-edit-org-page.render-missing-permission-message.title-access-denied', 'Access denied')}
+    >
+      <Trans i18nKey="admin.edit-org.access-denied">
+        You do not have permission to see users in this organization. To update this organization, contact your server
+        administrator.
+      </Trans>
     </Alert>
   );
 
@@ -78,17 +85,27 @@ const AdminEditOrgPage = () => {
   const pageNav: NavModelItem = {
     text: orgState?.value?.name ?? '',
     icon: 'shield',
-    subTitle: 'Manage settings and user roles for an organization.',
+    subTitle: t(
+      'admin.admin-edit-org-page.page-nav.subTitle.manage-settings-roles-organization',
+      'Manage settings and user roles for an organization.'
+    ),
   };
 
   return (
     <Page navId="global-orgs" pageNav={pageNav} subTitle="Manage settings for this specific org.">
       <Page.Contents>
         <>
-          <Legend>Edit organization</Legend>
+          <Legend>
+            <Trans i18nKey="admin.edit-org.heading">Edit Organization</Trans>
+          </Legend>
           {orgState.value && (
             <form onSubmit={handleSubmit(onUpdateOrgName)} style={{ maxWidth: '600px' }}>
-              <Field label="Name" invalid={!!errors.orgName} error="Name is required" disabled={!canWriteOrg}>
+              <Field
+                label={t('admin.admin-edit-org-page.label-name', 'Name')}
+                invalid={!!errors.orgName}
+                error="Name is required"
+                disabled={!canWriteOrg}
+              >
                 <Input
                   {...register('orgName', { required: true })}
                   id="org-name-input"
@@ -96,13 +113,15 @@ const AdminEditOrgPage = () => {
                 />
               </Field>
               <Button type="submit" disabled={!canWriteOrg}>
-                Update
+                <Trans i18nKey="admin.edit-org.update-button">Update</Trans>
               </Button>
             </form>
           )}
 
           <div style={{ marginTop: '20px' }}>
-            <Legend>Organization users</Legend>
+            <Legend>
+              <Trans i18nKey="admin.edit-org.users-heading">Organization users</Trans>
+            </Legend>
             {!canReadUsers && renderMissingPermissionMessage()}
             {canReadUsers && !!users.length && (
               <OrgUsersTable
