@@ -1,5 +1,5 @@
 import { css, cx } from '@emotion/css';
-import { createRef, PureComponent, ReactElement } from 'react';
+import { memo, PureComponent, ReactElement, useEffect, useRef, useState } from 'react';
 
 import { GrafanaTheme2, OrgRole } from '@grafana/data';
 import { Trans, t } from '@grafana/i18n';
@@ -10,11 +10,10 @@ import {
   Icon,
   Modal,
   stylesFactory,
-  Themeable2,
   Tooltip,
   useStyles2,
-  withTheme2,
   Stack,
+  TextLink,
 } from '@grafana/ui';
 import { UserRolePicker } from 'app/core/components/RolePicker/UserRolePicker';
 import { fetchRoleOptions, updateUserRoles } from 'app/core/components/RolePicker/api';
@@ -36,73 +35,63 @@ interface Props {
   onOrgAdd: (orgId: number, role: OrgRole) => void;
 }
 
-interface State {
-  showAddOrgModal: boolean;
-}
+export const UserOrgs = memo(({ user, orgs, isExternalUser, onOrgRoleChange, onOrgRemove, onOrgAdd }: Props) => {
+  const [showAddOrgModal, setShowAddOrgModal] = useState(false);
+  const addToOrgButtonRef = useRef<HTMLButtonElement>(null);
 
-export class UserOrgs extends PureComponent<Props, State> {
-  addToOrgButtonRef = createRef<HTMLButtonElement>();
-  state = {
-    showAddOrgModal: false,
+  const showOrgAddModal = () => {
+    setShowAddOrgModal(true);
   };
 
-  showOrgAddModal = () => {
-    this.setState({ showAddOrgModal: true });
+  const dismissOrgAddModal = () => {
+    setShowAddOrgModal(false);
+    addToOrgButtonRef.current?.focus();
   };
 
-  dismissOrgAddModal = () => {
-    this.setState({ showAddOrgModal: false }, () => {
-      this.addToOrgButtonRef.current?.focus();
-    });
-  };
+  const canAddToOrg = contextSrv.hasPermission(AccessControlAction.OrgUsersAdd) && !isExternalUser;
 
-  render() {
-    const { user, orgs, isExternalUser, onOrgRoleChange, onOrgRemove, onOrgAdd } = this.props;
-    const { showAddOrgModal } = this.state;
+  return (
+    <div>
+      <h3 className="page-heading">
+        <Trans i18nKey="admin.user-orgs.title">Organizations</Trans>
+      </h3>
+      <Stack gap={1.5} direction="column">
+        <table className="filter-table form-inline">
+          <tbody>
+            {orgs.map((org, index) => (
+              <OrgRow
+                key={`${org.orgId}-${index}`}
+                isExternalUser={isExternalUser}
+                user={user}
+                org={org}
+                onOrgRoleChange={onOrgRoleChange}
+                onOrgRemove={onOrgRemove}
+              />
+            ))}
+          </tbody>
+        </table>
 
-    const canAddToOrg = contextSrv.hasPermission(AccessControlAction.OrgUsersAdd) && !isExternalUser;
-    return (
-      <div>
-        <h3 className="page-heading">
-          <Trans i18nKey="admin.user-orgs.title">Organizations</Trans>
-        </h3>
-        <Stack gap={1.5} direction="column">
-          <table className="filter-table form-inline">
-            <tbody>
-              {orgs.map((org, index) => (
-                <OrgRow
-                  key={`${org.orgId}-${index}`}
-                  isExternalUser={isExternalUser}
-                  user={user}
-                  org={org}
-                  onOrgRoleChange={onOrgRoleChange}
-                  onOrgRemove={onOrgRemove}
-                />
-              ))}
-            </tbody>
-          </table>
+        <div>
+          {canAddToOrg && (
+            <Button variant="secondary" onClick={showOrgAddModal} ref={addToOrgButtonRef}>
+              <Trans i18nKey="admin.user-orgs.add-button">Add user to organization</Trans>
+            </Button>
+          )}
+        </div>
+        <AddToOrgModal
+          user={user}
+          userOrgs={orgs}
+          isOpen={showAddOrgModal}
+          onOrgAdd={onOrgAdd}
+          onDismiss={dismissOrgAddModal}
+        />
+      </Stack>
+    </div>
+  );
+});
+UserOrgs.displayName = 'UserOrgs';
 
-          <div>
-            {canAddToOrg && (
-              <Button variant="secondary" onClick={this.showOrgAddModal} ref={this.addToOrgButtonRef}>
-                <Trans i18nKey="admin.user-orgs.add-button">Add user to organization</Trans>
-              </Button>
-            )}
-          </div>
-          <AddToOrgModal
-            user={user}
-            userOrgs={orgs}
-            isOpen={showAddOrgModal}
-            onOrgAdd={onOrgAdd}
-            onDismiss={this.dismissOrgAddModal}
-          />
-        </Stack>
-      </div>
-    );
-  }
-}
-
-const getOrgRowStyles = stylesFactory((theme: GrafanaTheme2) => {
+const getOrgRowStyles = (theme: GrafanaTheme2) => {
   return {
     removeButton: css({
       marginRight: '0.6rem',
@@ -129,9 +118,9 @@ const getOrgRowStyles = stylesFactory((theme: GrafanaTheme2) => {
       marginRight: theme.spacing(1),
     }),
   };
-});
+};
 
-interface OrgRowProps extends Themeable2 {
+interface OrgRowProps {
   user?: UserDTO;
   org: UserOrg;
   isExternalUser?: boolean;
@@ -139,124 +128,116 @@ interface OrgRowProps extends Themeable2 {
   onOrgRoleChange: (orgId: number, newRole: OrgRole) => void;
 }
 
-class UnThemedOrgRow extends PureComponent<OrgRowProps> {
-  state = {
-    currentRole: this.props.org.role,
-    isChangingRole: false,
-    roleOptions: [],
-  };
+const OrgRow = memo(({ user, org, isExternalUser, onOrgRemove, onOrgRoleChange }: OrgRowProps) => {
+  const [currentRole, setCurrentRole] = useState(org.role);
+  const [isChangingRole, setIsChangingRole] = useState(false);
+  const [roleOptions, setRoleOptions] = useState<Role[]>([]);
+  const styles = useStyles2(getOrgRowStyles);
 
-  componentDidMount() {
+  useEffect(() => {
     if (contextSrv.licensedAccessControlEnabled()) {
       if (contextSrv.hasPermission(AccessControlAction.ActionRolesList)) {
-        fetchRoleOptions(this.props.org.orgId)
-          .then((roles) => this.setState({ roleOptions: roles }))
+        fetchRoleOptions(org.orgId)
+          .then((roles) => setRoleOptions(roles))
           .catch((e) => console.error(e));
       }
     }
-  }
+  }, [org.orgId]);
 
-  onOrgRemove = async () => {
-    const { org } = this.props;
-    this.props.onOrgRemove(org.orgId);
+  const handleOrgRemove = async () => {
+    onOrgRemove(org.orgId);
   };
 
-  onChangeRoleClick = () => {
-    const { org } = this.props;
-    this.setState({ isChangingRole: true, currentRole: org.role });
+  const handleChangeRoleClick = () => {
+    setIsChangingRole(true);
+    setCurrentRole(org.role);
   };
 
-  onOrgRoleChange = (newRole: OrgRole) => {
-    this.setState({ currentRole: newRole });
+  const handleOrgRoleChange = (newRole: OrgRole) => {
+    setCurrentRole(newRole);
   };
 
-  onOrgRoleSave = () => {
-    this.props.onOrgRoleChange(this.props.org.orgId, this.state.currentRole);
+  const handleOrgRoleSave = () => {
+    onOrgRoleChange(org.orgId, currentRole);
   };
 
-  onCancelClick = () => {
-    this.setState({ isChangingRole: false });
+  const handleCancelClick = () => {
+    setIsChangingRole(false);
   };
 
-  onBasicRoleChange = (newRole: OrgRole) => {
-    this.props.onOrgRoleChange(this.props.org.orgId, newRole);
+  const handleBasicRoleChange = (newRole: OrgRole) => {
+    onOrgRoleChange(org.orgId, newRole);
   };
 
-  render() {
-    const { user, org, isExternalUser, theme } = this.props;
-    const authSource = user?.authLabels?.length && user?.authLabels[0];
-    const lockMessage = authSource ? `Synced via ${authSource}` : '';
-    const { currentRole, isChangingRole } = this.state;
-    const styles = getOrgRowStyles(theme);
-    const labelClass = cx('width-16', styles.label);
-    const canChangeRole = contextSrv.hasPermission(AccessControlAction.OrgUsersWrite);
-    const canRemoveFromOrg = contextSrv.hasPermission(AccessControlAction.OrgUsersRemove) && !isExternalUser;
-    const rolePickerDisabled = isExternalUser || !canChangeRole;
+  const authSource = user?.authLabels?.length && user?.authLabels[0];
+  const lockMessage = authSource ? `Synced via ${authSource}` : '';
+  const labelClass = cx('width-16', styles.label);
+  const canChangeRole = contextSrv.hasPermission(AccessControlAction.OrgUsersWrite);
+  const canRemoveFromOrg = contextSrv.hasPermission(AccessControlAction.OrgUsersRemove) && !isExternalUser;
+  const rolePickerDisabled = isExternalUser || !canChangeRole;
 
-    const inputId = `${org.name}-input`;
-    return (
-      <tr>
-        <td className={labelClass}>
-          <label htmlFor={inputId}>{org.name}</label>
-        </td>
-        {contextSrv.licensedAccessControlEnabled() ? (
-          <td>
-            <div className={styles.rolePickerWrapper}>
-              <div className={styles.rolePicker}>
-                <UserRolePicker
-                  userId={user?.id || 0}
-                  orgId={org.orgId}
-                  basicRole={org.role}
-                  roleOptions={this.state.roleOptions}
-                  onBasicRoleChange={this.onBasicRoleChange}
-                  basicRoleDisabled={rolePickerDisabled}
-                  basicRoleDisabledMessage="This user's role is not editable because it is synchronized from your auth provider.
-                    Refer to the Grafana authentication docs for details."
-                />
-              </div>
-              {isExternalUser && <ExternalUserTooltip lockMessage={lockMessage} />}
+  const inputId = `${org.name}-input`;
+  return (
+    <tr>
+      <td className={labelClass}>
+        <label htmlFor={inputId}>{org.name}</label>
+      </td>
+      {contextSrv.licensedAccessControlEnabled() ? (
+        <td>
+          <div className={styles.rolePickerWrapper}>
+            <div className={styles.rolePicker}>
+              <UserRolePicker
+                userId={user?.id || 0}
+                orgId={org.orgId}
+                basicRole={org.role}
+                roleOptions={roleOptions}
+                onBasicRoleChange={handleBasicRoleChange}
+                basicRoleDisabled={rolePickerDisabled}
+                basicRoleDisabledMessage="This user's role is not editable because it is synchronized from your auth provider.
+                  Refer to the Grafana authentication docs for details."
+              />
             </div>
-          </td>
-        ) : (
-          <>
-            {isChangingRole ? (
-              <td>
-                <OrgRolePicker inputId={inputId} value={currentRole} onChange={this.onOrgRoleChange} autoFocus />
-              </td>
-            ) : (
-              <td className="width-25">{org.role}</td>
-            )}
-            <td colSpan={1}>
-              {canChangeRole && (
-                <ChangeOrgButton
-                  lockMessage={lockMessage}
-                  isExternalUser={isExternalUser}
-                  onChangeRoleClick={this.onChangeRoleClick}
-                  onCancelClick={this.onCancelClick}
-                  onOrgRoleSave={this.onOrgRoleSave}
-                />
-              )}
-            </td>
-          </>
-        )}
-        <td colSpan={1}>
-          {canRemoveFromOrg && (
-            <ConfirmButton
-              confirmText={t('admin.un-themed-org-row.confirmText-confirm-removal', 'Confirm removal')}
-              confirmVariant="destructive"
-              onCancel={this.onCancelClick}
-              onConfirm={this.onOrgRemove}
-            >
-              {t('admin.user-orgs.remove-button', 'Remove from organization')}
-            </ConfirmButton>
-          )}
+            {isExternalUser && <ExternalUserTooltip lockMessage={lockMessage} />}
+          </div>
         </td>
-      </tr>
-    );
-  }
-}
-
-const OrgRow = withTheme2(UnThemedOrgRow);
+      ) : (
+        <>
+          {isChangingRole ? (
+            <td>
+              <OrgRolePicker inputId={inputId} value={currentRole} onChange={handleOrgRoleChange} autoFocus />
+            </td>
+          ) : (
+            <td className="width-25">{org.role}</td>
+          )}
+          <td colSpan={1}>
+            {canChangeRole && (
+              <ChangeOrgButton
+                lockMessage={lockMessage}
+                isExternalUser={isExternalUser}
+                onChangeRoleClick={handleChangeRoleClick}
+                onCancelClick={handleCancelClick}
+                onOrgRoleSave={handleOrgRoleSave}
+              />
+            )}
+          </td>
+        </>
+      )}
+      <td colSpan={1}>
+        {canRemoveFromOrg && (
+          <ConfirmButton
+            confirmText={t('admin.un-themed-org-row.confirmText-confirm-removal', 'Confirm removal')}
+            confirmVariant="destructive"
+            onCancel={handleCancelClick}
+            onConfirm={handleOrgRemove}
+          >
+            {t('admin.user-orgs.remove-button', 'Remove from organization')}
+          </ConfirmButton>
+        )}
+      </td>
+    </tr>
+  );
+});
+OrgRow.displayName = 'OrgRow';
 
 const getAddToOrgModalStyles = stylesFactory(() => ({
   modal: css({
@@ -446,14 +427,9 @@ export function ChangeOrgButton({
                 <Trans i18nKey="admin.user-orgs.role-not-editable">
                   This user&apos;s role is not editable because it is synchronized from your auth provider. Refer to
                   the&nbsp;
-                  <a
-                    className={styles.tooltipItemLink}
-                    href={'https://grafana.com/docs/grafana/latest/auth'}
-                    rel="noreferrer"
-                    target="_blank"
-                  >
+                  <TextLink href={'https://grafana.com/docs/grafana/latest/auth'} external>
                     Grafana authentication docs
-                  </a>
+                  </TextLink>
                   &nbsp;for details.
                 </Trans>
               </div>
@@ -496,14 +472,9 @@ export const ExternalUserTooltip = ({ lockMessage }: ExternalUserTooltipProps) =
             <Trans i18nKey="admin.user-orgs.external-user-tooltip">
               This user&apos;s built-in role is not editable because it is synchronized from your auth provider. Refer
               to the&nbsp;
-              <a
-                className={styles.tooltipItemLink}
-                href={'https://grafana.com/docs/grafana/latest/auth'}
-                rel="noreferrer noopener"
-                target="_blank"
-              >
+              <TextLink href={'https://grafana.com/docs/grafana/latest/auth'} external>
                 Grafana authentication docs
-              </a>
+              </TextLink>
               &nbsp;for details.
             </Trans>
           </div>
@@ -519,9 +490,6 @@ const getTooltipStyles = (theme: GrafanaTheme2) => ({
   disabledTooltip: css({
     display: 'flex',
   }),
-  tooltipItemLink: css({
-    color: theme.v1.palette.blue95,
-  }),
   lockMessageClass: css({
     fontStyle: 'italic',
     marginLeft: '1.8rem',
