@@ -1,4 +1,5 @@
 import { NavModel } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { Page } from 'app/core/components/Page/Page';
 
 import { withPageErrorBoundary } from './withPageErrorBoundary';
@@ -6,12 +7,15 @@ import { withPageErrorBoundary } from './withPageErrorBoundary';
 function FeatureTogglePage() {
   const navModel: NavModel = {
     node: {
-      text: 'Alerting is not enabled',
+      text: t('alerting.feature-toggle-page.nav-model.text.alerting-is-not-enabled', 'Alerting is not enabled'),
       hideFromBreadcrumbs: true,
-      subTitle: 'To enable alerting, enable it in the Grafana config',
+      subTitle: t(
+        'alerting.feature-toggle-page.nav-model.subTitle.enable-alerting-grafana-config',
+        'To enable alerting, enable it in the Grafana config'
+      ),
     },
     main: {
-      text: 'Alerting is not enabled',
+      text: t('alerting.feature-toggle-page.nav-model.text.alerting-is-not-enabled', 'Alerting is not enabled'),
     },
   };
 
