@@ -1,15 +1,13 @@
+import irmLogoSvg from 'img/alerting/irm_logo.svg';
+import oncallLogoSvg from 'img/alerting/oncall_logo.svg';
+
 import { SupportedPlugin } from '../../../types/pluginBridges';
 
-export interface AmRouteReceiver {
-  label: string;
-  value: string;
-  grafanaAppReceiverType?: SupportedPlugin;
-}
-
 export const GRAFANA_APP_RECEIVERS_SOURCE_IMAGE: Record<SupportedPlugin, string> = {
-  [SupportedPlugin.OnCall]: 'public/img/alerting/oncall_logo.svg',
-
+  [SupportedPlugin.OnCall]: oncallLogoSvg,
+  [SupportedPlugin.Irm]: irmLogoSvg,
   [SupportedPlugin.Incident]: '',
   [SupportedPlugin.MachineLearning]: '',
   [SupportedPlugin.Labels]: '',
+  [SupportedPlugin.Slo]: '',
 };
