@@ -1,4 +1,4 @@
-import { RawQuery } from '@grafana/experimental';
+import { RawQuery } from '@grafana/plugin-ui';
 import lokiGrammar from 'app/plugins/datasource/loki/syntax';
 
 interface Props {
