@@ -1,32 +1,28 @@
 import { css } from '@emotion/css';
-import pluralize from 'pluralize';
 import React, { useEffect, useState } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { selectors } from '@grafana/e2e-selectors';
-import { Badge, ConfirmModal, Icon, Spinner, Stack, Tooltip, useStyles2 } from '@grafana/ui';
-import { useDispatch } from 'app/types';
-import { CombinedRuleGroup, CombinedRuleNamespace } from 'app/types/unified-alerting';
+import { Trans, t } from '@grafana/i18n';
+import { Badge, Icon, Spinner, Stack, Tooltip, useStyles2 } from '@grafana/ui';
+import { CombinedRuleGroup, CombinedRuleNamespace, RulesSource } from 'app/types/unified-alerting';
 
-import { LogMessages, logInfo } from '../../Analytics';
 import { useFolder } from '../../hooks/useFolder';
 import { useHasRuler } from '../../hooks/useHasRuler';
-import { deleteRulesGroupAction } from '../../state/actions';
 import { useRulesAccess } from '../../utils/accessControlHooks';
-import { GRAFANA_RULES_SOURCE_NAME, isCloudRulesSource } from '../../utils/datasource';
-import { makeFolderLink, makeFolderSettingsLink } from '../../utils/misc';
-import { isFederatedRuleGroup, isGrafanaRulerRule } from '../../utils/rules';
+import { GRAFANA_RULES_SOURCE_NAME, getRulesSourceName, isCloudRulesSource } from '../../utils/datasource';
+import { makeFolderLink } from '../../utils/misc';
+import { groups } from '../../utils/navigation';
+import { isFederatedRuleGroup, isPluginProvidedRule, rulerRuleType } from '../../utils/rules';
 import { CollapseToggle } from '../CollapseToggle';
 import { RuleLocation } from '../RuleLocation';
 import { GrafanaRuleFolderExporter } from '../export/GrafanaRuleFolderExporter';
-import { GrafanaRuleGroupExporter } from '../export/GrafanaRuleGroupExporter';
 import { decodeGrafanaNamespace } from '../expressions/util';
+import { FolderActionsButton } from '../folder-actions/FolderActionsButton';
 
 import { ActionIcon } from './ActionIcon';
-import { EditCloudGroupModal } from './EditRuleGroupModal';
-import { ReorderCloudGroupModal } from './ReorderRuleGroupModal';
 import { RuleGroupStats } from './RuleStats';
-import { RulesTable } from './RulesTable';
+import { RulesTable, useIsRulesLoading } from './RulesTable';
 
 type ViewMode = 'grouped' | 'list';
 
@@ -39,45 +35,43 @@ interface Props {
 
 export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }: Props) => {
   const { rulesSource } = namespace;
-  const dispatch = useDispatch();
+  const rulesSourceName = getRulesSourceName(rulesSource);
+  const rulerRulesLoaded = useIsRulesLoading(rulesSource);
+
   const styles = useStyles2(getStyles);
 
-  const [isEditingGroup, setIsEditingGroup] = useState(false);
-  const [isDeletingGroup, setIsDeletingGroup] = useState(false);
-  const [isReorderingGroup, setIsReorderingGroup] = useState(false);
-  const [isExporting, setIsExporting] = useState<'group' | 'folder' | undefined>(undefined);
+  const [isExporting, setIsExporting] = useState<'folder' | undefined>(undefined);
   const [isCollapsed, setIsCollapsed] = useState(!expandAll);
 
-  const { canEditRules } = useRulesAccess();
-
   useEffect(() => {
     setIsCollapsed(!expandAll);
   }, [expandAll]);
 
-  const { hasRuler, rulerRulesLoaded } = useHasRuler();
+  const { hasRuler } = useHasRuler(namespace.rulesSource);
+
   const rulerRule = group.rules[0]?.rulerRule;
-  const folderUID = (rulerRule && isGrafanaRulerRule(rulerRule) && rulerRule.grafana_alert.namespace_uid) || undefined;
+  const folderUID =
+    (rulerRule && rulerRuleType.grafana.rule(rulerRule) && rulerRule.grafana_alert.namespace_uid) || undefined;
   const { folder } = useFolder(folderUID);
 
+  const { canEditRules } = useRulesAccess();
+
   // group "is deleting" if rules source has ruler, but this group has no rules that are in ruler
-  const isDeleting =
-    hasRuler(rulesSource) && rulerRulesLoaded(rulesSource) && !group.rules.find((rule) => !!rule.rulerRule);
+  const isDeleting = hasRuler && rulerRulesLoaded && !group.rules.find((rule) => !!rule.rulerRule);
   const isFederated = isFederatedRuleGroup(group);
 
   // check if group has provisioned items
   const isProvisioned = group.rules.some((rule) => {
-    return isGrafanaRulerRule(rule.rulerRule) && rule.rulerRule.grafana_alert.provenance;
+    return rulerRuleType.grafana.rule(rule.rulerRule) && rule.rulerRule.grafana_alert.provenance;
   });
+  const isPluginProvided = group.rules.some((rule) => isPluginProvidedRule(rule.rulerRule ?? rule.promRule));
+
+  const canEditGroup = hasRuler && !isProvisioned && !isFederated && !isPluginProvided && canEditRules(rulesSourceName);
 
   // check what view mode we are in
   const isListView = viewMode === 'list';
   const isGroupView = viewMode === 'grouped';
 
-  const deleteGroup = () => {
-    dispatch(deleteRulesGroupAction(namespace, group));
-    setIsDeletingGroup(false);
-  };
-
   const actionIcons: React.ReactNode[] = [];
 
   // for grafana, link to folder views
@@ -85,42 +79,42 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
     actionIcons.push(
       <Stack key="is-deleting">
         <Spinner />
-        deleting
+        <Trans i18nKey="alerting.rules-group.deleting">Deleting</Trans>
       </Stack>
     );
   } else if (rulesSource === GRAFANA_RULES_SOURCE_NAME) {
     if (folderUID) {
       const baseUrl = makeFolderLink(folderUID);
-      if (folder?.canSave) {
-        if (isGroupView && !isProvisioned) {
+      if (isGroupView) {
+        actionIcons.push(
+          <ActionIcon
+            aria-label={t('alerting.rule-group-action.details', 'rule group details')}
+            key="rule-group-details"
+            icon="info-circle"
+            tooltip={t('alerting.rule-group-action.details', 'rule group details')}
+            to={groups.detailsPageLink('grafana', folderUID, group.name, { includeReturnTo: true })}
+          />
+        );
+        if (folder?.canSave && canEditGroup) {
           actionIcons.push(
             <ActionIcon
-              aria-label="edit rule group"
-              data-testid="edit-group"
-              key="edit"
+              aria-label={t('alerting.rule-group-action.edit', 'edit rule group')}
+              key="rule-group-edit"
               icon="pen"
-              tooltip="edit rule group"
-              onClick={() => setIsEditingGroup(true)}
-            />
-          );
-          actionIcons.push(
-            <ActionIcon
-              data-testid="reorder-group"
-              key="reorder"
-              icon="exchange-alt"
-              tooltip="reorder rules"
-              className={styles.rotate90}
-              onClick={() => setIsReorderingGroup(true)}
+              tooltip={t('alerting.rule-group-action.edit', 'edit rule group')}
+              to={groups.editPageLink('grafana', folderUID, group.name, { includeReturnTo: true })}
             />
           );
         }
+      }
+      if (folder?.canSave) {
         if (isListView) {
           actionIcons.push(
             <ActionIcon
-              aria-label="go to folder"
+              aria-label={t('alerting.rule-group-action.go-to-folder', 'go to folder')}
               key="goto"
               icon="folder-open"
-              tooltip="go to folder"
+              tooltip={t('alerting.rule-group-action.go-to-folder', 'go to folder')}
               to={baseUrl}
               target="__blank"
             />
@@ -129,10 +123,10 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
           if (folder?.canAdmin) {
             actionIcons.push(
               <ActionIcon
-                aria-label="manage permissions"
+                aria-label={t('alerting.rule-group-action.manage-permissions', 'manage permissions')}
                 key="manage-perms"
                 icon="lock"
-                tooltip="manage permissions"
+                tooltip={t('alerting.rule-group-action.manage-permissions', 'manage permissions')}
                 to={baseUrl + '/permissions'}
                 target="__blank"
               />
@@ -142,64 +136,31 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
       }
       if (folder) {
         if (isListView) {
-          actionIcons.push(
-            <ActionIcon
-              aria-label="export rule folder"
-              data-testid="export-folder"
-              key="export-folder"
-              icon="download-alt"
-              tooltip="Export rules folder"
-              onClick={() => setIsExporting('folder')}
-            />
-          );
-        } else if (isGroupView) {
-          actionIcons.push(
-            <ActionIcon
-              aria-label="export rule group"
-              data-testid="export-group"
-              key="export-group"
-              icon="download-alt"
-              tooltip="Export rule group"
-              onClick={() => setIsExporting('group')}
-            />
-          );
+          actionIcons.push(<FolderActionsButton folderUID={folderUID} key="folder-bulk-actions" />);
         }
       }
     }
-  } else if (canEditRules(rulesSource.name) && hasRuler(rulesSource)) {
-    if (!isFederated) {
+  } else {
+    actionIcons.push(
+      <ActionIcon
+        aria-label={t('alerting.rule-group-action.details', 'rule group details')}
+        key="rule-group-details"
+        icon="info-circle"
+        tooltip={t('alerting.rule-group-action.details', 'rule group details')}
+        to={groups.detailsPageLink(rulesSource.uid, namespace.name, group.name, { includeReturnTo: true })}
+      />
+    );
+    if (canEditGroup) {
       actionIcons.push(
         <ActionIcon
-          aria-label="edit rule group"
-          data-testid="edit-group"
-          key="edit"
+          aria-label={t('alerting.rule-group-action.edit', 'edit rule group')}
+          key="rule-group-edit"
           icon="pen"
-          tooltip="edit rule group"
-          onClick={() => setIsEditingGroup(true)}
-        />
-      );
-      actionIcons.push(
-        <ActionIcon
-          data-testid="reorder-group"
-          key="reorder"
-          icon="exchange-alt"
-          tooltip="reorder rules"
-          className={styles.rotate90}
-          onClick={() => setIsReorderingGroup(true)}
+          tooltip={t('alerting.rule-group-action.edit', 'edit rule group')}
+          to={groups.editPageLink(rulesSource.uid, namespace.name, group.name, { includeReturnTo: true })}
         />
       );
     }
-
-    actionIcons.push(
-      <ActionIcon
-        aria-label="delete rule group"
-        data-testid="delete-group"
-        key="delete-group"
-        icon="trash-alt"
-        tooltip="delete rule group"
-        onClick={() => setIsDeletingGroup(true)}
-      />
-    );
   }
 
   // ungrouped rules are rules that are in the "default" group name
@@ -209,13 +170,6 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
     <RuleLocation namespace={decodeGrafanaNamespace(namespace).name} group={group.name} />
   );
 
-  const closeEditModal = (saved = false) => {
-    if (!saved) {
-      logInfo(LogMessages.leavingRuleGroupEdit);
-    }
-    setIsEditingGroup(false);
-  };
-
   return (
     <div className={styles.wrapper} data-testid="rule-group">
       <div className={styles.header} data-testid="rule-group-header">
@@ -226,20 +180,13 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
           onToggle={setIsCollapsed}
           data-testid={selectors.components.AlertRules.groupToggle}
         />
-        <Icon name={isCollapsed ? 'folder' : 'folder-open'} />
-        {isCloudRulesSource(rulesSource) && (
-          <Tooltip content={rulesSource.name} placement="top">
-            <img
-              alt={rulesSource.meta.name}
-              className={styles.dataSourceIcon}
-              src={rulesSource.meta.info.logos.small}
-            />
-          </Tooltip>
-        )}
+        <FolderIcon isCollapsed={isCollapsed} />
+        <CloudSourceLogo rulesSource={rulesSource} />
         {
           // eslint-disable-next-line
           <div className={styles.groupName} onClick={() => setIsCollapsed(!isCollapsed)}>
-            {isFederated && <Badge color="purple" text="Federated" />} {groupName}
+            {isFederated && <Badge color="purple" text={t('alerting.rules-group.text-federated', 'Federated')} />}{' '}
+            {groupName}
           </div>
         }
         <div className={styles.spacer} />
@@ -250,7 +197,7 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
           <>
             <div className={styles.actionsSeparator}>|</div>
             <div className={styles.actionIcons}>
-              <Badge color="purple" text="Provisioned" />
+              <Badge color="purple" text={t('alerting.rules-group.text-provisioned', 'Provisioned')} />
             </div>
           </>
         )}
@@ -272,55 +219,42 @@ export const RulesGroup = React.memo(({ group, namespace, expandAll, viewMode }:
           rules={group.rules}
         />
       )}
-      {isEditingGroup && (
-        <EditCloudGroupModal
-          namespace={namespace}
-          group={group}
-          onClose={() => closeEditModal()}
-          folderUrl={folder?.canEdit ? makeFolderSettingsLink(folder.uid) : undefined}
-          folderUid={folderUID}
-        />
-      )}
-      {isReorderingGroup && (
-        <ReorderCloudGroupModal
-          group={group}
-          folderUid={folderUID}
-          namespace={namespace}
-          onClose={() => setIsReorderingGroup(false)}
-        />
-      )}
-      <ConfirmModal
-        isOpen={isDeletingGroup}
-        title="Delete group"
-        body={
-          <div>
-            <p>
-              Deleting &quot;<strong>{group.name}</strong>&quot; will permanently remove the group and{' '}
-              {group.rules.length} alert {pluralize('rule', group.rules.length)} belonging to it.
-            </p>
-            <p>Are you sure you want to delete this group?</p>
-          </div>
-        }
-        onConfirm={deleteGroup}
-        onDismiss={() => setIsDeletingGroup(false)}
-        confirmText="Delete"
-      />
       {folder && isExporting === 'folder' && (
         <GrafanaRuleFolderExporter folder={folder} onClose={() => setIsExporting(undefined)} />
       )}
-      {folder && isExporting === 'group' && (
-        <GrafanaRuleGroupExporter
-          folderUid={folder.uid}
-          groupName={group.name}
-          onClose={() => setIsExporting(undefined)}
-        />
-      )}
     </div>
   );
 });
 
 RulesGroup.displayName = 'RulesGroup';
 
+// It's a simple component but we render 80 of them on the list page it needs to be fast
+// The Tooltip component is expensive to render and the rulesSource doesn't change often
+// so memoization seems to bring a lot of benefit here
+const CloudSourceLogo = React.memo(({ rulesSource }: { rulesSource: RulesSource | string }) => {
+  const styles = useStyles2(getStyles);
+
+  if (isCloudRulesSource(rulesSource)) {
+    return (
+      <Tooltip content={rulesSource.name} placement="top">
+        <img alt={rulesSource.meta.name} className={styles.dataSourceIcon} src={rulesSource.meta.info.logos.small} />
+      </Tooltip>
+    );
+  }
+
+  return null;
+});
+
+CloudSourceLogo.displayName = 'CloudSourceLogo';
+
+// We render a lot of these on the list page, and the Icon component does quite a bit of work
+// to render its contents
+const FolderIcon = React.memo(({ isCollapsed }: { isCollapsed: boolean }) => {
+  return <Icon name={isCollapsed ? 'folder' : 'folder-open'} />;
+});
+
+FolderIcon.displayName = 'FolderIcon';
+
 export const getStyles = (theme: GrafanaTheme2) => {
   return {
     wrapper: css({}),
@@ -384,7 +318,7 @@ export const getStyles = (theme: GrafanaTheme2) => {
       margin: `0 ${theme.spacing(2)}`,
     }),
     actionIcons: css({
-      width: '80px',
+      width: '120px',
       alignItems: 'center',
 
       flexShrink: 0,
