@@ -1,7 +1,7 @@
 import { css } from '@emotion/css';
 import { useEffect, useMemo } from 'react';
 
-import { GrafanaTheme2, VariableHide } from '@grafana/data';
+import { CentralAlertHistorySceneV1Props, GrafanaTheme2, VariableHide } from '@grafana/data';
 import { Trans, t } from '@grafana/i18n';
 import {
   CustomVariable,
@@ -43,6 +43,7 @@ import { LogMessages, logInfo } from '../../../Analytics';
 
 import { alertStateHistoryDatasource, useRegisterHistoryRuntimeDataSource } from './CentralHistoryRuntimeDataSource';
 import { HistoryEventsListObject } from './EventListSceneObject';
+import { StateFilterValues } from './constants';
 
 export const LABELS_FILTER = 'LABELS_FILTER';
 export const STATE_FILTER_TO = 'STATE_FILTER_TO';
@@ -57,15 +58,15 @@ export const STATE_FILTER_FROM = 'STATE_FILTER_FROM';
  * Both share time range and filter variable from the parent scene.
  */
 
-export const StateFilterValues = {
-  all: 'all',
-  firing: 'Alerting',
-  normal: 'Normal',
-  pending: 'Pending',
-  recovering: 'Recovering',
-} as const;
-
-export const CentralAlertHistoryScene = () => {
+export const CentralAlertHistoryScene = ({
+  defaultLabelsFilter,
+  defaultTimeRange = {
+    from: 'now-1h',
+    to: 'now',
+  },
+  hideFilters,
+  hideAlertRuleColumn,
+}: CentralAlertHistorySceneV1Props = {}) => {
   //track the loading of the central alert state history
 
   useEffect(() => {
@@ -80,6 +81,7 @@ export const CentralAlertHistoryScene = () => {
     const labelsFilterVariable = new TextBoxVariable({
       name: LABELS_FILTER,
       label: t('alerting.central-alert-history-scene.scene.labels-filter-variable.label.labels', 'Labels: '),
+      ...(defaultLabelsFilter && { value: defaultLabelsFilter }),
     });
 
     //custom variable for filtering by the current state
@@ -107,25 +109,24 @@ export const CentralAlertHistoryScene = () => {
     });
 
     return new EmbeddedScene({
-      controls: [
-        new SceneReactObject({
-          component: LabelFilter,
-        }),
-        new SceneReactObject({
-          component: FilterInfo,
-        }),
-        new VariableValueSelectors({}),
-        new ClearFilterButtonScenesObject({}),
-        new SceneControlsSpacer(),
-        new SceneTimePicker({}),
-        new SceneRefreshPicker({}),
-      ],
+      controls: hideFilters
+        ? undefined
+        : [
+            new SceneReactObject({
+              component: LabelFilter,
+            }),
+            new SceneReactObject({
+              component: FilterInfo,
+            }),
+            new VariableValueSelectors({}),
+            new ClearFilterButtonScenesObject({}),
+            new SceneControlsSpacer(),
+            new SceneTimePicker({}),
+            new SceneRefreshPicker({}),
+          ],
       // use default time range as from 1 hour ago to now, as the limit of the history api is 5000 events,
       // and using a wider time range might lead to showing gaps in the events list and the chart.
-      $timeRange: new SceneTimeRange({
-        from: 'now-1h',
-        to: 'now',
-      }),
+      $timeRange: new SceneTimeRange(defaultTimeRange),
       $variables: new SceneVariableSet({
         variables: [labelsFilterVariable, transitionsFromFilterVariable, transitionsToFilterVariable],
       }),
@@ -134,12 +135,12 @@ export const CentralAlertHistoryScene = () => {
         children: [
           getEventsScenesFlexItem(),
           new SceneFlexItem({
-            body: new HistoryEventsListObject({}),
+            body: new HistoryEventsListObject({ hideAlertRuleColumn }),
           }),
         ],
       }),
     });
-  }, []);
+  }, [defaultLabelsFilter, defaultTimeRange, hideFilters, hideAlertRuleColumn]);
 
   // we need to call this to sync the url with the scene state
   const isUrlSyncInitialized = useUrlSync(scene);
@@ -304,3 +305,5 @@ const getStyles = (theme: GrafanaTheme2) => {
     }),
   };
 };
+
+export default CentralAlertHistoryScene;
