@@ -1,4 +1,4 @@
-import { RulesSource, RulesSourceIdentifier } from 'app/types/unified-alerting';
+import { GrafanaRulesSourceSymbol, RulesSource } from 'app/types/unified-alerting';
 
 import { featureDiscoveryApi } from '../api/featureDiscoveryApi';
 import { getRulesSourceName } from '../utils/datasource';
@@ -16,8 +16,8 @@ export function useHasRuler(rulesSource: RulesSource) {
   return { hasRuler, rulerConfig: dsFeatures?.rulerConfig };
 }
 
-export function useHasRulerV2(rulesSource: RulesSourceIdentifier) {
-  const { currentData: dsFeatures } = useDiscoverDsFeaturesQuery({ uid: rulesSource.uid });
+export function useHasRulerV2(ruleUid: string | typeof GrafanaRulesSourceSymbol) {
+  const { currentData: dsFeatures } = useDiscoverDsFeaturesQuery({ uid: ruleUid });
   const hasRuler = Boolean(dsFeatures?.rulerConfig);
 
   return { hasRuler, rulerConfig: dsFeatures?.rulerConfig };
