@@ -38,9 +38,10 @@ import {
   LibraryPanelKind,
   PanelKind,
   GridLayoutItemKind,
+  defaultDataQueryKind,
   RowsLayoutRowKind,
   GridLayoutKind,
-} from '@grafana/schema/dist/esm/schema/dashboard/v2alpha1/types.spec.gen';
+} from '@grafana/schema/dist/esm/schema/dashboard/v2';
 import { DashboardLink, DataTransformerConfig } from '@grafana/schema/src/raw/dashboard/x/dashboard_types.gen';
 import { isWeekStart, WeekStart } from '@grafana/ui';
 import {
@@ -55,6 +56,7 @@ import {
   DeprecatedInternalId,
   ObjectMeta,
 } from 'app/features/apiserver/types';
+import { transformV2ToV1AnnotationQuery } from 'app/features/dashboard-scene/serialization/annotations';
 import { GRID_ROW_HEIGHT } from 'app/features/dashboard-scene/serialization/const';
 import { validateFiltersOrigin } from 'app/features/dashboard-scene/serialization/sceneVariablesSetToVariables';
 import { TypedVariableModelV2 } from 'app/features/dashboard-scene/serialization/transformSaveModelSchemaV2ToScene';
@@ -76,7 +78,7 @@ import {
 import { DashboardDataDTO, DashboardDTO } from 'app/types/dashboard';
 
 import { DashboardWithAccessInfo } from './types';
-import { isDashboardResource, isDashboardV0Spec, isDashboardV2Resource } from './utils';
+import { isDashboardResource, isDashboardV0Spec, isDashboardV2Resource, isDashboardV2Spec } from './utils';
 
 export function ensureV2Response(
   dto: DashboardDTO | DashboardWithAccessInfo<DashboardDataDTO> | DashboardWithAccessInfo<DashboardV2Spec>
@@ -92,14 +94,6 @@ export function ensureV2Response(
     dashboard = dto.dashboard;
   }
 
-  const timeSettingsDefaults = defaultTimeSettingsSpec();
-  const dashboardDefaults = defaultDashboardV2Spec();
-  const [elements, layout] = getElementsFromPanels(dashboard.panels || []);
-  // @ts-expect-error - dashboard.templating.list is VariableModel[] and we need TypedVariableModel[] here
-  // that would allow accessing unique properties for each variable type that the API returns
-  const variables = getVariables(dashboard.templating?.list || []);
-  const annotations = getAnnotations(dashboard.annotations?.list || []);
-
   let accessMeta: DashboardWithAccessInfo<DashboardV2Spec>['access'];
   let annotationsMeta: DashboardWithAccessInfo<DashboardV2Spec>['metadata']['annotations'];
   let labelsMeta: DashboardWithAccessInfo<DashboardV2Spec>['metadata']['labels'];
@@ -152,6 +146,36 @@ export function ensureV2Response(
     annotationsMeta[AnnoKeyDashboardSnapshotOriginalUrl] = dashboard.snapshot?.originalUrl;
   }
 
+  const metadata = {
+    creationTimestamp: creationTimestamp || '', // TODO verify this empty string is valid
+    name: dashboard.uid,
+    resourceVersion: dashboard.version?.toString() || '0',
+    annotations: annotationsMeta,
+    labels: labelsMeta,
+  };
+
+  if (!isDashboardResource(dto)) {
+    if (isDashboardV2Spec(dto.dashboard)) {
+      // sometimes we can have a v2 spec returned through legacy api like public dashboard
+      // in that case we need to return dashboard as it is, since the conversion is not needed
+      return {
+        apiVersion: 'v2beta1',
+        kind: 'DashboardWithAccessInfo',
+        metadata,
+        spec: dto.dashboard,
+        access: accessMeta,
+      };
+    }
+  }
+
+  const timeSettingsDefaults = defaultTimeSettingsSpec();
+  const dashboardDefaults = defaultDashboardV2Spec();
+  const [elements, layout] = getElementsFromPanels(dashboard.panels || []);
+  // @ts-expect-error - dashboard.templating.list is VariableModel[] and we need TypedVariableModel[] here
+  // that would allow accessing unique properties for each variable type that the API returns
+  const variables = getVariables(dashboard.templating?.list || []);
+  const annotations = getAnnotations(dashboard.annotations?.list || []);
+
   const spec: DashboardV2Spec = {
     title: dashboard.title,
     description: dashboard.description,
@@ -181,15 +205,9 @@ export function ensureV2Response(
   };
 
   return {
-    apiVersion: 'v2alpha1',
+    apiVersion: 'v2beta1',
     kind: 'DashboardWithAccessInfo',
-    metadata: {
-      creationTimestamp: creationTimestamp || '', // TODO verify this empty string is valid
-      name: dashboard.uid,
-      resourceVersion: dashboard.version?.toString() || '0',
-      annotations: annotationsMeta,
-      labels: labelsMeta,
-    },
+    metadata,
     spec,
     access: accessMeta,
   };
@@ -423,52 +441,7 @@ function buildElement(p: Panel): [PanelKind | LibraryPanelKind, string] {
     return [panelKind, element_identifier];
   } else {
     // PanelKind
-
-    const queries = getPanelQueries(
-      (p.targets as unknown as DataQuery[]) || [],
-      p.datasource || getDefaultDatasource()
-    );
-
-    const transformations = getPanelTransformations(p.transformations || []);
-
-    const panelKind: PanelKind = {
-      kind: 'Panel',
-      spec: {
-        title: p.title || '',
-        description: p.description || '',
-        vizConfig: {
-          kind: p.type,
-          spec: {
-            fieldConfig: (p.fieldConfig as any) || defaultFieldConfigSource(),
-            options: p.options as any,
-            pluginVersion: p.pluginVersion!,
-          },
-        },
-        links:
-          p.links?.map<DataLink>((l) => ({
-            title: l.title,
-            url: l.url || '',
-            targetBlank: l.targetBlank,
-          })) || [],
-        id: p.id!,
-        data: {
-          kind: 'QueryGroup',
-          spec: {
-            queries,
-            transformations,
-            queryOptions: {
-              cacheTimeout: p.cacheTimeout,
-              maxDataPoints: p.maxDataPoints,
-              interval: p.interval,
-              hideTimeOverride: p.hideTimeOverride,
-              queryCachingTTL: p.queryCachingTTL,
-              timeFrom: p.timeFrom,
-              timeShift: p.timeShift,
-            },
-          },
-        },
-      },
-    };
+    const panelKind = buildPanelKind(p);
     return [panelKind, element_identifier];
   }
 }
@@ -483,7 +456,7 @@ export function getDefaultDatasource(): DataSourceRef {
 
   if (configDefaultDS.uid && !configDefaultDS.apiVersion) {
     // get api version from config
-    const dsInstance = config.bootData.settings.datasources[configDefaultDS.uid];
+    const dsInstance = config.datasources[configDefaultDS.uid];
     configDefaultDS.apiVersion = dsInstance.apiVersion ?? undefined;
   }
 
@@ -502,9 +475,13 @@ export function getPanelQueries(targets: DataQuery[], panelDatasource: DataSourc
       spec: {
         refId: t.refId,
         hidden: t.hide ?? false,
-        datasource: t.datasource ? t.datasource : panelDatasource,
         query: {
-          kind: t.datasource?.type || panelDatasource.type!,
+          kind: 'DataQuery',
+          version: defaultDataQueryKind().version,
+          group: t.datasource?.type || panelDatasource.type!,
+          datasource: {
+            name: t.datasource?.uid || panelDatasource.uid!,
+          },
           spec: {
             ...query,
           },
@@ -515,6 +492,53 @@ export function getPanelQueries(targets: DataQuery[], panelDatasource: DataSourc
   });
 }
 
+export function buildPanelKind(p: Panel): PanelKind {
+  const queries = getPanelQueries((p.targets as unknown as DataQuery[]) || [], p.datasource || getDefaultDatasource());
+
+  const transformations = getPanelTransformations(p.transformations || []);
+
+  const panelKind: PanelKind = {
+    kind: 'Panel',
+    spec: {
+      title: p.title || '',
+      description: p.description || '',
+      vizConfig: {
+        kind: 'VizConfig',
+        group: p.type,
+        version: p.pluginVersion!,
+        spec: {
+          fieldConfig: (p.fieldConfig as any) || defaultFieldConfigSource(),
+          options: p.options as any,
+        },
+      },
+      links:
+        p.links?.map<DataLink>((l) => ({
+          title: l.title,
+          url: l.url || '',
+          targetBlank: l.targetBlank,
+        })) || [],
+      id: p.id!,
+      data: {
+        kind: 'QueryGroup',
+        spec: {
+          queries,
+          transformations,
+          queryOptions: {
+            cacheTimeout: p.cacheTimeout,
+            maxDataPoints: p.maxDataPoints,
+            interval: p.interval,
+            hideTimeOverride: p.hideTimeOverride,
+            queryCachingTTL: p.queryCachingTTL,
+            timeFrom: p.timeFrom,
+            timeShift: p.timeShift,
+          },
+        },
+      },
+    },
+  };
+  return panelKind;
+}
+
 function getPanelTransformations(transformations: DataTransformerConfig[]): TransformationKind[] {
   return transformations.map((t) => {
     return {
@@ -538,6 +562,9 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
       hide: transformVariableHideToEnum(v.hide),
     };
 
+    let ds: DataSourceRef | undefined;
+    let dsType: string | undefined;
+
     switch (v.type) {
       case 'query':
         let query = v.query || {};
@@ -568,7 +595,12 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
             regex: v.regex || '',
             sort: transformSortVariableToEnum(v.sort),
             query: {
-              kind: v.datasource?.type || getDefaultDatasourceType(),
+              kind: 'DataQuery',
+              version: defaultDataQueryKind().version,
+              group: v.datasource?.type ?? getDefaultDatasourceType(),
+              datasource: {
+                name: v.datasource?.uid,
+              },
               spec: query,
             },
             allowCustomValue: v.allowCustomValue ?? true,
@@ -623,17 +655,27 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
         variables.push(cv);
         break;
       case 'adhoc':
+        ds = v.datasource || getDefaultDatasource();
+        dsType = ds.type ?? getDefaultDatasourceType();
+
         const av: AdhocVariableKind = {
           kind: 'AdhocVariable',
+          group: dsType,
           spec: {
             ...commonProperties,
-            datasource: v.datasource || getDefaultDatasource(),
             baseFilters: validateFiltersOrigin(v.baseFilters) || [],
             filters: validateFiltersOrigin(v.filters) || [],
             defaultKeys: v.defaultKeys || [],
             allowCustomValue: v.allowCustomValue ?? true,
           },
         };
+
+        if (ds.uid) {
+          av.datasource = {
+            name: ds.uid,
+          };
+        }
+
         variables.push(av);
         break;
       case 'constant':
@@ -687,11 +729,14 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
         variables.push(tx);
         break;
       case 'groupby':
+        ds = v.datasource || getDefaultDatasource();
+        dsType = ds.type ?? getDefaultDatasourceType();
+
         const gb: GroupByVariableKind = {
           kind: 'GroupByVariable',
+          group: dsType,
           spec: {
             ...commonProperties,
-            datasource: v.datasource || getDefaultDatasource(),
             options: v.options,
             current: {
               value: v.current.value,
@@ -700,6 +745,13 @@ function getVariables(vars: TypedVariableModel[]): DashboardV2Spec['variables']
             multi: v.multi,
           },
         };
+
+        if (ds.uid) {
+          gb.datasource = {
+            name: ds.uid,
+          };
+        }
+
         variables.push(gb);
         break;
       default:
@@ -722,7 +774,12 @@ function getAnnotations(annotations: AnnotationQuery[]): DashboardV2Spec['annota
         iconColor: a.iconColor,
         builtIn: Boolean(a.builtIn),
         query: {
-          kind: a.datasource?.type || getDefaultDatasourceType(),
+          kind: 'DataQuery',
+          version: defaultDataQueryKind().version,
+          group: a.datasource?.type || getDefaultDatasourceType(),
+          datasource: {
+            name: a.datasource?.uid,
+          },
           spec: {
             ...a.target,
           },
@@ -757,7 +814,10 @@ function getVariablesV1(vars: DashboardV2Spec['variables']): VariableModel[] {
             LEGACY_STRING_VALUE_KEY in v.spec.query.spec
               ? v.spec.query.spec[LEGACY_STRING_VALUE_KEY]
               : v.spec.query.spec,
-          datasource: v.spec.datasource,
+          datasource: {
+            type: v.spec.query?.spec.group,
+            uid: v.spec.query?.spec.datasource?.name,
+          },
           sort: transformSortVariableToEnumV1(v.spec.sort),
           refresh: transformVariableRefreshToEnumV1(v.spec.refresh),
           regex: v.spec.regex,
@@ -849,7 +909,10 @@ function getVariablesV1(vars: DashboardV2Spec['variables']): VariableModel[] {
       case 'GroupByVariable':
         const gv: VariableModel = {
           ...commonProperties,
-          datasource: v.spec.datasource,
+          datasource: {
+            uid: v.datasource?.name,
+            type: v.group,
+          },
           current: v.spec.current,
           options: v.spec.options,
         };
@@ -858,7 +921,10 @@ function getVariablesV1(vars: DashboardV2Spec['variables']): VariableModel[] {
       case 'AdhocVariable':
         const av: VariableModel = {
           ...commonProperties,
-          datasource: v.spec.datasource,
+          datasource: {
+            uid: v.datasource?.name,
+            type: v.group,
+          },
           // @ts-expect-error
           baseFilters: v.spec.baseFilters,
           filters: v.spec.filters,
@@ -874,22 +940,6 @@ function getVariablesV1(vars: DashboardV2Spec['variables']): VariableModel[] {
   return variables;
 }
 
-function getAnnotationsV1(annotations: DashboardV2Spec['annotations']): AnnotationQuery[] {
-  // @ts-expect-error - target v2 query is not compatible with v1 target
-  return annotations.map((a) => {
-    return {
-      name: a.spec.name,
-      datasource: a.spec.datasource,
-      enable: a.spec.enable,
-      hide: a.spec.hide,
-      iconColor: a.spec.iconColor,
-      builtIn: a.spec.builtIn ? 1 : 0,
-      target: a.spec.query?.spec,
-      filter: a.spec.filter,
-    };
-  });
-}
-
 interface LibraryPanelDTO extends Pick<Panel, 'libraryPanel' | 'id' | 'title' | 'gridPos' | 'type'> {}
 
 function getPanelsV1(
@@ -933,12 +983,12 @@ function transformV2PanelToV1Panel(
     const panel = p.spec;
     return {
       id: panel.id,
-      type: panel.vizConfig.kind,
+      type: panel.vizConfig.group,
       title: panel.title,
       description: panel.description,
       fieldConfig: transformMappingsToV1(panel.vizConfig.spec.fieldConfig),
       options: panel.vizConfig.spec.options,
-      pluginVersion: panel.vizConfig.spec.pluginVersion,
+      pluginVersion: panel.vizConfig.version,
       links:
         // @ts-expect-error - Panel link is wrongly typed as DashboardLink
         panel.links?.map<DashboardLink>((l) => ({
@@ -950,7 +1000,10 @@ function transformV2PanelToV1Panel(
         return {
           refId: q.spec.refId,
           hide: q.spec.hidden,
-          datasource: q.spec.datasource,
+          datasource: {
+            uid: q.spec.query.spec.datasource?.uid,
+            type: q.spec.query.spec.group,
+          },
           ...q.spec.query.spec,
         };
       }),
@@ -1134,7 +1187,8 @@ function transformToV1VariableTypes(variable: TypedVariableModelV2): VariableTyp
 }
 
 export function transformDashboardV2SpecToV1(spec: DashboardV2Spec, metadata: ObjectMeta): DashboardDataDTO {
-  const annotations = getAnnotationsV1(spec.annotations);
+  const annotations = spec.annotations.map(transformV2ToV1AnnotationQuery);
+
   const variables = getVariablesV1(spec.variables);
   const panels = getPanelsV1(spec.elements, spec.layout);
   return {
