@@ -1,9 +1,9 @@
 import { locationUtil } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { LinkButton, ButtonVariant } from '@grafana/ui';
 import { contextSrv } from 'app/core/core';
-import { Trans } from 'app/core/internationalization';
 import { ROUTES as CONNECTIONS_ROUTES } from 'app/features/connections/constants';
-import { AccessControlAction } from 'app/types';
+import { AccessControlAction } from 'app/types/accessControl';
 
 interface AddNewDataSourceButtonProps {
   onClick?: () => void;
@@ -19,7 +19,14 @@ export function AddNewDataSourceButton({ variant, onClick }: AddNewDataSourceBut
       variant={variant || 'primary'}
       href={newDataSourceURL}
       disabled={!hasCreateRights}
-      tooltip={!hasCreateRights ? 'You do not have permission to configure new data sources' : undefined}
+      tooltip={
+        !hasCreateRights
+          ? t(
+              'datasources.add-new-data-source-button.tooltip-no-permission',
+              'You do not have permission to configure new data sources'
+            )
+          : undefined
+      }
       onClick={onClick}
       target="_blank"
     >
