@@ -1,6 +1,6 @@
-import { DataFrame, EventBus, LoadingState, SplitOpen, TimeRange } from '@grafana/data';
+import { DataFrame, DataLinksContext, EventBus, LoadingState, SplitOpen, TimeRange } from '@grafana/data';
 import { PanelRenderer } from '@grafana/runtime';
-import { PanelChrome, PanelContext, PanelContextProvider } from '@grafana/ui';
+import { PanelChrome } from '@grafana/ui';
 
 import { getPanelPluginMeta } from '../plugins/importPanelPlugin';
 
@@ -18,29 +18,13 @@ export interface Props {
   eventBus: EventBus;
 }
 
-export function CustomContainer({
-  width,
-  height,
-  timeZone,
-  state,
-  pluginId,
-  frames,
-  timeRange,
-  splitOpenFn,
-  eventBus,
-}: Props) {
+export function CustomContainer({ width, height, timeZone, state, pluginId, frames, timeRange, splitOpenFn }: Props) {
   const plugin = getPanelPluginMeta(pluginId);
 
   const dataLinkPostProcessor = useExploreDataLinkPostProcessor(splitOpenFn, timeRange);
 
-  const panelContext: PanelContext = {
-    dataLinkPostProcessor,
-    eventBus,
-    eventsScope: 'explore',
-  };
-
   return (
-    <PanelContextProvider value={panelContext}>
+    <DataLinksContext.Provider value={{ dataLinkPostProcessor }}>
       <PanelChrome title={plugin.name} width={width} height={height} loadingState={state}>
         {(innerWidth, innerHeight) => (
           <PanelRenderer
@@ -53,6 +37,6 @@ export function CustomContainer({
           />
         )}
       </PanelChrome>
-    </PanelContextProvider>
+    </DataLinksContext.Provider>
   );
 }
