@@ -1,6 +1,7 @@
 import {
   DataFrame,
   DataLink,
+  DataLinkPostProcessor,
   DataSourceInstanceSettings,
   DataSourceJsonData,
   dateTime,
@@ -44,6 +45,7 @@ export function createSpanLinkFactory({
   dataFrame,
   createFocusSpanLink,
   trace,
+  dataLinkPostProcessor,
 }: {
   splitOpenFn: SplitOpen;
   traceToLogsOptions?: TraceToLogsOptionsV2;
@@ -52,6 +54,7 @@ export function createSpanLinkFactory({
   dataFrame?: DataFrame;
   createFocusSpanLink?: (traceId: string, spanId: string) => LinkModel<Field>;
   trace: Trace;
+  dataLinkPostProcessor?: DataLinkPostProcessor;
 }): SpanLinkFunc | undefined {
   if (!dataFrame) {
     return undefined;
@@ -67,7 +70,9 @@ export function createSpanLinkFactory({
     traceToLogsOptions,
     traceToMetricsOptions,
     createFocusSpanLink,
-    scopedVars
+    scopedVars,
+    dataFrame,
+    dataLinkPostProcessor
   );
 
   return function SpanLink(span: TraceSpan): SpanLinkDef[] | undefined {
@@ -147,7 +152,9 @@ function legacyCreateSpanLinkFactory(
   traceToLogsOptions?: TraceToLogsOptionsV2,
   traceToMetricsOptions?: TraceToMetricsOptions,
   createFocusSpanLink?: (traceId: string, spanId: string) => LinkModel<Field>,
-  scopedVars?: ScopedVars
+  scopedVars?: ScopedVars,
+  dataFrame?: DataFrame,
+  dataLinkPostProcessor?: DataLinkPostProcessor
 ) {
   let logsDataSourceSettings: DataSourceInstanceSettings<DataSourceJsonData> | undefined;
   if (traceToLogsOptions?.datasourceUid) {
@@ -196,6 +203,13 @@ function legacyCreateSpanLinkFactory(
         case 'googlecloud-logging-datasource':
           tags = getFormattedTags(span, tagsToUse, { joinBy: ' AND ' });
           query = getQueryForGoogleCloudLogging(span, traceToLogsOptions, tags, customQuery);
+          break;
+        case 'victoriametrics-logs-datasource':
+          // Build tag selector using strict equality (":=") required by LogsQL
+          // See https://docs.victoriametrics.com/victorialogs/logsql/#exact-filter
+          tags = getFormattedTags(span, tagsToUse, { labelValueSign: ':=', joinBy: ' AND ' });
+          query = getQueryForVictoriaLogs(span, traceToLogsOptions, tags, customQuery);
+          break;
       }
 
       // query can be false in case the simple UI tag mapping is used but none of them are present in the span.
@@ -208,6 +222,18 @@ function legacyCreateSpanLinkFactory(
             datasourceUid: logsDataSourceSettings.uid,
             datasourceName: logsDataSourceSettings.name,
             query,
+            range: getTimeRangeFromSpan(
+              span,
+              {
+                startMs: traceToLogsOptions.spanStartTimeShift
+                  ? rangeUtil.intervalToMs(traceToLogsOptions.spanStartTimeShift)
+                  : 0,
+                endMs: traceToLogsOptions.spanEndTimeShift
+                  ? rangeUtil.intervalToMs(traceToLogsOptions.spanEndTimeShift)
+                  : 0,
+              },
+              isSplunkDS
+            ),
           },
         };
 
@@ -222,29 +248,32 @@ function legacyCreateSpanLinkFactory(
         // Check if all variables are defined and don't show if they aren't. This is usually handled by the
         // getQueryFor* functions but this is for case of custom query supplied by the user.
         if (getVariableUsageInfo(dataLink.internal!.query, scopedVars).allVariablesDefined) {
-          const link = mapInternalLinkToExplore({
+          let link = mapInternalLinkToExplore({
             link: dataLink,
             internalLink: dataLink.internal!,
             scopedVars: scopedVars,
-            range: getTimeRangeFromSpan(
-              span,
-              {
-                startMs: traceToLogsOptions.spanStartTimeShift
-                  ? rangeUtil.intervalToMs(traceToLogsOptions.spanStartTimeShift)
-                  : 0,
-                endMs: traceToLogsOptions.spanEndTimeShift
-                  ? rangeUtil.intervalToMs(traceToLogsOptions.spanEndTimeShift)
-                  : 0,
-              },
-              isSplunkDS
-            ),
+            range: dataLink.internal!.range,
             field: {} as Field,
             onClickFn: splitOpenFn,
             replaceVariables: getTemplateSrv().replace.bind(getTemplateSrv()),
           });
 
+          link =
+            (dataFrame &&
+              dataLinkPostProcessor?.({
+                frame: dataFrame,
+                field: field,
+                dataLinkScopedVars: scopedVars,
+                replaceVariables: getTemplateSrv().replace.bind(getTemplateSrv()),
+                config: {},
+                link: dataLink,
+                linkModel: link,
+              })) ||
+            link;
+
           links.push({
             href: link.href,
+            linkModel: link,
             title: t('explore.legacy-create-span-link-factory.title.related-logs', 'Related logs'),
             onClick: link.onClick,
             content: (
@@ -344,6 +373,7 @@ function legacyCreateSpanLinkFactory(
 
         links!.push({
           href: link.href,
+          linkModel: link,
           title,
           content: <Icon name="link" title={title} />,
           onClick: link.onClick,
@@ -417,11 +447,11 @@ function getQueryForLoki(
   let expr = '{${__tags}}';
   if (filterByTraceID && span.traceID) {
     expr +=
-      ' | label_format log_line_contains_trace_id=`{{ contains "${__span.traceId}" __line__  }}` | log_line_contains_trace_id="true" OR trace_id="${__span.traceId}"';
+      ' | label_format log_line_contains_trace_id=`{{ contains "${__span.traceId}" __line__  }}` | log_line_contains_trace_id="true" or trace_id="${__span.traceId}"';
   }
   if (filterBySpanID && span.spanID) {
     expr +=
-      ' | label_format log_line_contains_span_id=`{{ contains "${__span.spanId}" __line__  }}` | log_line_contains_span_id="true" OR span_id="${__span.spanId}"';
+      ' | label_format log_line_contains_span_id=`{{ contains "${__span.spanId}" __line__  }}` | log_line_contains_span_id="true" or span_id="${__span.spanId}"';
   }
 
   return {
@@ -568,6 +598,45 @@ function getQueryForFalconLogScale(span: TraceSpan, options: TraceToLogsOptionsV
   };
 }
 
+/**
+ * Builds a LogsQL expression for victoria‑metrics‑logs‑datasource.
+ * Uses := for exact‑match filters and joins parts with AND.
+ * See https://docs.victoriametrics.com/victorialogs/logsql/#exact-filter
+ */
+function getQueryForVictoriaLogs(span: TraceSpan, options: TraceToLogsOptionsV2, tags: string, customQuery?: string) {
+  const { filterByTraceID, filterBySpanID } = options;
+
+  // Custom user query has priority
+  if (customQuery) {
+    return {
+      expr: customQuery,
+      refId: '',
+    };
+  }
+
+  const parts: string[] = [];
+
+  if (filterBySpanID && span.spanID) {
+    parts.push('span_id:="${__span.spanId}"');
+  }
+  if (filterByTraceID && span.traceID) {
+    parts.push('trace_id:="${__span.traceId}"');
+  }
+  if (tags) {
+    parts.push('${__tags}');
+  }
+
+  // Nothing to match against – do not create the link
+  if (!parts.length) {
+    return undefined;
+  }
+
+  return {
+    expr: parts.join(' AND '),
+    refId: '',
+  };
+}
+
 /**
  * Creates a string representing all the tags already formatted for use in the query. The tags are filtered so that
  * only intersection of tags that exist in a span and tags that you want are serialized into the string.
