@@ -12,6 +12,7 @@ import { MIXED_DATASOURCE_NAME } from 'app/plugins/datasource/mixed/MixedDataSou
 import { configureStore } from 'app/store/configureStore';
 
 import { makeDatasourceSetup } from '../../spec/helper/setup';
+import { updateQueryLibraryRefAction } from '../../state/explorePane';
 import { splitClose, splitOpen } from '../../state/main';
 
 import { useStateSync } from './';
@@ -584,4 +585,34 @@ describe('useStateSync', () => {
       expect(store.getState().explore.panes['one']?.queries[0]).toMatchObject({ expr: 'b', refId: 'B' });
     });
   });
+
+  it('should keep queryLibraryRef in state but not in URL', async () => {
+    const { store, location } = setup({
+      queryParams: {
+        panes: JSON.stringify({
+          one: {
+            datasource: 'loki-uid',
+            queries: [{ expr: 'test', refId: 'A' }],
+          },
+        }),
+        schemaVersion: 1,
+      },
+    });
+
+    await waitFor(() => {
+      expect(store.getState().explore.panes['one']).toBeDefined();
+    });
+
+    act(() => {
+      store.dispatch(updateQueryLibraryRefAction({ exploreId: 'one', queryLibraryRef: 'library-query-456' }));
+    });
+
+    await waitFor(() => {
+      expect(store.getState().explore.panes['one']?.queryLibraryRef).toBe('library-query-456');
+
+      const search = location.getSearchObject();
+      const panes = search.panes && typeof search.panes === 'string' ? JSON.parse(search.panes) : {};
+      expect(panes.one?.queryLibraryRef).toBeUndefined();
+    });
+  });
 });
