@@ -1,18 +1,18 @@
 import { Token } from 'prismjs';
+import { memo } from 'react';
 
-import { LogListModel } from './processing';
-
-export const HighlightedLogRenderer = ({ log }: { log: LogListModel }) => {
+export const HighlightedLogRenderer = memo(({ tokens }: { tokens: Array<string | Token> }) => {
   return (
     <>
-      {log.highlightedBodyTokens.map((token, i) => (
+      {tokens.map((token, i) => (
         <LogToken token={token} key={i} />
       ))}
     </>
   );
-};
+});
+HighlightedLogRenderer.displayName = 'HighlightedLogRenderer';
 
-const LogToken = ({ token }: { token: Token | string }) => {
+const LogToken = memo(({ token }: { token: Token | string }) => {
   if (typeof token === 'string') {
     return token;
   }
@@ -30,4 +30,5 @@ const LogToken = ({ token }: { token: Token | string }) => {
       {typeof token.content === 'string' ? token.content : <LogToken token={token.content} />}
     </span>
   );
-};
+});
+LogToken.displayName = 'LogToken';
