@@ -5,7 +5,7 @@ import { useMedia } from 'react-use';
 import { GrafanaTheme2 } from '@grafana/data';
 import { selectors as e2eSelectors } from '@grafana/e2e-selectors/src';
 import { Trans, t } from '@grafana/i18n';
-import { config, reportInteraction } from '@grafana/runtime';
+import { reportInteraction } from '@grafana/runtime';
 import {
   Card,
   EmptyState,
@@ -57,13 +57,9 @@ const PublicDashboardCard = ({ pd }: { pd: PublicDashboardListResponse }) => {
 
   const CardActions = useMemo(() => (isMobile ? Card.Actions : Card.SecondaryActions), [isMobile]);
 
-  const isNewSharingComponentEnabled = config.featureToggles.newDashboardSharingComponent;
-  const translatedPauseSharingText = isNewSharingComponentEnabled
-    ? t('shared-dashboard-list.toggle.pause-sharing-toggle-text', 'Pause access')
-    : t('public-dashboard-list.toggle.pause-sharing-toggle-text', 'Pause sharing');
-
+  const translatedPauseSharingText = t('shared-dashboard-list.toggle.pause-sharing-toggle-text', 'Pause access');
   return (
-    <Card className={styles.card} href={`/d/${pd.dashboardUid}`}>
+    <Card noMargin className={styles.card} href={`/d/${pd.dashboardUid}`}>
       <Card.Heading className={styles.heading}>
         <span>{pd.title}</span>
       </Card.Heading>
@@ -91,11 +87,7 @@ const PublicDashboardCard = ({ pd }: { pd: PublicDashboardListResponse }) => {
           color={theme.colors.warning.text}
           href={generatePublicDashboardUrl(pd.accessToken)}
           key="public-dashboard-url"
-          tooltip={
-            isNewSharingComponentEnabled
-              ? t('shared-dashboard-list.button.view-button-tooltip', 'View shared dashboard')
-              : t('public-dashboard-list.button.view-button-tooltip', 'View public dashboard')
-          }
+          tooltip={t('shared-dashboard-list.button.view-button-tooltip', 'View shared dashboard')}
           data-testid={selectors.ListItem.linkButton}
         />
         <LinkButton
@@ -105,11 +97,7 @@ const PublicDashboardCard = ({ pd }: { pd: PublicDashboardListResponse }) => {
           color={theme.colors.warning.text}
           href={generatePublicDashboardConfigUrl(pd.dashboardUid, pd.slug)}
           key="public-dashboard-config-url"
-          tooltip={
-            isNewSharingComponentEnabled
-              ? t('shared-dashboard-list.button.config-button-tooltip', 'Configure shared dashboard')
-              : t('public-dashboard-list.button.config-button-tooltip', 'Configure public dashboard')
-          }
+          tooltip={t('shared-dashboard-list.button.config-button-tooltip', 'Configure shared dashboard')}
           data-testid={selectors.ListItem.configButton}
         />
         {hasWritePermissions && (
@@ -118,11 +106,7 @@ const PublicDashboardCard = ({ pd }: { pd: PublicDashboardListResponse }) => {
             icon="trash-alt"
             variant="secondary"
             publicDashboard={pd}
-            tooltip={
-              isNewSharingComponentEnabled
-                ? t('shared-dashboard-list.button.revoke-button-tooltip', 'Revoke access')
-                : t('public-dashboard-list.button.revoke-button-tooltip', 'Revoke public dashboard URL')
-            }
+            tooltip={t('shared-dashboard-list.button.revoke-button-tooltip', 'Revoke access')}
             loader={<Spinner />}
             data-testid={selectors.ListItem.trashcanButton}
           />
@@ -144,43 +128,23 @@ export const PublicDashboardListTable = () => {
         {!isLoading && !isError && !!paginatedPublicDashboards && (
           <div>
             {paginatedPublicDashboards.publicDashboards.length === 0 ? (
-              config.featureToggles.newDashboardSharingComponent ? (
-                <EmptyState
-                  variant="call-to-action"
-                  message={t(
-                    'shared-dashboard-list.empty-state.message',
-                    "You haven't created any shared dashboards yet"
-                  )}
-                >
-                  <Trans i18nKey="shared-dashboard-list.empty-state.more-info">
-                    Create a shared dashboard from any existing dashboard through the <b>Share</b> modal.{' '}
-                    <TextLink
-                      external
-                      href="https://grafana.com/docs/grafana/latest/dashboards/share-dashboards-panels/shared-dashboards"
-                    >
-                      Learn more
-                    </TextLink>
-                  </Trans>
-                </EmptyState>
-              ) : (
-                <EmptyState
-                  variant="call-to-action"
-                  message={t(
-                    'public-dashboard-list.empty-state.message',
-                    "You haven't created any public dashboards yet"
-                  )}
-                >
-                  <Trans i18nKey="public-dashboard-list.empty-state.more-info">
-                    Create a public dashboard from any existing dashboard through the <b>Share</b> modal.{' '}
-                    <TextLink
-                      external
-                      href="https://grafana.com/docs/grafana/latest/dashboards/dashboard-public/#make-a-dashboard-public"
-                    >
-                      Learn more
-                    </TextLink>
-                  </Trans>
-                </EmptyState>
-              )
+              <EmptyState
+                variant="call-to-action"
+                message={t(
+                  'shared-dashboard-list.empty-state.message',
+                  "You haven't created any shared dashboards yet"
+                )}
+              >
+                <Trans i18nKey="shared-dashboard-list.empty-state.more-info">
+                  Create a shared dashboard from any existing dashboard through the <b>Share</b> modal.{' '}
+                  <TextLink
+                    external
+                    href="https://grafana.com/docs/grafana/latest/dashboards/share-dashboards-panels/shared-dashboards"
+                  >
+                    Learn more
+                  </TextLink>
+                </Trans>
+              </EmptyState>
             ) : (
               <>
                 <ul className={styles.list}>
@@ -209,6 +173,9 @@ const getStyles = (theme: GrafanaTheme2) => ({
   list: css({
     listStyleType: 'none',
     marginBottom: theme.spacing(2),
+    display: 'flex',
+    flexDirection: 'column',
+    gap: theme.spacing(1),
   }),
   card: css({
     [theme.breakpoints.up('sm')]: {
