@@ -1,25 +1,21 @@
-import React, { PureComponent } from 'react';
-import { connect } from 'react-redux';
+import { PureComponent } from 'react';
+import { ConnectedProps, connect } from 'react-redux';
 
-import { NavModel } from '@grafana/data';
-import { VerticalGroup } from '@grafana/ui';
+import { t } from '@grafana/i18n';
+import { Stack } from '@grafana/ui';
 import { Page } from 'app/core/components/Page/Page';
 import SharedPreferences from 'app/core/components/SharedPreferences/SharedPreferences';
-import { contextSrv } from 'app/core/core';
+import { appEvents, contextSrv } from 'app/core/core';
 import { getNavModel } from 'app/core/selectors/navModel';
-import { AccessControlAction, Organization, StoreState } from 'app/types';
+import { AccessControlAction } from 'app/types/accessControl';
+import { ShowConfirmModalEvent } from 'app/types/events';
+import { StoreState } from 'app/types/store';
 
 import OrgProfile from './OrgProfile';
 import { loadOrganization, updateOrganization } from './state/actions';
 import { setOrganizationName } from './state/reducers';
 
-export interface Props {
-  navModel: NavModel;
-  organization: Organization;
-  loadOrganization: typeof loadOrganization;
-  setOrganizationName: typeof setOrganizationName;
-  updateOrganization: typeof updateOrganization;
-}
+interface OwnProps {}
 
 export class OrgDetailsPage extends PureComponent<Props> {
   async componentDidMount() {
@@ -31,6 +27,21 @@ export class OrgDetailsPage extends PureComponent<Props> {
     this.props.updateOrganization();
   };
 
+  handleConfirm = () => {
+    return new Promise<boolean>((resolve) => {
+      appEvents.publish(
+        new ShowConfirmModalEvent({
+          title: t('org.org-details-page.title.confirm-preferences-update', 'Confirm preferences update'),
+          text: 'This will update the preferences for the whole organization. Are you sure you want to update the preferences?',
+          yesText: 'Save',
+          yesButtonVariant: 'primary',
+          onConfirm: async () => resolve(true),
+          onDismiss: async () => resolve(false),
+        })
+      );
+    });
+  };
+
   render() {
     const { navModel, organization } = this.props;
     const isLoading = Object.keys(organization).length === 0;
@@ -42,10 +53,17 @@ export class OrgDetailsPage extends PureComponent<Props> {
       <Page navModel={navModel}>
         <Page.Contents isLoading={isLoading}>
           {!isLoading && (
-            <VerticalGroup spacing="lg">
+            <Stack direction="column" gap={3}>
               {canReadOrg && <OrgProfile onSubmit={this.onUpdateOrganization} orgName={organization.name} />}
-              {canReadPreferences && <SharedPreferences resourceUri="org" disabled={!canWritePreferences} />}
-            </VerticalGroup>
+              {canReadPreferences && (
+                <SharedPreferences
+                  resourceUri="org"
+                  disabled={!canWritePreferences}
+                  preferenceType="org"
+                  onConfirm={this.handleConfirm}
+                />
+              )}
+            </Stack>
           )}
         </Page.Contents>
       </Page>
@@ -66,4 +84,7 @@ const mapDispatchToProps = {
   updateOrganization,
 };
 
-export default connect(mapStateToProps, mapDispatchToProps)(OrgDetailsPage);
+const connector = connect(mapStateToProps, mapDispatchToProps);
+export type Props = OwnProps & ConnectedProps<typeof connector>;
+
+export default connector(OrgDetailsPage);
