@@ -2,14 +2,16 @@ import { useEffect, useState } from 'react';
 import { useLocation } from 'react-router-dom-v5-compat';
 
 import { AppEvents } from '@grafana/data';
+import { t, Trans } from '@grafana/i18n';
 import { config, locationService, reportInteraction } from '@grafana/runtime';
-import { Button, ConfirmModal, Stack } from '@grafana/ui';
+import { Button, ConfirmModal, LinkButton, Stack } from '@grafana/ui';
 import appEvents from 'app/core/app_events';
-import configCore from 'app/core/config';
 import { useQueryParams } from 'app/core/hooks/useQueryParams';
 import { removePluginFromNavTree } from 'app/core/reducers/navBarTree';
-import { useDispatch } from 'app/types';
+import { isOpenSourceBuildOrUnlicenced } from 'app/features/admin/EnterpriseAuthFeaturesCard';
+import { useDispatch } from 'app/types/store';
 
+import { getExternalManageLink, isDisabledAngularPlugin } from '../../helpers';
 import {
   useInstallStatus,
   useUninstallStatus,
@@ -55,6 +57,8 @@ export function InstallControlsButton({
     plugin_id: plugin.id,
     plugin_type: plugin.type,
     path: location.pathname,
+    creator_team: 'grafana_plugins_catalog',
+    schema_version: '1.0.0',
   };
 
   useEffect(() => {
@@ -70,7 +74,7 @@ export function InstallControlsButton({
     const result = await install(plugin.id, latestCompatibleVersion?.version);
     if (!errorInstalling && !('error' in result)) {
       let successMessage = `Installed ${plugin.name}`;
-      if (config.pluginAdminExternalManageEnabled && configCore.featureToggles.managedPluginsInstall) {
+      if (config.pluginAdminExternalManageEnabled) {
         successMessage = 'Install requested, this may take a few minutes.';
       }
 
@@ -96,7 +100,7 @@ export function InstallControlsButton({
       }
 
       let successMessage = `Uninstalled ${plugin.name}`;
-      if (config.pluginAdminExternalManageEnabled && configCore.featureToggles.managedPluginsInstall) {
+      if (config.pluginAdminExternalManageEnabled) {
         successMessage = 'Uninstall requested, this may take a few minutes.';
       }
 
@@ -109,42 +113,72 @@ export function InstallControlsButton({
   };
 
   const onUpdate = async () => {
-    reportInteraction(PLUGIN_UPDATE_INTERACTION_EVENT_NAME);
+    reportInteraction(PLUGIN_UPDATE_INTERACTION_EVENT_NAME, trackingProps);
 
-    await install(plugin.id, latestCompatibleVersion?.version, true);
+    await install(plugin.id, latestCompatibleVersion?.version, PluginStatus.UPDATE);
     if (!errorInstalling) {
       appEvents.emit(AppEvents.alertSuccess, [`Updated ${plugin.name}`]);
     }
   };
 
-  let disableUninstall =
-    config.pluginAdminExternalManageEnabled && configCore.featureToggles.managedPluginsInstall
-      ? plugin.isUninstallingFromInstance
-      : isUninstalling;
+  let disableUninstall = shouldDisableUninstall(isUninstalling, plugin) ?? false;
+  const uninstallTooltip = isDisabledAngularPlugin(plugin)
+    ? 'To uninstall this plugin, upgrade to a compatible version first, then uninstall it.'
+    : '';
+
   let uninstallTitle = '';
   if (plugin.isPreinstalled.found) {
     disableUninstall = true;
     uninstallTitle = 'Preinstalled plugin. Remove from Grafana config before uninstalling.';
   }
 
+  const uninstallControls = (
+    <>
+      <ConfirmModal
+        isOpen={isConfirmModalVisible}
+        title={t('plugins.install-controls-button.title-uninstall-modal', 'Uninstall {{plugin}}', {
+          plugin: plugin.name,
+        })}
+        body={t(
+          'plugins.install-controls-button.uninstall-controls.body-uninstall-plugin',
+          'Are you sure you want to uninstall this plugin?'
+        )}
+        confirmText={t('plugins.install-controls-button.uninstall-controls.confirmText-confirm', 'Confirm')}
+        icon="exclamation-triangle"
+        onConfirm={onUninstall}
+        onDismiss={hideConfirmModal}
+      />
+      <Button
+        variant="destructive"
+        disabled={disableUninstall}
+        onClick={showConfirmModal}
+        title={uninstallTitle}
+        tooltip={uninstallTooltip}
+      >
+        {uninstallBtnText}
+      </Button>
+    </>
+  );
+
   if (pluginStatus === PluginStatus.UNINSTALL) {
     return (
-      <>
-        <ConfirmModal
-          isOpen={isConfirmModalVisible}
-          title={`Uninstall ${plugin.name}`}
-          body="Are you sure you want to uninstall this plugin?"
-          confirmText="Confirm"
-          icon="exclamation-triangle"
-          onConfirm={onUninstall}
-          onDismiss={hideConfirmModal}
-        />
-        <Stack alignItems="flex-start" width="auto" height="auto">
-          <Button variant="destructive" disabled={disableUninstall} onClick={showConfirmModal} title={uninstallTitle}>
-            {uninstallBtnText}
-          </Button>
-        </Stack>
-      </>
+      <Stack alignItems="flex-start" width="auto" height="auto">
+        {uninstallControls}
+      </Stack>
+    );
+  }
+
+  // Show learn more button for an enterprise plugin if your on OSS
+  if (plugin.isEnterprise && isOpenSourceBuildOrUnlicenced()) {
+    return (
+      <LinkButton
+        href={`${getExternalManageLink(plugin.id)}?utm_source=grafana_catalog_learn_more`}
+        target="_blank"
+        rel="noopener noreferrer"
+        icon="external-link-alt"
+      >
+        <Trans i18nKey="plugins.install-controls-warning.learn-more">Learn more</Trans>
+      </LinkButton>
     );
   }
 
@@ -154,28 +188,41 @@ export function InstallControlsButton({
   }
 
   if (pluginStatus === PluginStatus.UPDATE) {
-    const disableUpdate =
-      config.pluginAdminExternalManageEnabled && configCore.featureToggles.managedPluginsInstall
-        ? plugin.isUpdatingFromInstance
-        : isInstalling;
+    const disableUpdate = config.pluginAdminExternalManageEnabled ? plugin.isUpdatingFromInstance : isInstalling;
 
     return (
       <Stack alignItems="flex-start" width="auto" height="auto">
         {!plugin.isManaged && !plugin.isPreinstalled.withVersion && (
           <Button disabled={disableUpdate} onClick={onUpdate}>
-            {isInstalling ? 'Updating' : 'Update'}
+            {isInstalling
+              ? t('plugins.install-controls.updating', 'Updating')
+              : t('plugins.install-controls.update', 'Update')}
           </Button>
         )}
-        <Button variant="destructive" disabled={disableUninstall} onClick={onUninstall} title={uninstallTitle}>
-          {uninstallBtnText}
-        </Button>
+        {uninstallControls}
       </Stack>
     );
   }
-  const shouldDisable = isInstalling || errorInstalling || (!config.angularSupportEnabled && plugin.angularDetected);
+
+  const shouldDisable = isInstalling || errorInstalling || plugin.angularDetected;
+
   return (
     <Button disabled={shouldDisable} onClick={onInstall}>
-      {isInstalling ? 'Installing' : 'Install'}
+      {isInstalling
+        ? t('plugins.install-controls.installing', 'Installing')
+        : t('plugins.install-controls.install', 'Install')}
     </Button>
   );
 }
+
+function shouldDisableUninstall(isUninstalling: boolean, plugin: CatalogPlugin) {
+  if (isDisabledAngularPlugin(plugin)) {
+    return true;
+  }
+
+  if (config.pluginAdminExternalManageEnabled) {
+    return plugin.isUninstallingFromInstance || !plugin.isFullyInstalled || plugin.isUpdatingFromInstance;
+  }
+
+  return isUninstalling;
+}
