@@ -74,16 +74,12 @@ export interface Screenshots {
 export interface CatalogPluginDetails {
   readme?: string;
   versions?: Version[];
-  links: Array<{
-    name: string;
-    url: string;
-  }>;
+  links: Array<{ name: string; url: string }>;
   grafanaDependency?: string;
   pluginDependencies?: PluginDependencies['plugins'];
   statusContext?: string;
   iam?: IdentityAccessManagement;
   changelog?: string;
-  lastCommitDate?: string;
   licenseUrl?: string;
   documentationUrl?: string;
   sponsorshipUrl?: string;
@@ -95,10 +91,7 @@ export interface CatalogPluginDetails {
 }
 
 export interface CatalogPluginInfo {
-  logos: {
-    large: string;
-    small: string;
-  };
+  logos: { large: string; small: string };
   keywords: string[];
 }
 
@@ -115,13 +108,7 @@ export type RemotePlugin = {
   json?: {
     dependencies: PluginDependencies;
     iam?: IdentityAccessManagement;
-    info: {
-      links: Array<{
-        name: string;
-        url: string;
-      }>;
-      screenshots?: Screenshots[] | null;
-    };
+    info: { links: Array<{ name: string; url: string }>; screenshots?: Screenshots[] | null };
   };
   links: Array<{ rel: string; href: string }>;
   name: string;
@@ -129,12 +116,7 @@ export type RemotePlugin = {
   orgName: string;
   orgSlug: string;
   orgUrl: string;
-  packages: {
-    [arch: string]: {
-      packageName: string;
-      downloadUrl: string;
-    };
-  };
+  packages: { [arch: string]: { packageName: string; downloadUrl: string } };
   popularity: number;
   readme?: string;
   signatureType: PluginSignatureType | '';
@@ -154,7 +136,6 @@ export type RemotePlugin = {
   versionSignedByOrgName: string;
   versionStatus: string;
   angularDetected?: boolean;
-  lastCommitDate?: string;
   licenseUrl?: string;
   documentationUrl?: string;
   sponsorshipUrl?: string;
@@ -184,16 +165,10 @@ export type LocalPlugin = WithAccessControlMetadata & {
     author: Rel;
     description: string;
     links?: Rel[];
-    logos: {
-      small: string;
-      large: string;
-    };
+    logos: { small: string; large: string };
     keywords: string[];
     build: Build;
-    screenshots?: Array<{
-      path: string;
-      name: string;
-    }> | null;
+    screenshots?: Array<{ path: string; name: string }> | null;
     version: string;
     updated: string;
   };
@@ -255,11 +230,7 @@ export interface Org {
   avatarUrl: string;
 }
 
-export type CatalogPluginsState = {
-  loading: boolean;
-  error?: Error;
-  plugins: CatalogPlugin[];
-};
+export type CatalogPluginsState = { loading: boolean; error?: Error; plugins: CatalogPlugin[] };
 
 export enum PluginStatus {
   INSTALL = 'INSTALL',
@@ -300,10 +271,7 @@ export enum RequestStatus {
   Fulfilled = 'Fulfilled',
   Rejected = 'Rejected',
 }
-export type RemotePluginResponse = {
-  plugins: RemotePlugin[];
-  error?: Error;
-};
+export type RemotePluginResponse = { plugins: RemotePlugin[]; error?: Error };
 
 export type RequestInfo = {
   status: RequestStatus;
@@ -350,11 +318,6 @@ export type PluginVersion = {
   angularDetected?: boolean;
 };
 
-export type InstancePlugin = {
-  pluginSlug: string;
-  version: string;
-};
+export type InstancePlugin = { pluginSlug: string; version: string };
 
-export type ProvisionedPlugin = {
-  slug: string;
-};
+export type ProvisionedPlugin = { slug: string };
