@@ -1,11 +1,21 @@
 import { t } from '@grafana/i18n';
 
-import { RepositorySpec } from '../../../api/clients/provisioning/v0alpha1';
+import { RepositorySpec, RepositoryViewList } from '../../../api/clients/provisioning/v0alpha1';
 import { RepositoryFormData } from '../types';
 import { specToData } from '../utils/data';
 
-export function getDefaultValues(repository?: RepositorySpec): RepositoryFormData {
+export interface GetDefaultValuesOptions {
+  repository?: RepositorySpec;
+  allowedTargets?: RepositoryViewList['allowedTargets'];
+}
+
+export function getDefaultValues({
+  repository,
+  allowedTargets = ['instance', 'folder'],
+}: GetDefaultValuesOptions = {}): RepositoryFormData {
   if (!repository) {
+    const defaultTarget = allowedTargets.includes('folder') ? 'folder' : 'instance';
+
     return {
       type: 'github',
       title: t('provisioning.get-default-values.title.repository', 'Repository'),
@@ -18,7 +28,7 @@ export function getDefaultValues(repository?: RepositorySpec): RepositoryFormDat
       path: 'grafana/',
       sync: {
         enabled: false,
-        target: 'instance',
+        target: defaultTarget,
         intervalSeconds: 60,
       },
     };
