@@ -1,9 +1,8 @@
 import { useNavigate } from 'react-router-dom-v5-compat';
 
-import { Trans } from '@grafana/i18n';
-import { Alert, Button, Dropdown, Icon, Menu, Stack } from '@grafana/ui';
-import { Repository } from 'app/api/clients/provisioning/v0alpha1';
-import { useGetFrontendSettingsQuery } from 'app/api/clients/provisioning/v0alpha1/endpoints.gen';
+import { t, Trans } from '@grafana/i18n';
+import { Button, Dropdown, Icon, Menu, Stack } from '@grafana/ui';
+import { useGetFrontendSettingsQuery, Repository } from 'app/api/clients/provisioning/v0alpha1';
 
 import { CONNECT_URL, DEFAULT_REPOSITORY_TYPES } from '../constants';
 import { checkSyncSettings } from '../utils/checkSyncSettings';
@@ -18,22 +17,7 @@ export function ConnectRepositoryButton({ items }: Props) {
   const navigate = useNavigate();
   const { data: frontendSettings } = useGetFrontendSettingsQuery();
 
-  if (state.instanceConnected) {
-    return null;
-  }
-
-  if (state.maxReposReached) {
-    return (
-      <Alert title="" severity="info">
-        <Trans
-          i18nKey="provisioning.connect-repository-button.repository-limit-info-alert"
-          values={{ count: state.repoCount }}
-        >
-          Repository limit reached ({'{{count}}'})
-        </Trans>
-      </Alert>
-    );
-  }
+  const isButtonDisabled = state.instanceConnected || state.maxReposReached;
 
   const availableTypes = frontendSettings?.availableRepositoryTypes || DEFAULT_REPOSITORY_TYPES;
   const { orderedConfigs } = getOrderedRepositoryConfigs(availableTypes);
@@ -48,14 +32,24 @@ export function ConnectRepositoryButton({ items }: Props) {
                 key={config.type}
                 icon={config.icon}
                 label={config.label}
-                onClick={() => navigate(`${CONNECT_URL}/${config.type}`)}
+                onClick={() => {
+                  navigate(`${CONNECT_URL}/${config.type}`);
+                }}
               />
             );
           })}
         </Menu>
       }
     >
-      <Button variant="primary">
+      <Button
+        variant="primary"
+        disabled={isButtonDisabled}
+        tooltip={getConfigureRepoTooltip({
+          instanceConnected: state.instanceConnected,
+          maxReposReached: state.maxReposReached,
+          count: state.repoCount,
+        })}
+      >
         <Stack alignItems="center">
           <Trans i18nKey="provisioning.connect-repository-button.configure">Configure</Trans>
           <Icon name={'angle-down'} />
@@ -64,3 +58,32 @@ export function ConnectRepositoryButton({ items }: Props) {
     </Dropdown>
   );
 }
+
+export function getConfigureRepoTooltip({
+  instanceConnected,
+  maxReposReached,
+  count,
+}: {
+  instanceConnected: boolean;
+  maxReposReached: boolean;
+  count: number;
+}) {
+  if (instanceConnected) {
+    return t(
+      'provisioning.connect-repository-button.instance-fully-managed-tooltip',
+      'Configuration is disabled because this instance is fully managed'
+    );
+  }
+
+  if (maxReposReached) {
+    return t(
+      'provisioning.connect-repository-button.repository-limit-reached-tooltip',
+      'Repository limit reached {{count}}',
+      {
+        count,
+      }
+    );
+  }
+
+  return '';
+}
