@@ -1,7 +1,10 @@
+import { waitFor } from '@testing-library/dom';
+
 import { config, locationService } from '@grafana/runtime';
 
 import { ScopesService } from '../ScopesService';
 import { ScopesDashboardsService } from '../dashboards/ScopesDashboardsService';
+import { ScopeNavigation } from '../dashboards/types';
 
 import {
   clearNotFound,
@@ -259,6 +262,35 @@ describe('Dashboards list', () => {
     expectDashboardLength('billing-usage', 1);
   });
 
+  it('redirects to the first scope navigation if your current dashboard is not a scope navigation', async () => {
+    // Render another dashboard, which is not a scope navigation
+    const mockNavigations: ScopeNavigation[] = [
+      {
+        spec: {
+          scope: 'grafana',
+          url: '/d/dashboard1',
+        },
+        status: {
+          title: 'Dashboard 1',
+          groups: ['group1'],
+        },
+        metadata: {
+          name: 'dashboard1',
+        },
+      },
+    ];
+    fetchDashboardsSpy.mockResolvedValue(mockNavigations);
+
+    await renderDashboard();
+    expect(locationService.getLocation().pathname).toBe('/');
+
+    await updateScopes(scopesService, ['grafana']);
+    expect(locationService.getLocation().pathname).toBe('/d/dashboard1');
+    // renderDashboard defaults to home dashboard
+    expect(locationService.getLocation().pathname).not.toBe('/');
+    expect(fetchDashboardsSpy).toHaveBeenCalled();
+  });
+
   it('Shows a proper message when no scopes are selected', async () => {
     await toggleDashboards();
     expectNoDashboardsNoScopes();
@@ -276,7 +308,7 @@ describe('Dashboards list', () => {
     await updateScopes(scopesService, ['mimir']);
     await searchDashboards('unknown');
     expectDashboardsSearch();
-    expectNoDashboardsForFilter();
+    await waitFor(() => expectNoDashboardsForFilter());
 
     await clearNotFound();
     expectDashboardSearchValue('');
