@@ -18,11 +18,9 @@ import {
 import { DeepPartial } from '../../mocks/utils';
 import ResourcePickerData, { ResourcePickerQueryType } from '../../resourcePicker/resourcePickerData';
 
-import { RECENT_RESOURCES_KEY } from './ResourcePicker';
+import ResourcePicker, { RECENT_RESOURCES_KEY } from './ResourcePicker';
 import { ResourceRowGroup, ResourceRowType } from './types';
 
-import ResourcePicker from '.';
-
 jest.mock('@grafana/runtime', () => ({
   ...jest.requireActual('@grafana/runtime'),
   getTemplateSrv: () => ({
