@@ -1,4 +1,4 @@
-import React, { useMemo } from 'react';
+import { useMemo } from 'react';
 
 import { SelectableValue } from '@grafana/data';
 import { Select } from '@grafana/ui';
@@ -54,6 +54,7 @@ export function PeriodSelect({
       inputId={inputId}
       disabled={disabled}
       allowCustomValue
+      menuPlacement="top"
     />
   );
 }
