@@ -1,3 +1,5 @@
+import { TextLink } from '@grafana/ui';
+
 export interface Props {
   region: string;
 }
@@ -5,23 +7,16 @@ export interface Props {
 export const ThrottlingErrorMessage = ({ region }: Props) => (
   <p>
     Please visit the&nbsp;
-    <a
-      target="_blank"
-      rel="noreferrer"
-      className="text-link"
+    <TextLink
+      external
       href={`https://${region}.console.aws.amazon.com/servicequotas/home?region=${region}#!/services/monitoring/quotas/L-5E141212`}
     >
       AWS Service Quotas console
-    </a>
+    </TextLink>
     &nbsp;to request a quota increase or see our&nbsp;
-    <a
-      target="_blank"
-      rel="noreferrer"
-      className="text-link"
-      href="https://grafana.com/docs/grafana/latest/datasources/cloudwatch/#manage-service-quotas"
-    >
+    <TextLink external href="https://grafana.com/docs/grafana/latest/datasources/cloudwatch/#manage-service-quotas">
       documentation
-    </a>
+    </TextLink>
     &nbsp;to learn more.
   </p>
 );
