@@ -1,11 +1,12 @@
-import React from 'react';
-import { BucketAggregationEditor } from './BucketAggregationEditor';
+import { Button } from '@grafana/ui';
+
+import { BucketAggregation } from '../../../dataquery.gen';
 import { useDispatch } from '../../../hooks/useStatelessReducer';
-import { addBucketAggregation, removeBucketAggregation } from './state/actions';
-import { BucketAggregation } from './aggregations';
 import { useQuery } from '../ElasticsearchQueryContext';
 import { QueryEditorRow } from '../QueryEditorRow';
-import { IconButton } from '../../IconButton';
+
+import { BucketAggregationEditor } from './BucketAggregationEditor';
+import { addBucketAggregation, removeBucketAggregation } from './state/actions';
 
 interface Props {
   nextId: BucketAggregation['id'];
@@ -27,7 +28,14 @@ export const BucketAggregationsEditor = ({ nextId }: Props) => {
           <BucketAggregationEditor value={bucketAgg} />
 
           {index === 0 && (
-            <IconButton iconName="plus" onClick={() => dispatch(addBucketAggregation(nextId))} label="add" />
+            <Button
+              variant="secondary"
+              fill="text"
+              icon="plus"
+              onClick={() => dispatch(addBucketAggregation(nextId))}
+              tooltip="Add grouping condition"
+              aria-label="Add grouping condition"
+            />
           )}
         </QueryEditorRow>
       ))}
