@@ -1,5 +1,6 @@
+import { MetricAggregation } from 'app/plugins/datasource/elasticsearch/dataquery.gen';
+
 import { extendedStats } from '../../../../queryDef';
-import { MetricAggregation } from '../aggregations';
 
 const hasValue = (value: string) => (object: { value: string }) => object.value === value;
 
