@@ -1,15 +1,13 @@
-import { GraphiteDatasource } from './datasource';
 import { DataSourcePlugin } from '@grafana/data';
-import { ConfigEditor } from './configuration/ConfigEditor';
-import { MetricTankMetaInspector } from './components/MetricTankMetaInspector';
-import { GraphiteQueryEditor } from './components/GraphiteQueryEditor';
 
-class AnnotationsQueryCtrl {
-  static templateUrl = 'partials/annotations.editor.html';
-}
+import { GraphiteQueryEditor } from './components/GraphiteQueryEditor';
+import { GraphiteVariableEditor } from './components/GraphiteVariableEditor';
+import { MetricTankMetaInspector } from './components/MetricTankMetaInspector';
+import { ConfigEditor } from './configuration/ConfigEditor';
+import { GraphiteDatasource } from './datasource';
 
 export const plugin = new DataSourcePlugin(GraphiteDatasource)
   .setQueryEditor(GraphiteQueryEditor)
   .setConfigEditor(ConfigEditor)
-  .setMetadataInspector(MetricTankMetaInspector)
-  .setAnnotationQueryCtrl(AnnotationsQueryCtrl);
+  .setVariableQueryEditor(GraphiteVariableEditor)
+  .setMetadataInspector(MetricTankMetaInspector);
