@@ -1,23 +1,26 @@
-import { dispatch } from 'app/store/store';
+import { getTemplateSrv } from '@grafana/runtime';
+
+import { GraphiteDatasource } from '../datasource';
 import gfunc from '../gfunc';
-import { TemplateSrvStub } from 'test/specs/helpers';
-import { silenceConsoleOutput } from 'test/core/utils/silenceConsoleOutput';
 import { actions } from '../state/actions';
-import { getAltSegmentsSelectables, getTagsSelectables, getTagsAsSegmentsSelectables } from '../state/providers';
-import { GraphiteSegment } from '../types';
+import {
+  getAltSegmentsSelectables,
+  getTagsAsSegmentsSelectables,
+  getTagsSelectables,
+  getTagValuesSelectables,
+} from '../state/providers';
 import { createStore } from '../state/store';
+import { GraphiteSegment } from '../types';
 
-jest.mock('app/core/utils/promiseToDigest', () => ({
-  promiseToDigest: (scope: any) => {
-    return (p: Promise<any>) => p;
-  },
+const mockPublish = jest.fn();
+jest.mock('@grafana/runtime', () => ({
+  ...(jest.requireActual('@grafana/runtime') as unknown as object),
+  getAppEvents: () => ({
+    publish: mockPublish,
+  }),
+  // getTemplateSrv: jest.fn().mockReturnValue({ replace: jest.fn(), getVariables: jest.fn() }),
 }));
 
-jest.mock('app/store/store', () => ({
-  dispatch: jest.fn(),
-}));
-const mockDispatch = dispatch as jest.Mock;
-
 /**
  * Simulate switching to text editor, changing the query and switching back to visual editor
  */
@@ -28,23 +31,30 @@ async function changeTarget(ctx: any, target: string): Promise<void> {
   await ctx.dispatch(actions.toggleEditorMode());
 }
 
-describe('Graphite actions', async () => {
+describe('Graphite actions', () => {
   const ctx = {
-    datasource: {
-      metricFindQuery: jest.fn(() => Promise.resolve([])),
-      getFuncDefs: jest.fn(() => Promise.resolve(gfunc.getFuncDefs('1.0'))),
-      getFuncDef: gfunc.getFuncDef,
-      waitForFuncDefsLoaded: jest.fn(() => Promise.resolve(null)),
-      createFuncInstance: gfunc.createFuncInstance,
-      getTagsAutoComplete: jest.fn().mockReturnValue(Promise.resolve([])),
-    },
     target: { target: 'aliasByNode(scaleToSeconds(test.prod.*,1),2)' },
   } as any;
 
   beforeEach(async () => {
     jest.clearAllMocks();
 
-    ctx.state = null;
+    const instanceSettings = {
+      url: '/api/datasources/proxy/1',
+      name: 'graphiteProd',
+      jsonData: {
+        rollupIndicatorEnabled: true,
+      },
+    };
+    ctx.datasource = new GraphiteDatasource(instanceSettings);
+    ctx.datasource.metricFindQuery = jest.fn(() => Promise.resolve([]));
+    ctx.datasource.getFuncDefs = jest.fn(() => Promise.resolve(gfunc.getFuncDefs('1.0')));
+    ctx.datasource.getFuncDef = gfunc.getFuncDef;
+    ctx.datasource.waitForFuncDefsLoaded = jest.fn(() => Promise.resolve(null));
+    ctx.datasource.createFuncInstance = gfunc.createFuncInstance;
+    ctx.datasource.getTagsAutoComplete = jest.fn().mockReturnValue(Promise.resolve([]));
+    ctx.datasource.getTagValuesAutoComplete = jest.fn().mockReturnValue(Promise.resolve([]));
+    ctx.state = { datasource: ctx.datasource };
     ctx.dispatch = createStore((state) => {
       ctx.state = state;
     });
@@ -56,7 +66,7 @@ describe('Graphite actions', async () => {
         refresh: jest.fn(),
         queries: [],
         //@ts-ignore
-        templateSrv: new TemplateSrvStub(),
+        templateSrv: getTemplateSrv(),
       })
     );
   });
@@ -87,12 +97,6 @@ describe('Graphite actions', async () => {
       expect(ctx.datasource.metricFindQuery.mock.calls[lastCallIndex][0]).toBe('test.prod.*');
     });
 
-    it('should delete last segment if no metrics are found', () => {
-      expect(ctx.state.segments[0].value).toBe('test');
-      expect(ctx.state.segments[1].value).toBe('prod');
-      expect(ctx.state.segments[2].value).toBe('select metric');
-    });
-
     it('should parse expression and build function model', () => {
       expect(ctx.state.queryModel.functions.length).toBe(2);
     });
@@ -109,12 +113,6 @@ describe('Graphite actions', async () => {
       expect(ctx.datasource.metricFindQuery.mock.calls[lastCallIndex][0]).toBe('test.test.*');
     });
 
-    it('should delete last segment if no metrics are found', () => {
-      expect(ctx.state.segments[0].value).toBe('test');
-      expect(ctx.state.segments[1].value).toBe('test');
-      expect(ctx.state.segments[2].value).toBe('select metric');
-    });
-
     it('should parse expression and build function model', () => {
       expect(ctx.state.queryModel.functions.length).toBe(2);
     });
@@ -159,7 +157,7 @@ describe('Graphite actions', async () => {
     });
 
     it('should add 2 segments', () => {
-      expect(ctx.state.segments.length).toBe(2);
+      expect(ctx.state.segments.length).toBe(3);
     });
 
     it('should add function param', () => {
@@ -190,7 +188,7 @@ describe('Graphite actions', async () => {
     });
 
     it('should add segments', () => {
-      expect(ctx.state.segments.length).toBe(3);
+      expect(ctx.state.segments.length).toBe(4);
     });
 
     it('should have correct func params', () => {
@@ -210,8 +208,33 @@ describe('Graphite actions', async () => {
     });
   });
 
+  it('current time range and limit is passed when getting list of tags when editing', async () => {
+    const currentRange = { from: 0, to: 1 };
+    ctx.state.range = currentRange;
+    await getTagsSelectables(ctx.state, 0, 'any');
+    expect(ctx.state.datasource.getTagsAutoComplete).toHaveBeenCalledWith([], 'any', {
+      range: currentRange,
+      limit: 5000,
+    });
+  });
+
+  it('current time range and limit is passed when getting list of tags for adding', async () => {
+    const currentRange = { from: 0, to: 1 };
+    ctx.state.range = currentRange;
+    await getTagsAsSegmentsSelectables(ctx.state, 'any');
+    expect(ctx.state.datasource.getTagsAutoComplete).toHaveBeenCalledWith([], 'any', {
+      range: currentRange,
+      limit: 5000,
+    });
+  });
+
+  it('limit is passed when getting list of tag values', async () => {
+    ctx.state.templateSrv = { replace: jest.fn(), getVariables: jest.fn() };
+    ctx.datasource = await getTagValuesSelectables(ctx.state, { key: 'key', operator: '=', value: 'value' }, 1, 'test');
+    expect(ctx.state.datasource.getTagValuesAutoComplete).toHaveBeenCalledWith([], 'key', 'test', { limit: 5000 });
+  });
+
   describe('when autocomplete for metric names is not available', () => {
-    silenceConsoleOutput();
     beforeEach(() => {
       ctx.state.datasource.getTagsAutoComplete = jest.fn().mockReturnValue(Promise.resolve([]));
       ctx.state.datasource.metricFindQuery = jest.fn().mockReturnValue(
@@ -224,25 +247,22 @@ describe('Graphite actions', async () => {
     it('getAltSegmentsSelectables should handle autocomplete errors', async () => {
       await expect(async () => {
         await getAltSegmentsSelectables(ctx.state, 0, 'any');
-        expect(mockDispatch).toBeCalledWith(
-          expect.objectContaining({
-            type: 'appNotifications/notifyApp',
-          })
+        expect(mockPublish).toHaveBeenCalledWith(
+          expect.objectContaining({ payload: ['Fetching metrics failed: .'], type: 'alert-error' })
         );
       }).not.toThrow();
     });
 
     it('getAltSegmentsSelectables should display the error message only once', async () => {
       await getAltSegmentsSelectables(ctx.state, 0, 'any');
-      expect(mockDispatch.mock.calls.length).toBe(1);
+      expect(mockPublish.mock.calls.length).toBe(1);
 
       await getAltSegmentsSelectables(ctx.state, 0, 'any');
-      expect(mockDispatch.mock.calls.length).toBe(1);
+      expect(mockPublish.mock.calls.length).toBe(1);
     });
   });
 
   describe('when autocomplete for tags is not available', () => {
-    silenceConsoleOutput();
     beforeEach(() => {
       ctx.datasource.metricFindQuery = jest.fn().mockReturnValue(Promise.resolve([]));
       ctx.datasource.getTagsAutoComplete = jest.fn().mockReturnValue(
@@ -255,39 +275,35 @@ describe('Graphite actions', async () => {
     it('getTagsSelectables should handle autocomplete errors', async () => {
       await expect(async () => {
         await getTagsSelectables(ctx.state, 0, 'any');
-        expect(mockDispatch).toBeCalledWith(
-          expect.objectContaining({
-            type: 'appNotifications/notifyApp',
-          })
+        expect(mockPublish).toHaveBeenCalledWith(
+          expect.objectContaining({ payload: ['Fetching tags failed: .'], type: 'alert-error' })
         );
       }).not.toThrow();
     });
 
     it('getTagsSelectables should display the error message only once', async () => {
       await getTagsSelectables(ctx.state, 0, 'any');
-      expect(mockDispatch.mock.calls.length).toBe(1);
+      expect(mockPublish.mock.calls.length).toBe(1);
 
       await getTagsSelectables(ctx.state, 0, 'any');
-      expect(mockDispatch.mock.calls.length).toBe(1);
+      expect(mockPublish.mock.calls.length).toBe(1);
     });
 
     it('getTagsAsSegmentsSelectables should handle autocomplete errors', async () => {
       await expect(async () => {
         await getTagsAsSegmentsSelectables(ctx.state, 'any');
-        expect(mockDispatch).toBeCalledWith(
-          expect.objectContaining({
-            type: 'appNotifications/notifyApp',
-          })
+        expect(mockPublish).toHaveBeenCalledWith(
+          expect.objectContaining({ payload: ['Fetching tags failed: .'], type: 'alert-error' })
         );
       }).not.toThrow();
     });
 
     it('getTagsAsSegmentsSelectables should display the error message only once', async () => {
       await getTagsAsSegmentsSelectables(ctx.state, 'any');
-      expect(mockDispatch.mock.calls.length).toBe(1);
+      expect(mockPublish.mock.calls.length).toBe(1);
 
       await getTagsAsSegmentsSelectables(ctx.state, 'any');
-      expect(mockDispatch.mock.calls.length).toBe(1);
+      expect(mockPublish.mock.calls.length).toBe(1);
     });
   });
 
@@ -458,4 +474,49 @@ describe('Graphite actions', async () => {
       expect(ctx.state.target.target).toEqual(expected);
     });
   });
+
+  describe('when auto-completing over a large set of tags and metrics', () => {
+    const manyMetrics: Array<{ text: string }> = [],
+      max = 20000;
+
+    beforeEach(() => {
+      for (let i = 0; i < max; i++) {
+        manyMetrics.push({ text: `metric${i}` });
+      }
+      ctx.state.datasource.metricFindQuery = jest.fn().mockReturnValue(Promise.resolve(manyMetrics));
+      ctx.state.datasource.getTagsAutoComplete = jest.fn((_tag, _prefix, { limit }) => {
+        const tags = [];
+        for (let i = 0; i < limit; i++) {
+          tags.push({ text: `tag${i}` });
+        }
+        return tags;
+      });
+    });
+
+    it('uses limited metrics and tags list', async () => {
+      ctx.state.supportsTags = true;
+      ctx.state.templateSrv = { replace: jest.fn(), getVariables: jest.fn() };
+      const segments = await getAltSegmentsSelectables(ctx.state, 0, '');
+      expect(segments).toHaveLength(10000);
+      expect(segments[0].value!.value).toBe('*'); // * - is a fixed metric name, always added at the top
+      expect(segments[4999].value!.value).toBe('metric4998');
+      expect(segments[5000].value!.value).toBe('tag: tag0');
+      expect(segments[9999].value!.value).toBe('tag: tag4999');
+    });
+
+    it('uses correct limit for metrics and tags list when tags are not supported', async () => {
+      ctx.state.supportsTags = false;
+      ctx.state.templateSrv = { replace: jest.fn(), getVariables: jest.fn() };
+      const segments = await getAltSegmentsSelectables(ctx.state, 0, '');
+      expect(segments).toHaveLength(5000);
+      expect(segments[0].value!.value).toBe('*'); // * - is a fixed metric name, always added at the top
+      expect(segments[4999].value!.value).toBe('metric4998');
+    });
+
+    it('uses limited metrics when adding more metrics', async () => {
+      ctx.state.templateSrv = { replace: jest.fn(), getVariables: jest.fn() };
+      const segments = await getAltSegmentsSelectables(ctx.state, 1, '');
+      expect(segments).toHaveLength(5000);
+    });
+  });
 });
