@@ -1,23 +1,21 @@
-import {
-  createAggregationOperation,
-  createAggregationOperationWithParam,
-} from '../../prometheus/querybuilder/shared/operationUtils';
-import { QueryBuilderOperationDef } from '../../prometheus/querybuilder/shared/types';
+import { QueryBuilderOperationDefinition, QueryBuilderOperationParamValue } from '@grafana/plugin-ui';
 
 import { binaryScalarOperations } from './binaryScalarOperations';
 import { UnwrapParamEditor } from './components/UnwrapParamEditor';
 import {
   addLokiOperation,
   addNestedQueryHandler,
+  createAggregationOperation,
+  createAggregationOperationWithParam,
   createRangeOperation,
   createRangeOperationWithGrouping,
   getLineFilterRenderer,
   labelFilterRenderer,
   pipelineRenderer,
 } from './operationUtils';
-import { LokiOperationId, LokiOperationOrder, LokiVisualQueryOperationCategory } from './types';
+import { LokiOperationId, LokiOperationOrder, lokiOperators, LokiVisualQueryOperationCategory } from './types';
 
-export function getOperationDefinitions(): QueryBuilderOperationDef[] {
+function getOperationDefinitions(): QueryBuilderOperationDefinition[] {
   const aggregations = [
     LokiOperationId.Sum,
     LokiOperationId.Min,
@@ -49,6 +47,7 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
 
   const rangeOperations = [
     createRangeOperation(LokiOperationId.Rate),
+    createRangeOperation(LokiOperationId.RateCounter),
     createRangeOperation(LokiOperationId.CountOverTime),
     createRangeOperation(LokiOperationId.SumOverTime),
     createRangeOperation(LokiOperationId.BytesRate),
@@ -67,7 +66,7 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
     ...createRangeOperationWithGrouping(LokiOperationId.QuantileOverTime),
   ];
 
-  const list: QueryBuilderOperationDef[] = [
+  const list: QueryBuilderOperationDefinition[] = [
     ...aggregations,
     ...aggregationsWithParam,
     ...rangeOperations,
@@ -88,10 +87,11 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: [],
+      toggleable: true,
       alternativesKey: 'format',
       category: LokiVisualQueryOperationCategory.Formats,
-      orderRank: LokiOperationOrder.LineFormats,
-      renderer: (model, def, innerExpr) => `${innerExpr} | json ${model.params.join(', ')}`.trim(),
+      orderRank: LokiOperationOrder.Parsers,
+      renderer: pipelineRenderer,
       addOperationHandler: addLokiOperation,
       explainHandler: () =>
         `This will extract keys and values from a [json](https://grafana.com/docs/loki/latest/logql/log_queries/#json) formatted log line as labels. The extracted labels can be used in label filter expressions and used as values for a range aggregation via the unwrap operation.`,
@@ -99,11 +99,37 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
     {
       id: LokiOperationId.Logfmt,
       name: 'Logfmt',
-      params: [],
-      defaultParams: [],
+      params: [
+        {
+          name: 'Strict',
+          type: 'boolean',
+          optional: true,
+          description:
+            'With strict parsing enabled, the logfmt parser immediately stops scanning the log line and returns early with an error when it encounters any poorly formatted key/value pair.',
+        },
+        {
+          name: 'Keep empty',
+          type: 'boolean',
+          optional: true,
+          description:
+            'The logfmt parser retains standalone keys (keys without a value) as labels with its value set to empty string. ',
+        },
+        {
+          name: 'Expression',
+          type: 'string',
+          optional: true,
+          restParam: true,
+          minWidth: 18,
+          placeholder: 'field_name',
+          description:
+            'Using expressions with your logfmt parser will extract and rename (if provided) only the specified fields to labels. You can specify one or more expressions in this way.',
+        },
+      ],
+      defaultParams: [false, false],
+      toggleable: true,
       alternativesKey: 'format',
       category: LokiVisualQueryOperationCategory.Formats,
-      orderRank: LokiOperationOrder.LineFormats,
+      orderRank: LokiOperationOrder.Parsers,
       renderer: pipelineRenderer,
       addOperationHandler: addLokiOperation,
       explainHandler: () =>
@@ -123,9 +149,10 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: [''],
+      toggleable: true,
       alternativesKey: 'format',
       category: LokiVisualQueryOperationCategory.Formats,
-      orderRank: LokiOperationOrder.LineFormats,
+      orderRank: LokiOperationOrder.Parsers,
       renderer: (model, def, innerExpr) => `${innerExpr} | regexp \`${model.params[0]}\``,
       addOperationHandler: addLokiOperation,
       explainHandler: () =>
@@ -145,9 +172,10 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: [''],
+      toggleable: true,
       alternativesKey: 'format',
       category: LokiVisualQueryOperationCategory.Formats,
-      orderRank: LokiOperationOrder.LineFormats,
+      orderRank: LokiOperationOrder.Parsers,
       renderer: (model, def, innerExpr) => `${innerExpr} | pattern \`${model.params[0]}\``,
       addOperationHandler: addLokiOperation,
       explainHandler: () =>
@@ -158,9 +186,10 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
       name: 'Unpack',
       params: [],
       defaultParams: [],
+      toggleable: true,
       alternativesKey: 'format',
       category: LokiVisualQueryOperationCategory.Formats,
-      orderRank: LokiOperationOrder.LineFormats,
+      orderRank: LokiOperationOrder.Parsers,
       renderer: pipelineRenderer,
       addOperationHandler: addLokiOperation,
       explainHandler: () =>
@@ -180,17 +209,18 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: [''],
+      toggleable: true,
       alternativesKey: 'format',
       category: LokiVisualQueryOperationCategory.Formats,
-      orderRank: LokiOperationOrder.LineFormats,
+      orderRank: LokiOperationOrder.PipeOperations,
       renderer: (model, def, innerExpr) => `${innerExpr} | line_format \`${model.params[0]}\``,
       addOperationHandler: addLokiOperation,
       explainHandler: () =>
         `This will replace log line using a specified template. The template can refer to stream labels and extracted labels.
 
-        Example: \`{{.status_code}} - {{.message}}\`
+Example: \`{{.status_code}} - {{.message}}\`
 
-        [Read the docs](https://grafana.com/docs/loki/latest/logql/log_queries/#line-format-expression) for more.
+[Read the docs](https://grafana.com/docs/loki/latest/logql/log_queries/#line-format-expression) for more.
         `,
     },
     {
@@ -201,17 +231,18 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         { name: 'Rename to', type: 'string' },
       ],
       defaultParams: ['', ''],
+      toggleable: true,
       alternativesKey: 'format',
       category: LokiVisualQueryOperationCategory.Formats,
-      orderRank: LokiOperationOrder.LineFormats,
+      orderRank: LokiOperationOrder.PipeOperations,
       renderer: (model, def, innerExpr) => `${innerExpr} | label_format ${model.params[1]}=${model.params[0]}`,
       addOperationHandler: addLokiOperation,
       explainHandler: () =>
         `This will change name of label to desired new label. In the example below, label "error_level" will be renamed to "level".
 
-        Example: error_level=\`level\`
+Example: \`\`error_level=\`level\` \`\`
 
-        [Read the docs](https://grafana.com/docs/loki/latest/logql/log_queries/#labels-format-expression) for more.
+[Read the docs](https://grafana.com/docs/loki/latest/logql/log_queries/#labels-format-expression) for more.
         `,
     },
 
@@ -220,9 +251,10 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
       name: 'Line contains',
       params: [
         {
-          name: 'String',
+          name: '',
           type: 'string',
           hideName: true,
+          restParam: true,
           placeholder: 'Text to find',
           description: 'Find log lines that contains this text',
           minWidth: 20,
@@ -230,21 +262,23 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: [''],
+      toggleable: true,
       alternativesKey: 'line filter',
       category: LokiVisualQueryOperationCategory.LineFilters,
       orderRank: LokiOperationOrder.LineFilters,
       renderer: getLineFilterRenderer('|='),
       addOperationHandler: addLokiOperation,
-      explainHandler: (op) => `Return log lines that contain string \`${op.params[0]}\`.`,
+      explainHandler: (op) => `Return log lines that contain string \`${op.params?.join('`, or `')}\`.`,
     },
     {
       id: LokiOperationId.LineContainsNot,
       name: 'Line does not contain',
       params: [
         {
-          name: 'String',
+          name: '',
           type: 'string',
           hideName: true,
+          restParam: true,
           placeholder: 'Text to exclude',
           description: 'Find log lines that does not contain this text',
           minWidth: 26,
@@ -252,21 +286,71 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: [''],
+      toggleable: true,
       alternativesKey: 'line filter',
       category: LokiVisualQueryOperationCategory.LineFilters,
       orderRank: LokiOperationOrder.LineFilters,
       renderer: getLineFilterRenderer('!='),
       addOperationHandler: addLokiOperation,
-      explainHandler: (op) => `Return log lines that does not contain string \`${op.params[0]}\`.`,
+      explainHandler: (op) => `Return log lines that does not contain string \`${op.params?.join('`, or `')}\`.`,
+    },
+    {
+      id: LokiOperationId.LineContainsCaseInsensitive,
+      name: 'Line contains case insensitive',
+      params: [
+        {
+          name: '',
+          type: 'string',
+          hideName: true,
+          restParam: true,
+          placeholder: 'Text to find',
+          description: 'Find log lines that contains this text',
+          minWidth: 33,
+          runQueryOnEnter: true,
+        },
+      ],
+      defaultParams: [''],
+      toggleable: true,
+      alternativesKey: 'line filter',
+      category: LokiVisualQueryOperationCategory.LineFilters,
+      orderRank: LokiOperationOrder.LineFilters,
+      renderer: getLineFilterRenderer('|~', true),
+      addOperationHandler: addLokiOperation,
+      explainHandler: (op) => `Return log lines that match regex \`(?i)${op.params?.join('`, or `(?i)')}\`.`,
+    },
+    {
+      id: LokiOperationId.LineContainsNotCaseInsensitive,
+      name: 'Line does not contain case insensitive',
+      params: [
+        {
+          name: '',
+          type: 'string',
+          hideName: true,
+          restParam: true,
+          placeholder: 'Text to exclude',
+          description: 'Find log lines that does not contain this text',
+          minWidth: 40,
+          runQueryOnEnter: true,
+        },
+      ],
+      defaultParams: [''],
+      toggleable: true,
+      alternativesKey: 'line filter',
+      category: LokiVisualQueryOperationCategory.LineFilters,
+      orderRank: LokiOperationOrder.LineFilters,
+      renderer: getLineFilterRenderer('!~', true),
+      addOperationHandler: addLokiOperation,
+      explainHandler: (op) => `Return log lines that does not match regex \`(?i)${op.params?.join('`, or `(?i)')}\`.`,
     },
     {
       id: LokiOperationId.LineMatchesRegex,
       name: 'Line contains regex match',
       params: [
         {
-          name: 'Regex',
+          name: '',
           type: 'string',
           hideName: true,
+          restParam: true,
           placeholder: 'Pattern to match',
           description: 'Find log lines that match this regex pattern',
           minWidth: 30,
@@ -274,21 +358,23 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: [''],
+      toggleable: true,
       alternativesKey: 'line filter',
       category: LokiVisualQueryOperationCategory.LineFilters,
       orderRank: LokiOperationOrder.LineFilters,
       renderer: getLineFilterRenderer('|~'),
       addOperationHandler: addLokiOperation,
-      explainHandler: (op) => `Return log lines that match regex \`${op.params[0]}\`.`,
+      explainHandler: (op) => `Return log lines that match a \`RE2\` regex pattern. \`${op.params?.join('`, or `')}\`.`,
     },
     {
       id: LokiOperationId.LineMatchesRegexNot,
       name: 'Line does not match regex',
       params: [
         {
-          name: 'Regex',
+          name: '',
           type: 'string',
           hideName: true,
+          restParam: true,
           placeholder: 'Pattern to exclude',
           description: 'Find log lines that does not match this regex pattern',
           minWidth: 30,
@@ -296,18 +382,25 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: [''],
+      toggleable: true,
       alternativesKey: 'line filter',
       category: LokiVisualQueryOperationCategory.LineFilters,
       orderRank: LokiOperationOrder.LineFilters,
       renderer: getLineFilterRenderer('!~'),
       addOperationHandler: addLokiOperation,
-      explainHandler: (op) => `Return log lines that does not match regex \`${op.params[0]}\`.`,
+      explainHandler: (op) =>
+        `Return log lines that doesn't match a \`RE2\` regex pattern. \`${op.params?.join('`, or `')}\`.`,
     },
     {
       id: LokiOperationId.LineFilterIpMatches,
       name: 'IP line filter expression',
       params: [
-        { name: 'Operator', type: 'string', options: ['|=', '!='] },
+        {
+          name: 'Operator',
+          type: 'string',
+          minWidth: 16,
+          options: [lokiOperators.contains, lokiOperators.doesNotContain],
+        },
         {
           name: 'Pattern',
           type: 'string',
@@ -317,6 +410,7 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: ['|=', ''],
+      toggleable: true,
       alternativesKey: 'line filter',
       category: LokiVisualQueryOperationCategory.LineFilters,
       orderRank: LokiOperationOrder.LineFilters,
@@ -328,14 +422,29 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
       id: LokiOperationId.LabelFilter,
       name: 'Label filter expression',
       params: [
-        { name: 'Label', type: 'string' },
-        { name: 'Operator', type: 'string', options: ['=', '!=', ' =~', '!~', '>', '<', '>=', '<='] },
-        { name: 'Value', type: 'string' },
+        { name: 'Label', type: 'string', minWidth: 14 },
+        {
+          name: 'Operator',
+          type: 'string',
+          minWidth: 14,
+          options: [
+            lokiOperators.equals,
+            lokiOperators.doesNotEqual,
+            lokiOperators.matchesRegex,
+            lokiOperators.doesNotMatchRegex,
+            lokiOperators.greaterThan,
+            lokiOperators.lessThan,
+            lokiOperators.greaterThanOrEqual,
+            lokiOperators.lessThanOrEqual,
+          ],
+        },
+        { name: 'Value', type: 'string', minWidth: 14 },
       ],
       defaultParams: ['', '=', ''],
+      toggleable: true,
       alternativesKey: 'label filter',
       category: LokiVisualQueryOperationCategory.LabelFilters,
-      orderRank: LokiOperationOrder.LabelFilters,
+      orderRank: LokiOperationOrder.PipeOperations,
       renderer: labelFilterRenderer,
       addOperationHandler: addLokiOperation,
       explainHandler: () => `Label expression filter allows filtering using original and extracted labels.`,
@@ -344,14 +453,20 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
       id: LokiOperationId.LabelFilterIpMatches,
       name: 'IP label filter expression',
       params: [
-        { name: 'Label', type: 'string' },
-        { name: 'Operator', type: 'string', options: ['=', '!='] },
-        { name: 'Value', type: 'string' },
+        { name: 'Label', type: 'string', minWidth: 14 },
+        {
+          name: 'Operator',
+          type: 'string',
+          minWidth: 14,
+          options: [lokiOperators.equals, lokiOperators.doesNotEqual],
+        },
+        { name: 'Value', type: 'string', minWidth: 14 },
       ],
       defaultParams: ['', '=', ''],
+      toggleable: true,
       alternativesKey: 'label filter',
       category: LokiVisualQueryOperationCategory.LabelFilters,
-      orderRank: LokiOperationOrder.LabelFilters,
+      orderRank: LokiOperationOrder.PipeOperations,
       renderer: (model, def, innerExpr) =>
         `${innerExpr} | ${model.params[0]} ${model.params[1]} ip(\`${model.params[2]}\`)`,
       addOperationHandler: addLokiOperation,
@@ -362,6 +477,7 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
       name: 'No pipeline errors',
       params: [],
       defaultParams: [],
+      toggleable: true,
       alternativesKey: 'label filter',
       category: LokiVisualQueryOperationCategory.LabelFilters,
       orderRank: LokiOperationOrder.NoErrors,
@@ -390,6 +506,7 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         },
       ],
       defaultParams: ['', ''],
+      toggleable: true,
       alternativesKey: 'format',
       category: LokiVisualQueryOperationCategory.Formats,
       orderRank: LokiOperationOrder.Unwrap,
@@ -405,12 +522,77 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
         }`;
       },
     },
+    {
+      id: LokiOperationId.Decolorize,
+      name: 'Decolorize',
+      params: [],
+      defaultParams: [],
+      toggleable: true,
+      alternativesKey: 'format',
+      category: LokiVisualQueryOperationCategory.Formats,
+      orderRank: LokiOperationOrder.PipeOperations,
+      renderer: (op, def, innerExpr) => `${innerExpr} | decolorize`,
+      addOperationHandler: addLokiOperation,
+      explainHandler: () => `This will remove ANSI color codes from log lines.`,
+    },
+    {
+      id: LokiOperationId.Drop,
+      name: 'Drop',
+      params: [
+        // As drop can support both labels (e.g. job) and expressions (e.g. job="grafana"), we
+        // use input and not LabelParamEditor.
+        {
+          name: 'Label',
+          type: 'string',
+          restParam: true,
+          optional: true,
+          minWidth: 18,
+          placeholder: 'job="grafana"',
+          description: 'Specify labels or expressions to drop.',
+        },
+      ],
+      defaultParams: [''],
+      toggleable: true,
+      alternativesKey: 'format',
+      category: LokiVisualQueryOperationCategory.Formats,
+      orderRank: LokiOperationOrder.PipeOperations,
+      renderer: pipelineRenderer,
+      addOperationHandler: addLokiOperation,
+      explainHandler: () => 'The drop expression will drop the given labels in the pipeline.',
+    },
+    {
+      id: LokiOperationId.Keep,
+      name: 'Keep',
+      params: [
+        // As keep can support both labels (e.g. job) and expressions (e.g. job="grafana"), we
+        // use input and not LabelParamEditor.
+        {
+          name: 'Label',
+          type: 'string',
+          restParam: true,
+          optional: true,
+          minWidth: 18,
+          placeholder: 'job="grafana"',
+          description: 'Specify labels or expressions to keep.',
+        },
+      ],
+      defaultParams: [''],
+      toggleable: true,
+      alternativesKey: 'format',
+      category: LokiVisualQueryOperationCategory.Formats,
+      orderRank: LokiOperationOrder.PipeOperations,
+      renderer: pipelineRenderer,
+      addOperationHandler: addLokiOperation,
+      explainHandler: () =>
+        'The keep expression will keep only the specified labels in the pipeline and drop all the other labels.',
+    },
     ...binaryScalarOperations,
     {
       id: LokiOperationId.NestedQuery,
       name: 'Binary operation with query',
       params: [],
       defaultParams: [],
+      toggleable: true,
       category: LokiVisualQueryOperationCategory.BinaryOps,
       renderer: (model, def, innerExpr) => innerExpr,
       addOperationHandler: addNestedQueryHandler,
@@ -419,3 +601,35 @@ export function getOperationDefinitions(): QueryBuilderOperationDef[] {
 
   return list;
 }
+
+// Keeping a local copy as an optimization measure.
+export const operationDefinitions = getOperationDefinitions();
+
+/**
+ * Given an operator, return the corresponding explain.
+ * For usage within the Query Editor.
+ */
+export function explainOperator(id: LokiOperationId | string): string {
+  const definition = operationDefinitions.find((operation) => operation.id === id);
+
+  const explain = definition?.explainHandler?.({ id: '', params: ['<value>'] }) || '';
+
+  // Strip markdown links
+  return explain.replace(/\[(.*)\]\(.*\)/g, '$1');
+}
+
+export function getDefinitionById(id: string): QueryBuilderOperationDefinition | undefined {
+  return operationDefinitions.find((x) => x.id === id);
+}
+
+export function checkParamsAreValid(
+  def: QueryBuilderOperationDefinition,
+  params: QueryBuilderOperationParamValue[]
+): boolean {
+  // For now we only check if the operation has all the required params.
+  if (params.length < def.params.filter((param) => !param.optional).length) {
+    return false;
+  }
+
+  return true;
+}
