@@ -1,24 +1,27 @@
+import { v4 as uuidv4 } from 'uuid';
+
 import { DataSourceInstanceSettings, ScopedVars } from '@grafana/data';
+import { LanguageDefinition } from '@grafana/plugin-ui';
 import { TemplateSrv } from '@grafana/runtime';
-import { AGGREGATE_FNS } from 'app/features/plugins/sql/constants';
-import { SqlDatasource } from 'app/features/plugins/sql/datasource/SqlDatasource';
 import {
+  COMMON_FNS,
   DB,
-  LanguageCompletionProvider,
-  ResponseParser,
+  FuncParameter,
+  MACRO_FUNCTIONS,
   SQLQuery,
   SQLSelectableValue,
-} from 'app/features/plugins/sql/types';
+  SqlDatasource,
+  formatSQL,
+} from '@grafana/sql';
 
-import { getSchema, showDatabases, getSchemaAndName } from './MSSqlMetaQuery';
+import { getSchema, getSchemaAndName, showDatabases } from './MSSqlMetaQuery';
 import { MSSqlQueryModel } from './MSSqlQueryModel';
-import { MSSqlResponseParser } from './response_parser';
 import { fetchColumns, fetchTables, getSqlCompletionProvider } from './sqlCompletionProvider';
 import { getIcon, getRAQBType, toRawSql } from './sqlUtil';
 import { MssqlOptions } from './types';
 
 export class MssqlDatasource extends SqlDatasource {
-  completionProvider: LanguageCompletionProvider | undefined = undefined;
+  sqlLanguageDefinition: LanguageDefinition | undefined = undefined;
   constructor(instanceSettings: DataSourceInstanceSettings<MssqlOptions>) {
     super(instanceSettings);
   }
@@ -27,19 +30,15 @@ export class MssqlDatasource extends SqlDatasource {
     return new MSSqlQueryModel(target, templateSrv, scopedVars);
   }
 
-  getResponseParser(): ResponseParser {
-    return new MSSqlResponseParser();
-  }
-
   async fetchDatasets(): Promise<string[]> {
     const datasets = await this.runSql<{ name: string[] }>(showDatabases(), { refId: 'datasets' });
-    return datasets.fields.name.values.toArray().flat();
+    return datasets.fields.name?.values.flat() ?? [];
   }
 
   async fetchTables(dataset?: string): Promise<string[]> {
     // We get back the table name with the schema as well. like dbo.table
     const tables = await this.runSql<{ schemaAndName: string[] }>(getSchemaAndName(dataset), { refId: 'tables' });
-    return tables.fields.schemaAndName.values.toArray().flat();
+    return tables.fields.schemaAndName?.values.flat() ?? [];
   }
 
   async fetchFields(query: SQLQuery): Promise<SQLSelectableValue[]> {
@@ -48,35 +47,52 @@ export class MssqlDatasource extends SqlDatasource {
     }
     const [_, table] = query.table.split('.');
     const schema = await this.runSql<{ column: string; type: string }>(getSchema(query.dataset, table), {
-      refId: 'columns',
+      refId: `columns-${uuidv4()}`,
     });
     const result: SQLSelectableValue[] = [];
     for (let i = 0; i < schema.length; i++) {
-      const column = schema.fields.column.values.get(i);
-      const type = schema.fields.type.values.get(i);
+      const column = schema.fields.column.values[i];
+      const type = schema.fields.type.values[i];
       result.push({ label: column, value: column, type, icon: getIcon(type), raqbFieldType: getRAQBType(type) });
     }
     return result;
   }
 
-  getSqlCompletionProvider(db: DB): LanguageCompletionProvider {
-    if (this.completionProvider !== undefined) {
-      return this.completionProvider;
+  getSqlLanguageDefinition(db: DB): LanguageDefinition {
+    if (this.sqlLanguageDefinition !== undefined) {
+      return this.sqlLanguageDefinition;
     }
     const args = {
       getColumns: { current: (query: SQLQuery) => fetchColumns(db, query) },
       getTables: { current: (dataset?: string) => fetchTables(db, dataset) },
     };
-    this.completionProvider = getSqlCompletionProvider(args);
-    return this.completionProvider;
+    this.sqlLanguageDefinition = {
+      id: 'sql',
+      completionProvider: getSqlCompletionProvider(args),
+      formatter: formatSQL,
+    };
+    return this.sqlLanguageDefinition;
   }
 
+  getFunctions = (): ReturnType<DB['functions']> => {
+    const columnParam: FuncParameter = {
+      name: 'Column',
+      required: true,
+      options: (query) => this.fetchFields(query),
+    };
+
+    return [...MACRO_FUNCTIONS(columnParam), ...COMMON_FNS.map((fn) => ({ ...fn, parameters: [columnParam] }))];
+  };
+
   getDB(): DB {
+    if (this.db !== undefined) {
+      return this.db;
+    }
     return {
       init: () => Promise.resolve(true),
       datasets: () => this.fetchDatasets(),
       tables: (dataset?: string) => this.fetchTables(dataset),
-      getSqlCompletionProvider: () => this.getSqlCompletionProvider(this.db),
+      getEditorLanguageDefinition: () => this.getSqlLanguageDefinition(this.db),
       fields: async (query: SQLQuery) => {
         if (!query?.dataset || !query?.table) {
           return [];
@@ -86,12 +102,13 @@ export class MssqlDatasource extends SqlDatasource {
       validateQuery: (query) =>
         Promise.resolve({ isError: false, isValid: true, query, error: '', rawSql: query.rawSql }),
       dsID: () => this.id,
-      dispose: (dsID?: string) => {},
+      dispose: (_dsID?: string) => {},
       toRawSql,
+      functions: () => this.getFunctions(),
       lookup: async (path?: string) => {
         if (!path) {
           const datasets = await this.fetchDatasets();
-          return datasets.map((d) => ({ name: d, completion: d }));
+          return datasets.map((d) => ({ name: d, completion: `${d}.` }));
         } else {
           const parts = path.split('.').filter((s: string) => s);
           if (parts.length > 2) {
@@ -105,7 +122,6 @@ export class MssqlDatasource extends SqlDatasource {
           }
         }
       },
-      functions: async () => AGGREGATE_FNS,
     };
   }
 }
