@@ -1,16 +1,17 @@
 import { groupBy } from 'lodash';
-import { EMPTY, forkJoin, from, lastValueFrom, merge, Observable, of } from 'rxjs';
+import { EMPTY, from, merge, Observable, of } from 'rxjs';
 import { catchError, concatMap, finalize, map, mergeMap, toArray } from 'rxjs/operators';
-import semver from 'semver';
 
 import {
   CoreApp,
   DataFrame,
   DataFrameDTO,
+  DataFrameJSON,
   DataLink,
   DataQueryRequest,
   DataQueryResponse,
   DataQueryResponseData,
+  DataSourceGetTagKeysOptions,
   DataSourceGetTagValuesOptions,
   DataSourceInstanceSettings,
   dateTime,
@@ -21,6 +22,7 @@ import {
   ScopedVars,
   SelectableValue,
   TestDataSourceResponse,
+  TimeRange,
   urlUtil,
 } from '@grafana/data';
 import { NodeGraphOptions, SpanBarOptions, TraceToLogsOptions } from '@grafana/o11y-ds-frontend';
@@ -36,7 +38,7 @@ import {
 } from '@grafana/runtime';
 import { BarGaugeDisplayMode, TableCellDisplayMode, VariableFormatID } from '@grafana/schema';
 
-import { getTagWithoutScope, interpolateFilters } from './SearchTraceQLEditor/utils';
+import { interpolateFilters } from './SearchTraceQLEditor/utils';
 import { TempoVariableQuery, TempoVariableQueryType } from './VariableQueryEditor';
 import { PrometheusDatasource, PromQuery } from './_importedDependencies/datasources/prometheus/types';
 import { TagLimitOptions } from './configuration/TagLimitSettings';
@@ -83,10 +85,6 @@ export const featuresToTempoVersion = {
   [FeatureName.metricsStreaming]: '2.7.0',
 };
 
-// The version that we use as default in case we cannot retrieve it from the backend.
-// This is the last minor version of Tempo that does not expose the endpoint for build information.
-const defaultTempoVersion = '2.1.0';
-
 interface ServiceMapQueryResponse {
   nodes: DataFrame;
   edges: DataFrame;
@@ -112,7 +110,6 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
   tracesToLogs?: TraceToLogsOptions;
   serviceMap?: {
     datasourceUid?: string;
-    histogramType?: 'classic' | 'native' | 'both';
   };
   search?: {
     hide?: boolean;
@@ -134,8 +131,7 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
     metrics?: boolean;
   };
 
-  // The version of Tempo running on the backend. `null` if we cannot retrieve it for whatever reason
-  tempoVersion?: string | null;
+  timeRangeForTags?: number;
 
   constructor(
     public instanceSettings: DataSourceInstanceSettings<TempoJsonData>,
@@ -149,7 +145,7 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
     this.nodeGraph = instanceSettings.jsonData.nodeGraph;
     this.traceQuery = instanceSettings.jsonData.traceQuery;
     this.streamingEnabled = instanceSettings.jsonData.streamingEnabled;
-
+    this.timeRangeForTags = instanceSettings.jsonData.timeRangeForTags;
     this.languageProvider = new TempoLanguageProvider(this);
 
     if (!this.search?.filters) {
@@ -170,7 +166,7 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
     this.variables = new TempoVariableSupport(this);
   }
 
-  async executeVariableQuery(query: TempoVariableQuery) {
+  async executeVariableQuery(query: TempoVariableQuery, range?: TimeRange) {
     // Avoid failing if the user did not select the query type (label names, label values, etc.)
     if (query.type === undefined) {
       return new Promise<Array<{ text: string }>>(() => []);
@@ -178,10 +174,10 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
 
     switch (query.type) {
       case TempoVariableQueryType.LabelNames: {
-        return await this.labelNamesQuery();
+        return await this.labelNamesQuery(range);
       }
       case TempoVariableQueryType.LabelValues: {
-        return this.labelValuesQuery(query.label);
+        return this.labelValuesQuery(query.label, range);
       }
       default: {
         throw Error('Invalid query type: ' + query.type);
@@ -189,48 +185,48 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
     }
   }
 
-  async labelNamesQuery(): Promise<Array<{ text: string }>> {
-    await this.languageProvider.fetchTags();
+  async labelNamesQuery(range?: TimeRange): Promise<Array<{ text: string }>> {
+    await this.languageProvider.start(range, this.timeRangeForTags);
     const tags = this.languageProvider.getAutocompleteTags();
     return tags.filter((tag) => tag !== undefined).map((tag) => ({ text: tag }));
   }
 
-  async labelValuesQuery(labelName?: string): Promise<Array<{ text: string }>> {
+  async labelValuesQuery(labelName?: string, range?: TimeRange): Promise<Array<{ text: string }>> {
     if (!labelName) {
       return [];
     }
 
-    let options;
-    try {
-      // Retrieve the scope of the tag
-      // Example: given `http.status_code`, we want scope `span`
-      // Note that we ignore possible name clashes, e.g., `http.status_code` in both `span` and `resource`
-      const scope: string | undefined = (this.languageProvider.tagsV2 || [])
-        // flatten the Scope objects
-        .flatMap((tagV2) => tagV2.tags.map((tag) => ({ scope: tagV2.name, name: tag })))
-        // find associated scope
-        .find((tag) => tag.name === labelName)?.scope;
-      if (!scope) {
-        throw Error(`Scope for tag ${labelName} not found`);
-      }
+    await this.languageProvider.start(range, this.timeRangeForTags);
 
-      // For V2, we need to send scope and tag name, e.g. `span.http.status_code`,
-      // unless the tag has intrinsic scope
-      const scopeAndTag = scope === 'intrinsic' ? labelName : `${scope}.${labelName}`;
-      options = await this.languageProvider.getOptionsV2(scopeAndTag);
-    } catch {
-      // For V1, the tag name (e.g. `http.status_code`) is enough
-      options = await this.languageProvider.getOptionsV1(labelName);
+    // Retrieve the scope of the tag
+    // Example: given `http.status_code`, we want scope `span`
+    // Note that we ignore possible name clashes, e.g., `http.status_code` in both `span` and `resource`
+    const scope: string | undefined = (this.languageProvider.tagsV2 || [])
+      // flatten the Scope objects
+      .flatMap((tagV2) => tagV2.tags.map((tag) => ({ scope: tagV2.name, name: tag })))
+      // find associated scope
+      .find((tag) => tag.name === labelName)?.scope;
+    if (!scope) {
+      throw Error(`Scope for tag ${labelName} not found`);
     }
 
+    // For V2, we need to send scope and tag name, e.g. `span.http.status_code`,
+    // unless the tag has intrinsic scope
+    const scopeAndTag = scope === 'intrinsic' ? labelName : `${scope}.${labelName}`;
+    const options = await this.languageProvider.getOptionsV2({
+      tag: scopeAndTag,
+      timeRangeForTags: this.timeRangeForTags,
+      range,
+    });
+
     return options.flatMap((option: SelectableValue<string>) =>
       option.value !== undefined ? [{ text: option.value }] : []
     );
   }
 
   // Allows to retrieve the list of tags for ad-hoc filters
-  async getTagKeys(): Promise<Array<{ text: string }>> {
-    await this.languageProvider.fetchTags();
+  async getTagKeys(options: DataSourceGetTagKeysOptions<TempoQuery>): Promise<Array<{ text: string }>> {
+    await this.languageProvider.fetchTags(this.timeRangeForTags, options?.timeRange ?? undefined);
     const tags = this.languageProvider.tagsV2 || [];
     return tags
       .map(({ name, tags }) =>
@@ -243,56 +239,68 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
   // Allows to retrieve the list of tag values for ad-hoc filters
   getTagValues(options: DataSourceGetTagValuesOptions<TempoQuery>): Promise<Array<{ text: string }>> {
     const query = this.languageProvider.generateQueryFromFilters({ adhocFilters: options.filters });
-    return this.tagValuesQuery(options.key, query);
+    return this.tagValuesQuery(options.key, query, options?.timeRange ?? undefined);
   }
 
-  async tagValuesQuery(tag: string, query: string): Promise<Array<{ text: string }>> {
-    let options;
-    try {
-      // For V2, we need to send scope and tag name, e.g. `span.http.status_code`,
-      // unless the tag has intrinsic scope
-      options = await this.languageProvider.getOptionsV2(tag, query);
-    } catch {
-      // For V1, the tag name (e.g. `http.status_code`) is enough
-      options = await this.languageProvider.getOptionsV1(getTagWithoutScope(tag));
-    }
+  async tagValuesQuery(tag: string, query: string, range?: TimeRange): Promise<Array<{ text: string }>> {
+    // For V2, we need to send scope and tag name, e.g. `span.http.status_code`,
+    // unless the tag has intrinsic scope
+    const options = await this.languageProvider.getOptionsV2({
+      tag,
+      query,
+      timeRangeForTags: this.timeRangeForTags,
+      range,
+    });
 
     return options.flatMap((option: SelectableValue<string>) =>
       option.value !== undefined ? [{ text: option.value }] : []
     );
   }
 
-  init = async () => {
-    const response = await lastValueFrom(
-      this._request('/api/status/buildinfo').pipe(
-        map((response) => response),
-        catchError((error) => {
-          console.error('Failure in retrieving build information', error?.data?.message);
-          return of({ error, data: { version: null } }); // unknown version
-        })
-      )
-    );
-    this.tempoVersion = response.data.version;
-  };
+  // TODO: Implement this function in Prometheus datasource https://github.com/grafana/grafana/issues/109706
+  async getNativeHistograms(timeRange?: TimeRange): Promise<boolean> {
+    if (!this.serviceMap?.datasourceUid) {
+      return false;
+    }
 
-  /**
-   * Check, for the given feature, whether it is available in Grafana.
-   *
-   * The check is done based on the version of the Tempo instance running on the backend and
-   * the minimum version required by the given feature to work.
-   *
-   * @param featureName - the name of the feature to consider
-   * @return true if the feature is available, false otherwise
-   */
-  isFeatureAvailable(featureName: FeatureName) {
-    // We know for old Tempo instances we don't know their version, so resort to default
-    const actualVersion = this.tempoVersion ?? defaultTempoVersion;
+    // remove _bucket from the metric name to get the native histogram metric name
+    const metricName = histogramMetric.replace('_bucket', '');
 
     try {
-      return semver.gte(actualVersion, featuresToTempoVersion[featureName]);
-    } catch {
-      // We assume we are on a development and recent branch, thus we enable all features
-      return true;
+      // Get the Prometheus datasource instance
+      const promDs = await getDataSourceSrv().get(this.serviceMap.datasourceUid);
+      // Use provided time range or default to last hour
+      const from = timeRange?.from || dateTime().subtract(1, 'hour');
+      const to = timeRange?.to || dateTime();
+
+      // Convert to Unix timestamps (seconds since epoch)
+      const start = Math.floor(from.valueOf() / 1000);
+      const end = Math.floor(to.valueOf() / 1000);
+
+      // Use the series endpoint to check if native histogram metrics exist
+      // this has a 90% chance of returning correctly due to sparse data
+      if (!('metadataRequest' in promDs) || typeof promDs.metadataRequest !== 'function') {
+        return false;
+      }
+
+      const seriesResult = await promDs.metadataRequest('/api/v1/series', {
+        'match[]': metricName,
+        limit: 1,
+        start: start,
+        end: end,
+      });
+
+      // Check if any native histogram series exist
+      const seriesData = seriesResult?.data?.data;
+      if (seriesData && Array.isArray(seriesData)) {
+        // If the series array has any entries, native histograms exist
+        return seriesData.length > 0;
+      }
+
+      return false;
+    } catch (error) {
+      console.warn('Failed to check for native histograms:', error);
+      return false;
     }
   }
 
@@ -362,6 +370,7 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
       }
     }
 
+    // TraceQL
     if (targets.traceql?.length) {
       try {
         const appliedQuery = this.applyVariables(targets.traceql[0], options.scopedVars);
@@ -378,14 +387,19 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
           subQueries.push(this.handleTraceIdQuery(options, targets.traceql, queryValue));
         } else {
           if (this.isTraceQlMetricsQuery(queryValue)) {
+            const useStreaming =
+              this.isStreamingMetricsEnabled() &&
+              options.app !== CoreApp.CloudAlerting &&
+              options.app !== CoreApp.UnifiedAlerting;
+
             reportInteraction('grafana_traces_traceql_metrics_queried', {
               datasourceType: 'tempo',
               app: options.app ?? '',
               grafana_version: config.buildInfo.version,
               query: queryValue ?? '',
-              streaming: this.isStreamingMetricsEnabled(),
+              streaming: useStreaming,
             });
-            if (this.isStreamingMetricsEnabled()) {
+            if (useStreaming) {
               subQueries.push(this.handleMetricsStreamingQuery(options, targets.traceql, queryValue));
             } else {
               subQueries.push(this.handleTraceQlMetricsQuery(options, targets.traceql, queryValue));
@@ -398,7 +412,16 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
               query: queryValue ?? '',
               streaming: this.isStreamingSearchEnabled(),
             });
-            subQueries.push(this.handleTraceQlQuery(options, targets, queryValue));
+
+            if (this.isStreamingSearchEnabled()) {
+              return this.handleStreamingQuery(options, targets.traceql, queryValue);
+            }
+
+            if (config.featureToggles.tempoSearchBackendMigration) {
+              subQueries.push(this.handleTraceQlQuery(options, targets));
+            } else {
+              subQueries.push(this.oldSearchQueryLogic(options, targets, queryValue));
+            }
           }
         }
       } catch (error) {
@@ -406,6 +429,7 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
       }
     }
 
+    // Search
     if (targets.traceqlSearch?.length) {
       if (targets.traceqlSearch[0].groupBy) {
         return of({
@@ -437,44 +461,11 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
           if (this.isStreamingSearchEnabled()) {
             subQueries.push(this.handleStreamingQuery(options, traceqlSearchTargets, queryFromFilters));
           } else {
-            const startTime = performance.now();
-            subQueries.push(
-              this._request('/api/search', {
-                q: queryFromFilters,
-                limit: options.targets[0].limit ?? DEFAULT_LIMIT,
-                spss: options.targets[0].spss ?? DEFAULT_SPSS,
-                start: options.range.from.unix(),
-                end: options.range.to.unix(),
-              }).pipe(
-                map((response) => {
-                  reportTempoQueryMetrics('grafana_traces_traceql_response', options, {
-                    success: true,
-                    streaming: false,
-                    latencyMs: Math.round(performance.now() - startTime), // rounded to nearest millisecond
-                    query: queryFromFilters ?? '',
-                  });
-                  return {
-                    data: formatTraceQLResponse(
-                      response.data.traces,
-                      this.instanceSettings,
-                      targets.traceqlSearch[0].tableType
-                    ),
-                  };
-                }),
-                catchError((err) => {
-                  reportTempoQueryMetrics('grafana_traces_traceql_response', options, {
-                    success: false,
-                    streaming: false,
-                    latencyMs: Math.round(performance.now() - startTime), // rounded to nearest millisecond
-                    query: queryFromFilters ?? '',
-                    error: getErrorMessage(err.message),
-                    statusCode: err.status,
-                    statusText: err.statusText,
-                  });
-                  return of({ error: { message: getErrorMessage(err?.data?.message) }, data: [] });
-                })
-              )
-            );
+            if (config.featureToggles.tempoSearchBackendMigration) {
+              subQueries.push(this.handleTraceQlQuery(options, targets));
+            } else {
+              subQueries.push(this.oldSearchQueryLogic(options, targets, queryFromFilters));
+            }
           }
         }
       } catch (error) {
@@ -482,6 +473,7 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
       }
     }
 
+    // Upload
     if (targets.upload?.length) {
       if (this.uploadedJson) {
         reportInteraction('grafana_traces_json_file_uploaded', {
@@ -507,6 +499,7 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
       }
     }
 
+    // Service Map
     if (this.serviceMap?.datasourceUid && targets.serviceMap?.length > 0) {
       reportInteraction('grafana_traces_service_graph_queried', {
         datasourceType: 'tempo',
@@ -515,13 +508,20 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
         hasServiceMapQuery: targets.serviceMap[0].serviceMapQuery ? true : false,
       });
 
-      const { datasourceUid, histogramType } = this.serviceMap;
+      const { datasourceUid } = this.serviceMap;
+
+      // if the query contains the serviceMapUseNativeHistograms flag,
+      // then use the native histograms
+      const useNativeHistogram = options.targets[0].serviceMapUseNativeHistograms;
+
       const tempoDsUid = this.uid;
       subQueries.push(
-        serviceMapQuery(options, datasourceUid, tempoDsUid, histogramType).pipe(
+        serviceMapQuery(options, datasourceUid, tempoDsUid, useNativeHistogram).pipe(
           concatMap((result) =>
             rateQuery(options, result, datasourceUid).pipe(
-              concatMap((result) => errorAndDurationQuery(options, result, datasourceUid, tempoDsUid, histogramType))
+              concatMap((result) =>
+                errorAndDurationQuery(options, result, datasourceUid, tempoDsUid, useNativeHistogram)
+              )
             )
           )
         )
@@ -629,49 +629,127 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
     );
   }
 
-  handleTraceQlQuery = (
-    options: DataQueryRequest<TempoQuery>,
-    targets: {
-      [type: string]: TempoQuery[];
-    },
-    queryValue: string
-  ): Observable<DataQueryResponse> => {
+  handleTraceQlQuery = (options: DataQueryRequest<TempoQuery>, targets: { [type: string]: TempoQuery[] }) => {
     const startTime = performance.now();
-    if (this.isStreamingSearchEnabled()) {
-      return this.handleStreamingQuery(options, targets.traceql, queryValue);
+    const traceqlSearchTargets = targets.traceqlSearch || targets.traceql;
+    const appliedQuery = this.applyVariables(traceqlSearchTargets[0], options.scopedVars);
+    let queries: TempoQuery[];
+
+    if (targets.traceqlSearch) {
+      const queryFromFilters = this.languageProvider.generateQueryFromFilters({
+        traceqlFilters: appliedQuery.filters,
+        adhocFilters: options.filters,
+      });
+      queries = traceqlSearchTargets.map((t) => ({ ...t, query: queryFromFilters }));
     } else {
-      return this._request('/api/search', {
-        q: queryValue,
-        limit: options.targets[0].limit ?? DEFAULT_LIMIT,
-        spss: options.targets[0].spss ?? DEFAULT_SPSS,
-        start: options.range.from.unix(),
-        end: options.range.to.unix(),
-      }).pipe(
-        map((response) => {
-          reportTempoQueryMetrics('grafana_traces_traceql_response', options, {
-            success: true,
-            streaming: false,
-            latencyMs: Math.round(performance.now() - startTime), // rounded to nearest millisecond
-            query: queryValue ?? '',
-          });
-          return {
-            data: formatTraceQLResponse(response.data.traces, this.instanceSettings, targets.traceql[0].tableType),
-          };
-        }),
-        catchError((err) => {
-          reportTempoQueryMetrics('grafana_traces_traceql_response', options, {
-            success: false,
-            streaming: false,
-            latencyMs: Math.round(performance.now() - startTime), // rounded to nearest millisecond
-            query: queryValue ?? '',
-            error: getErrorMessage(err.message),
-            statusCode: err.status,
-            statusText: err.statusText,
-          });
-          return of({ error: { message: getErrorMessage(err?.data?.message) }, data: [] });
-        })
-      );
+      queries = traceqlSearchTargets.map((t) => ({ ...t, query: appliedQuery?.query }));
     }
+
+    return super.query({ ...options, targets: queries }).pipe(
+      map((response: DataQueryResponse) => {
+        if (queries[0].tableType === SearchTableType.Traces && response.data && response.data.length > 0) {
+          response.data.forEach((frame) => {
+            reportTempoQueryMetrics('grafana_traces_traceql_response', options, {
+              success: true,
+              streaming: false,
+              latencyMs: Math.round(performance.now() - startTime),
+              query: queries[0].query ?? '',
+            });
+
+            // The backend does not support nested data frames directly, so we return
+            // what should be nested as a JSON array in a column: e.g. "[{dataframe}]".
+            // Here, we take the frames from that column, and change the type to "nestedFrames"
+            // This allows the frontend to render the nested frames as intended.
+            const nested = frame.fields[5];
+            nested.type = 'nestedFrames';
+            nested.typeInfo.frame = 'nestedFrames';
+
+            // The returned JSON data frame structure does not fully match what the frontend expects for
+            // rendering nested frames. Here, we transform each nested frame array to the correct format:
+            //
+            // - For each row in the main data frame, there is an array of nested frames (nestedFrameArray).
+            // - Each nested frame (nestedFrame) contains a 'schema' (with 'fields' and 'meta') and 'data' (with 'values').
+            // - We create a new frame object (newNestedFrame) with the expected 'fields' and 'meta' properties.
+            // - For each field, we copy its definition and assign the corresponding values from nestedFrame.data.values.
+            // - We also set the 'length' property on the new frame, which is required by the frontend to know how many rows it contains.
+            // - Finally, we replace the original nestedFrame in the array with the transformed newNestedFrame.
+            // const mestedFrames = nested.values as DataFrameJSON[][];
+            // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
+            const mestedFrames = nested.values as DataFrameJSON[][];
+
+            nested.values = mestedFrames.map((nestedFrameArray) => {
+              return nestedFrameArray.map((nestedFrame) => {
+                const newNestedFrame = { fields: nestedFrame.schema?.fields, meta: nestedFrame.schema?.meta };
+
+                newNestedFrame.fields = newNestedFrame.fields?.map((field, fieldIndex: number) => {
+                  return { ...field, values: nestedFrame.data?.values[fieldIndex] };
+                });
+
+                const rowCount = Array.isArray(nestedFrame.data?.values?.[0]) ? nestedFrame.data.values?.[0].length : 0;
+
+                return { fields: newNestedFrame.fields, meta: nestedFrame.schema?.meta, length: rowCount };
+              });
+            });
+          });
+        }
+        return response;
+      }),
+      catchError((err) => {
+        reportTempoQueryMetrics('grafana_traces_traceql_response', options, {
+          success: false,
+          streaming: false,
+          latencyMs: Math.round(performance.now() - startTime),
+          query: queries[0].query ?? '',
+          error: getErrorMessage(err.message),
+          statusCode: err.status,
+          statusText: err.statusText,
+        });
+        return of({ error: { message: getErrorMessage(err?.data?.message) }, data: [] });
+      })
+    );
+  };
+
+  // this is just a short term function, we will remove once we have rolled
+  // out the backend migration and are happy with the stability of the feature
+  oldSearchQueryLogic = (
+    options: DataQueryRequest<TempoQuery>,
+    targets: { [type: string]: TempoQuery[] },
+    queryValue: string
+  ) => {
+    const startTime = performance.now();
+    const tableType = targets.traceqlSearch?.[0]?.tableType ?? targets.traceql?.[0]?.tableType;
+
+    return this._request('/api/search', {
+      q: queryValue,
+      limit: options.targets[0].limit ?? DEFAULT_LIMIT,
+      spss: options.targets[0].spss ?? DEFAULT_SPSS,
+      start: options.range.from.unix(),
+      end: options.range.to.unix(),
+    }).pipe(
+      map((response) => {
+        reportTempoQueryMetrics('grafana_traces_traceql_response', options, {
+          success: true,
+          streaming: false,
+          latencyMs: Math.round(performance.now() - startTime), // rounded to nearest millisecond
+          query: queryValue ?? '',
+        });
+        return {
+          data: formatTraceQLResponse(response.data.traces, this.instanceSettings, tableType),
+        };
+      }),
+      catchError((err) => {
+        reportTempoQueryMetrics('grafana_traces_traceql_response', options, {
+          success: false,
+          streaming: false,
+          latencyMs: Math.round(performance.now() - startTime), // rounded to nearest millisecond
+          query: queryValue ?? '',
+          error: getErrorMessage(err.message),
+          statusCode: err.status,
+          statusText: err.statusText,
+        });
+        return of({ error: { message: getErrorMessage(err?.data?.message) }, data: [] });
+      })
+    );
   };
 
   handleTraceQlMetricsQuery(
@@ -782,6 +860,9 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
         )
       )
     ).pipe(
+      map((response) => {
+        return enhanceTraceQlMetricsResponse(response, this.instanceSettings);
+      }),
       catchError((error) => {
         reportTempoQueryMetrics('grafana_traces_traceql_metrics_response', options, {
           success: false,
@@ -832,7 +913,14 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
   }
 
   async metadataRequest(url: string, params = {}) {
-    return await lastValueFrom(this._request(url, params, { method: 'GET', hideFromInspector: true }));
+    // url must not start with a `/`, otherwise the AJAX-request
+    // going from the browser will contain `//`, which can cause problems.
+    if (url.startsWith('/')) {
+      throw new Error(`invalid metadata request url: ${url}`);
+    }
+
+    const res = await this.getResource(url, params, { method: 'GET', hideFromInspector: true });
+    return res?.data ?? res;
   }
 
   _request(apiUrl: string, data?: unknown, options?: Partial<BackendSrvRequest>): Observable<Record<string, any>> {
@@ -843,86 +931,7 @@ export class TempoDatasource extends DataSourceWithBackend<TempoQuery, TempoJson
   }
 
   async testDatasource(): Promise<TestDataSourceResponse> {
-    const observables = [];
-
-    const options: BackendSrvRequest = {
-      headers: {},
-      method: 'GET',
-      url: `${this.instanceSettings.url}/api/echo`,
-    };
-    observables.push(
-      getBackendSrv()
-        .fetch(options)
-        .pipe(
-          mergeMap(() => {
-            return of({ status: 'success', message: 'Health check succeeded' });
-          }),
-          catchError((err) => {
-            return of({
-              status: 'error',
-              message: getErrorMessage(err?.data?.message, 'Unable to connect with Tempo'),
-            });
-          })
-        )
-    );
-
-    if (this.streamingEnabled?.search) {
-      const now = new Date();
-      const from = new Date(now);
-      from.setMinutes(from.getMinutes() - 15);
-      observables.push(
-        this.handleStreamingQuery(
-          {
-            range: {
-              from: dateTime(from),
-              to: dateTime(now),
-              raw: { from: 'now-15m', to: 'now' },
-            },
-            requestId: '',
-            interval: '',
-            intervalMs: 0,
-            scopedVars: {},
-            targets: [],
-            timezone: '',
-            app: '',
-            startTime: 0,
-          },
-          [
-            {
-              datasource: this.instanceSettings,
-              limit: 1,
-              query: '{}',
-              queryType: 'traceql',
-              refId: 'A',
-              tableType: SearchTableType.Traces,
-              filters: [],
-            },
-          ],
-          '{}'
-        ).pipe(
-          mergeMap(() => {
-            return of({ status: 'success', message: 'Streaming test succeeded.' });
-          }),
-          catchError((err) => {
-            return of({
-              status: 'error',
-              message: getErrorMessage(err?.data?.message, 'Test for streaming failed, consider disabling streaming'),
-            });
-          })
-        )
-      );
-    }
-
-    return await lastValueFrom(
-      forkJoin(observables).pipe(
-        mergeMap((observableResults) => {
-          const erroredResult = observableResults.find((result) => result.status !== 'success');
-          return erroredResult
-            ? of(erroredResult)
-            : of({ status: 'success', message: 'Successfully connected to Tempo data source.' });
-        })
-      )
-    );
+    return await super.testDatasource();
   }
 
   getQueryDisplayText(query: TempoQuery) {
@@ -947,9 +956,9 @@ function serviceMapQuery(
   request: DataQueryRequest<TempoQuery>,
   datasourceUid: string,
   tempoDatasourceUid: string,
-  histogramType?: string
+  useNativeHistogram?: boolean
 ): Observable<ServiceMapQueryResponse> {
-  const serviceMapRequest = makePromServiceMapRequest(request, histogramType);
+  const serviceMapRequest = makePromServiceMapRequest(request, useNativeHistogram);
 
   return queryPrometheus(serviceMapRequest, datasourceUid).pipe(
     // Just collect all the responses first before processing into node graph data
@@ -987,7 +996,7 @@ function serviceMapQuery(
           '__data.fields[0]', // tempoField
           undefined, // sourceField
           { targetNamespace: '__data.fields.subtitle' },
-          histogramType
+          useNativeHistogram
         );
 
         edges.fields[0].config = getFieldConfig(
@@ -997,7 +1006,7 @@ function serviceMapQuery(
           '__data.fields.target', // tempoField
           '__data.fields.sourceName', // sourceField
           { targetNamespace: '__data.fields.targetNamespace', sourceNamespace: '__data.fields.sourceNamespace' },
-          histogramType
+          useNativeHistogram
         );
       } else {
         nodes.fields[0].config = getFieldConfig(
@@ -1007,7 +1016,7 @@ function serviceMapQuery(
           '__data.fields[0]',
           undefined,
           undefined,
-          histogramType
+          useNativeHistogram
         );
         edges.fields[0].config = getFieldConfig(
           datasourceUid,
@@ -1016,7 +1025,7 @@ function serviceMapQuery(
           '__data.fields.target',
           '__data.fields.source',
           undefined,
-          histogramType
+          useNativeHistogram
         );
       }
 
@@ -1033,9 +1042,9 @@ function rateQuery(
   request: DataQueryRequest<TempoQuery>,
   serviceMapResponse: ServiceMapQueryResponse,
   datasourceUid: string,
-  histogramType?: string
+  useNativeHistogram?: boolean
 ): Observable<ServiceMapQueryResponseWithRates> {
-  const serviceMapRequest = makePromServiceMapRequest(request, histogramType);
+  const serviceMapRequest = makePromServiceMapRequest(request, useNativeHistogram);
   serviceMapRequest.targets = makeServiceGraphViewRequest([buildExpr(rateMetric, defaultTableFilter, request)]);
 
   return queryPrometheus(serviceMapRequest, datasourceUid).pipe(
@@ -1061,7 +1070,7 @@ function errorAndDurationQuery(
   rateResponse: ServiceMapQueryResponseWithRates,
   datasourceUid: string,
   tempoDatasourceUid: string,
-  histogramType?: string
+  useNativeHistogram?: boolean
 ) {
   let serviceGraphViewMetrics = [];
   let errorRateBySpanName = '';
@@ -1087,14 +1096,14 @@ function errorAndDurationQuery(
     errorRateBySpanName = buildExpr(errorRateMetric, 'span_name=~"' + spanNames.join('|') + '"', request);
     serviceGraphViewMetrics.push(errorRateBySpanName);
     spanNames.map((name: string) => {
-      const checkedDurationMetric = histogramType === 'native' ? nativeHistogramDurationMetric : durationMetric;
+      const checkedDurationMetric = useNativeHistogram ? nativeHistogramDurationMetric : durationMetric;
       const metric = buildExpr(checkedDurationMetric, 'span_name=~"' + name + '"', request);
       durationsBySpanName.push(metric);
       serviceGraphViewMetrics.push(metric);
     });
   }
 
-  const serviceMapRequest = makePromServiceMapRequest(request, histogramType);
+  const serviceMapRequest = makePromServiceMapRequest(request, useNativeHistogram);
   serviceMapRequest.targets = makeServiceGraphViewRequest(serviceGraphViewMetrics);
 
   return queryPrometheus(serviceMapRequest, datasourceUid).pipe(
@@ -1114,7 +1123,7 @@ function errorAndDurationQuery(
         durationsBySpanName,
         datasourceUid,
         tempoDatasourceUid,
-        histogramType
+        useNativeHistogram
       );
 
       if (serviceGraphView.fields.length === 0) {
@@ -1166,7 +1175,7 @@ export function getFieldConfig(
   tempoField: string,
   sourceField?: string,
   namespaceFields?: { targetNamespace: string; sourceNamespace?: string },
-  histogramType?: string
+  useNativeHistogram?: boolean
 ) {
   let source = sourceField ? `client="\${${sourceField}}",` : '';
   let target = `server="\${${targetField}}"`;
@@ -1192,7 +1201,7 @@ export function getFieldConfig(
         datasourceUid,
         false
       ),
-      ...makeHistogramLink(datasourceUid, source, target, serverSumBy, histogramType),
+      ...makeHistogramLink(datasourceUid, source, target, serverSumBy, useNativeHistogram),
       makePromLink(
         'Failed request rate',
         `sum by (client, ${serverSumBy})(rate(${failedMetric}{${source}${target}}[$__rate_interval]))`,
@@ -1214,7 +1223,7 @@ export function makeHistogramLink(
   source: string,
   target: string,
   serverSumBy: string,
-  histogramType?: string
+  useNativeHistogram?: boolean
 ) {
   const createHistogramLink = (metric: string, title: string) =>
     makePromLink(
@@ -1223,18 +1232,10 @@ export function makeHistogramLink(
       datasourceUid,
       false
     );
-
-  switch (histogramType) {
-    case 'both':
-      return [
-        createHistogramLink(histogramMetric, 'Request classic histogram'),
-        createHistogramLink(nativeHistogramMetric, 'Request native histogram'),
-      ];
-    case 'native':
-      return [createHistogramLink(nativeHistogramMetric, 'Request native histogram')];
-    default:
-      return [createHistogramLink(histogramMetric, 'Request classic histogram')];
+  if (useNativeHistogram) {
+    return [createHistogramLink(nativeHistogramMetric, 'Request native histogram')];
   }
+  return [createHistogramLink(histogramMetric, 'Request classic histogram')];
 }
 
 export function makeTempoLink(
@@ -1345,13 +1346,13 @@ function makeTempoLinkServiceMap(
 
 export function makePromServiceMapRequest(
   options: DataQueryRequest<TempoQuery>,
-  histogramType?: string
+  useNativeHistogram?: boolean
 ): DataQueryRequest<PromQuery> {
   return {
     ...options,
     targets: serviceMapMetrics
       .map<PromQuery[]>((metric) => {
-        if (histogramType === 'native' && metric.includes('_bucket')) {
+        if (useNativeHistogram) {
           metric = metric.replace('_bucket', '');
         }
         const { serviceMapQuery, serviceMapIncludeNamespace: serviceMapIncludeNamespace } = options.targets[0];
@@ -1395,7 +1396,7 @@ function getServiceGraphViewDataFrames(
   durationsBySpanName: string[],
   datasourceUid: string,
   tempoDatasourceUid: string,
-  histogramType?: string
+  useNativeHistogram?: boolean
 ) {
   let df: any = { fields: [] };
 
@@ -1520,7 +1521,7 @@ function getServiceGraphViewDataFrames(
       }
     });
     if (Object.keys(durationObj).length > 0) {
-      const checkedDurationMetric = histogramType === 'native' ? nativeHistogramDurationMetric : durationMetric;
+      const checkedDurationMetric = useNativeHistogram ? nativeHistogramDurationMetric : durationMetric;
       df.fields.push({
         ...duration[0].fields[1],
         name: 'Duration (p90)',
