@@ -7,9 +7,10 @@ import {
   PanelPlugin,
   VizOrientation,
 } from '@grafana/data';
+import { t } from '@grafana/i18n';
 import { GraphTransform, GraphThresholdsStyleMode, StackingMode, VisibilityMode } from '@grafana/schema';
-import { graphFieldOptions, commonOptionsBuilder } from '@grafana/ui';
-import { optsWithHideZeros } from '@grafana/ui/src/options/builder/tooltip';
+import { getGraphFieldOptions, commonOptionsBuilder } from '@grafana/ui';
+import { optsWithHideZeros } from '@grafana/ui/internal';
 
 import { ThresholdsStyleEditor } from '../timeseries/ThresholdsStyleEditor';
 
@@ -47,7 +48,7 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
       builder
         .addSliderInput({
           path: 'lineWidth',
-          name: 'Line width',
+          name: t('barchart.config.name-line-width', 'Line width'),
           defaultValue: cfg.lineWidth,
           settings: {
             min: 0,
@@ -57,7 +58,7 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
         })
         .addSliderInput({
           path: 'fillOpacity',
-          name: 'Fill opacity',
+          name: t('barchart.config.name-fill-opacity', 'Fill opacity'),
           defaultValue: cfg.fillOpacity,
           settings: {
             min: 0,
@@ -67,28 +68,34 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
         })
         .addRadio({
           path: 'gradientMode',
-          name: 'Gradient mode',
-          defaultValue: graphFieldOptions.fillGradient[0].value,
+          name: t('barchart.config.name-gradient-mode', 'Gradient mode'),
+          defaultValue: getGraphFieldOptions().fillGradient[0].value,
           settings: {
-            options: graphFieldOptions.fillGradient,
+            options: getGraphFieldOptions().fillGradient,
           },
         });
 
       builder.addSelect({
         category: ['Graph styles'],
-        name: 'Transform',
+        name: t('barchart.config.name-transform', 'Transform'),
         path: 'transform',
         settings: {
           options: [
             {
-              label: 'Constant',
+              label: t('barchart.config.transform-options.label-constant', 'Constant'),
               value: GraphTransform.Constant,
-              description: 'The first value will be shown as a constant line',
+              description: t(
+                'barchart.config.transform-options.description-constant',
+                'The first value will be shown as a constant line'
+              ),
             },
             {
-              label: 'Negative Y',
+              label: t('barchart.config.transform-options.label-negative-y', 'Negative Y'),
               value: GraphTransform.NegativeY,
-              description: 'Flip the results to negative values on the y axis',
+              description: t(
+                'barchart.config.transform-options.description-negative-y',
+                'Flip the results to negative values on the y axis'
+              ),
             },
           ],
           isClearable: true,
@@ -99,11 +106,11 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
       builder.addCustomEditor({
         id: 'thresholdsStyle',
         path: 'thresholdsStyle',
-        name: 'Show thresholds',
-        category: ['Thresholds'],
+        name: t('barchart.config.name-show-thresholds', 'Show thresholds'),
+        category: [t('barchart.config.category-thresholds', 'Thresholds')],
         defaultValue: { mode: GraphThresholdsStyleMode.Off },
         settings: {
-          options: graphFieldOptions.thresholdsDisplayModes,
+          options: getGraphFieldOptions().thresholdsDisplayModes,
         },
         editor: ThresholdsStyleEditor,
         override: ThresholdsStyleEditor,
@@ -119,26 +126,32 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
     builder
       .addFieldNamePicker({
         path: 'xField',
-        name: 'X Axis',
+        name: t('barchart.config.name-x-axis', 'X Axis'),
         settings: {
-          placeholderText: 'First string or time field',
+          placeholderText: t('barchart.config.placeholder-x-axis', 'First string or time field'),
         },
       })
       .addRadio({
         path: 'orientation',
-        name: 'Orientation',
+        name: t('barchart.config.name-orientation', 'Orientation'),
         settings: {
           options: [
-            { value: VizOrientation.Auto, label: 'Auto' },
-            { value: VizOrientation.Horizontal, label: 'Horizontal' },
-            { value: VizOrientation.Vertical, label: 'Vertical' },
+            { value: VizOrientation.Auto, label: t('barchart.config.orientation-options.label-auto', 'Auto') },
+            {
+              value: VizOrientation.Horizontal,
+              label: t('barchart.config.orientation-options.label-horizontal', 'Horizontal'),
+            },
+            {
+              value: VizOrientation.Vertical,
+              label: t('barchart.config.orientation-options.label-line-vertical', 'Vertical'),
+            },
           ],
         },
         defaultValue: defaultOptions.orientation,
       })
       .addSliderInput({
         path: 'xTickLabelRotation',
-        name: 'Rotate x-axis tick labels',
+        name: t('barchart.config.name-rotate-x-labels', 'Rotate x-axis tick labels'),
         defaultValue: defaultOptions.xTickLabelRotation,
         settings: {
           min: -90,
@@ -150,10 +163,13 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
       })
       .addNumberInput({
         path: 'xTickLabelMaxLength',
-        name: 'X-axis tick label max length',
-        description: 'X-axis labels will be truncated to the length provided',
+        name: t('barchart.config.name-x-label-max-length', 'X-axis tick label max length'),
+        description: t(
+          'barchart.config.description-x-label-max-length',
+          'X-axis labels will be truncated to the length provided'
+        ),
         settings: {
-          placeholder: 'None',
+          placeholder: t('barchart.config.placeholder-x-label-max-length', 'None'),
           min: 0,
         },
         showIf: (opts) => opts.xTickLabelRotation !== 0,
@@ -161,33 +177,33 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
       .addCustomEditor({
         id: 'xTickLabelSpacing',
         path: 'xTickLabelSpacing',
-        name: 'X-axis labels minimum spacing',
+        name: t('barchart.config.name-x-label-min-spacing', 'X-axis labels minimum spacing'),
         defaultValue: defaultOptions.xTickLabelSpacing,
         editor: TickSpacingEditor,
       })
       .addRadio({
         path: 'showValue',
-        name: 'Show values',
+        name: t('barchart.config.name-show-values', 'Show values'),
         settings: {
           options: [
-            { value: VisibilityMode.Auto, label: 'Auto' },
-            { value: VisibilityMode.Always, label: 'Always' },
-            { value: VisibilityMode.Never, label: 'Never' },
+            { value: VisibilityMode.Auto, label: t('barchart.config.show-values-options.label-auto', 'Auto') },
+            { value: VisibilityMode.Always, label: t('barchart.config.show-values-options.label-always', 'Always') },
+            { value: VisibilityMode.Never, label: t('barchart.config.show-values-options.label-never', 'Never') },
           ],
         },
         defaultValue: defaultOptions.showValue,
       })
       .addRadio({
         path: 'stacking',
-        name: 'Stacking',
+        name: t('barchart.config.name-stacking', 'Stacking'),
         settings: {
-          options: graphFieldOptions.stacking,
+          options: getGraphFieldOptions().stacking,
         },
         defaultValue: defaultOptions.stacking,
       })
       .addSliderInput({
         path: 'groupWidth',
-        name: 'Group width',
+        name: t('barchart.config.name-group-width', 'Group width'),
         defaultValue: defaultOptions.groupWidth,
         settings: {
           min: 0,
@@ -203,7 +219,7 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
       })
       .addSliderInput({
         path: 'barWidth',
-        name: 'Bar width',
+        name: t('barchart.config.name-bar-width', 'Bar width'),
         defaultValue: defaultOptions.barWidth,
         settings: {
           min: 0,
@@ -213,7 +229,7 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
       })
       .addSliderInput({
         path: 'barRadius',
-        name: 'Bar radius',
+        name: t('barchart.config.name-bar-radius', 'Bar radius'),
         defaultValue: defaultOptions.barRadius,
         settings: {
           min: 0,
@@ -223,20 +239,23 @@ export const plugin = new PanelPlugin<Options, FieldConfig>(BarChartPanel)
       })
       .addBooleanSwitch({
         path: 'fullHighlight',
-        name: 'Highlight full area on hover',
+        name: t('barchart.config.name-full-highlight', 'Highlight full area on hover'),
         defaultValue: defaultOptions.fullHighlight,
         showIf: (c) => c.stacking === StackingMode.None,
       });
 
     builder.addFieldNamePicker({
       path: 'colorByField',
-      name: 'Color by field',
-      description: 'Use the color value for a sibling field to color each bar value.',
+      name: t('barchart.config.name-color-by-field', 'Color by field'),
+      description: t(
+        'barchart.config.description-color-by-field',
+        'Use the color value for a sibling field to color each bar value.'
+      ),
     });
 
     commonOptionsBuilder.addTooltipOptions(builder, false, false, optsWithHideZeros);
     commonOptionsBuilder.addLegendOptions(builder);
-    commonOptionsBuilder.addTextSizeOptions(builder, false);
+    commonOptionsBuilder.addTextSizeOptions(builder, { withValue: true });
   })
   .setSuggestionsSupplier(new BarChartSuggestionsSupplier());
 
