@@ -12,7 +12,11 @@ import {
   getDefaultTimeRange,
   LogsDedupStrategy,
   EventBusSrv,
+  DataFrameType,
+  LogSortOrderChangeEvent,
 } from '@grafana/data';
+import { getAppEvents } from '@grafana/runtime';
+// eslint-disable-next-line no-restricted-imports
 import * as grafanaUI from '@grafana/ui';
 import * as styles from 'app/features/logs/components/getLogRowStyles';
 import { LogRowContextModal } from 'app/features/logs/components/log-context/LogRowContextModal';
@@ -38,10 +42,15 @@ const datasourceSrv = new DatasourceSrvMock(defaultDs, {
 const getDataSourceSrvMock = jest.fn().mockReturnValue(datasourceSrv);
 jest.mock('@grafana/runtime', () => ({
   ...jest.requireActual('@grafana/runtime'),
+  getAppEvents: jest.fn(),
   getDataSourceSrv: () => getDataSourceSrvMock(),
+  usePluginLinks: jest.fn().mockReturnValue({ links: [] }),
 }));
 
 const hasLogsContextSupport = jest.fn().mockImplementation((ds) => {
+  if (!ds) {
+    return false;
+  }
   return ds.name === 'show-context';
 });
 jest.mock('@grafana/data', () => ({
@@ -49,57 +58,202 @@ jest.mock('@grafana/data', () => ({
   hasLogsContextSupport: (ds: MockDataSourceApi) => hasLogsContextSupport(ds),
 }));
 
-describe('LogsPanel', () => {
+jest.mock('@grafana/assistant', () => {
+  return {
+    ...jest.requireActual('@grafana/assistant'),
+    useAssistant: jest.fn().mockReturnValue({ isAvailable: true }),
+  };
+});
+
+const defaultProps = {
+  data: {
+    error: undefined,
+    request: {
+      panelId: 4,
+      app: 'dashboard',
+      requestId: 'A',
+      timezone: 'browser',
+      interval: '30s',
+      intervalMs: 30000,
+      maxDataPoints: 823,
+      targets: [],
+      range: getDefaultTimeRange(),
+      scopedVars: {},
+      startTime: 1,
+    },
+    series: [
+      createDataFrame({
+        refId: 'A',
+        fields: [
+          {
+            name: 'timestamp',
+            type: FieldType.time,
+            values: ['2019-04-26T09:28:11.352440161Z'],
+          },
+          {
+            name: 'body',
+            type: FieldType.string,
+            values: ['logline text'],
+          },
+          {
+            name: 'labels',
+            type: FieldType.other,
+            values: [
+              {
+                app: 'common_app',
+              },
+            ],
+          },
+        ],
+        meta: {
+          type: DataFrameType.LogLines,
+        },
+      }),
+    ],
+    state: LoadingState.Done,
+    timeRange: getDefaultTimeRange(),
+  },
+  timeZone: 'utc',
+  timeRange: getDefaultTimeRange(),
+  options: {
+    showLabels: false,
+    showTime: false,
+    wrapLogMessage: false,
+    showCommonLabels: false,
+    prettifyLogMessage: false,
+    sortOrder: LogsSortOrder.Descending,
+    dedupStrategy: LogsDedupStrategy.none,
+    enableLogDetails: false,
+    showLogContextToggle: false,
+  },
+  title: 'Logs panel',
+  id: 1,
+  transparent: false,
+  width: 400,
+  height: 100,
+  renderCounter: 0,
+  fieldConfig: {
+    defaults: {},
+    overrides: [],
+  },
+  eventBus: new EventBusSrv(),
+  onOptionsChange: jest.fn(),
+  onFieldConfigChange: jest.fn(),
+  replaceVariables: jest.fn(),
+  onChangeTimeRange: jest.fn(),
+};
+
+const publishMock = jest.fn();
+beforeAll(() => {
+  jest.mocked(getAppEvents).mockReturnValue({
+    publish: publishMock,
+    getStream: jest.fn(),
+    subscribe: jest.fn(),
+    removeAllListeners: jest.fn(),
+    newScopedBus: jest.fn(),
+  });
+});
+
+describe.each([false, true])('LogsPanel with controls = %s', (showControls: boolean) => {
+  it('publishes an event with the current sort order', async () => {
+    publishMock.mockClear();
+    setup({}, showControls);
+
+    await screen.findByText('logline text');
+
+    expect(publishMock).toHaveBeenCalledTimes(1);
+    expect(publishMock).toHaveBeenCalledWith(
+      new LogSortOrderChangeEvent({
+        order: LogsSortOrder.Descending,
+      })
+    );
+  });
+
   describe('when returned series include common labels', () => {
     const seriesWithCommonLabels = [
       createDataFrame({
         fields: [
           {
-            name: 'time',
+            name: 'timestamp',
             type: FieldType.time,
             values: ['2019-04-26T09:28:11.352440161Z', '2019-04-26T14:42:50.991981292Z'],
           },
           {
-            name: 'message',
+            name: 'body',
             type: FieldType.string,
             values: [
               't=2019-04-26T11:05:28+0200 lvl=info msg="Initializing DatasourceCacheService" logger=server',
               't=2019-04-26T16:42:50+0200 lvl=eror msg="new token…t unhashed token=56d9fdc5c8b7400bd51b060eea8ca9d7',
             ],
-            labels: {
-              app: 'common_app',
-              job: 'common_job',
-            },
+          },
+          {
+            name: 'labels',
+            type: FieldType.other,
+            values: [
+              {
+                app: 'common_app',
+                job: 'common_job',
+              },
+              {
+                app: 'common_app',
+                job: 'common_job',
+              },
+            ],
           },
         ],
+        meta: {
+          type: DataFrameType.LogLines,
+        },
       }),
     ];
 
     it('shows common labels when showCommonLabels is set to true', async () => {
-      setup({ data: { series: seriesWithCommonLabels }, options: { showCommonLabels: true } });
+      setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: true },
+        },
+        showControls
+      );
 
       expect(await screen.findByText(/common labels:/i)).toBeInTheDocument();
       expect(await screen.findByText(/common_app/i)).toBeInTheDocument();
       expect(await screen.findByText(/common_job/i)).toBeInTheDocument();
     });
     it('shows common labels on top when descending sort order', async () => {
-      const { container } = setup({
-        data: { series: seriesWithCommonLabels },
-        options: { showCommonLabels: true, sortOrder: LogsSortOrder.Descending },
-      });
+      const { container } = setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: true, sortOrder: LogsSortOrder.Descending },
+        },
+        showControls
+      );
       expect(await screen.findByText(/common labels:/i)).toBeInTheDocument();
       expect(container.firstChild?.childNodes[0].textContent).toMatch(/^Common labels:app=common_appjob=common_job/);
     });
     it('shows common labels on bottom when ascending sort order', async () => {
-      const { container } = setup({
-        data: { series: seriesWithCommonLabels },
-        options: { showCommonLabels: true, sortOrder: LogsSortOrder.Ascending },
-      });
+      const { container } = setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: true, sortOrder: LogsSortOrder.Ascending },
+        },
+        showControls
+      );
       expect(await screen.findByText(/common labels:/i)).toBeInTheDocument();
-      expect(container.firstChild?.childNodes[0].textContent).toMatch(/Common labels:app=common_appjob=common_job$/);
+      if (!showControls) {
+        expect(container.firstChild?.childNodes[0].textContent).toMatch(/Common labels:app=common_appjob=common_job$/);
+      } else {
+        expect(container.childNodes[0].textContent).toMatch(/Common labels:app=common_appjob=common_job$/);
+      }
     });
     it('does not show common labels when showCommonLabels is set to false', async () => {
-      setup({ data: { series: seriesWithCommonLabels }, options: { showCommonLabels: false } });
+      setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: false },
+        },
+        showControls
+      );
 
       await waitFor(async () => {
         expect(screen.queryByText(/common labels:/i)).toBeNull();
@@ -113,12 +267,12 @@ describe('LogsPanel', () => {
       createDataFrame({
         fields: [
           {
-            name: 'time',
+            name: 'timestamp',
             type: FieldType.time,
             values: ['2019-04-26T09:28:11.352440161Z', '2019-04-26T14:42:50.991981292Z'],
           },
           {
-            name: 'message',
+            name: 'body',
             type: FieldType.string,
             values: [
               't=2019-04-26T11:05:28+0200 lvl=info msg="Initializing DatasourceCacheService" logger=server',
@@ -126,16 +280,31 @@ describe('LogsPanel', () => {
             ],
           },
         ],
+        meta: {
+          type: DataFrameType.LogLines,
+        },
       }),
     ];
     it('shows (no common labels) when showCommonLabels is set to true', async () => {
-      setup({ data: { series: seriesWithoutCommonLabels }, options: { showCommonLabels: true } });
+      setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithoutCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: true },
+        },
+        showControls
+      );
 
       expect(await screen.findByText(/common labels:/i)).toBeInTheDocument();
       expect(await screen.findByText(/(no common labels)/i)).toBeInTheDocument();
     });
     it('does not show common labels when showCommonLabels is set to false', async () => {
-      setup({ data: { series: seriesWithoutCommonLabels }, options: { showCommonLabels: false } });
+      setup(
+        {
+          data: { ...defaultProps.data, series: seriesWithoutCommonLabels },
+          options: { ...defaultProps.options, showCommonLabels: false },
+        },
+        showControls
+      );
       await waitFor(async () => {
         expect(screen.queryByText(/common labels:/i)).toBeNull();
         expect(screen.queryByText(/(no common labels)/i)).toBeNull();
@@ -149,20 +318,33 @@ describe('LogsPanel', () => {
         refId: 'A',
         fields: [
           {
-            name: 'time',
+            name: 'timestamp',
             type: FieldType.time,
             values: ['2019-04-26T09:28:11.352440161Z', '2019-04-26T14:42:50.991981292Z'],
           },
           {
-            name: 'message',
+            name: 'body',
             type: FieldType.string,
-            values: ['logline text'],
-            labels: {
-              app: 'common_app',
-              job: 'common_job',
-            },
+            values: ['logline text', 'more text'],
+          },
+          {
+            name: 'labels',
+            type: FieldType.other,
+            values: [
+              {
+                app: 'common_app',
+                job: 'common_job',
+              },
+              {
+                app: 'common_app',
+                job: 'common_job',
+              },
+            ],
           },
         ],
+        meta: {
+          type: DataFrameType.LogLines,
+        },
       }),
     ];
 
@@ -171,16 +353,20 @@ describe('LogsPanel', () => {
     });
 
     it('should not show the toggle if the datasource does not support show context', async () => {
-      setup({
-        data: {
-          series,
-          options: { showCommonLabels: false },
-          request: {
-            app: CoreApp.Dashboard,
-            targets: [{ refId: 'A', datasource: { uid: 'no-show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.Dashboard,
+              targets: [{ refId: 'A', datasource: { uid: 'no-show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
 
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
@@ -189,16 +375,20 @@ describe('LogsPanel', () => {
     });
 
     it('should show the toggle if the datasource does support show context', async () => {
-      setup({
-        data: {
-          series,
-          options: { showCommonLabels: false },
-          request: {
-            app: CoreApp.Dashboard,
-            targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.Dashboard,
+              targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
 
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
@@ -207,16 +397,20 @@ describe('LogsPanel', () => {
     });
 
     it('should not show the toggle if the datasource does support show context but the app is not Dashboard', async () => {
-      setup({
-        data: {
-          series,
-          options: { showCommonLabels: false },
-          request: {
-            app: CoreApp.CloudAlerting,
-            targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.CloudAlerting,
+              targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
 
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
@@ -225,16 +419,20 @@ describe('LogsPanel', () => {
     });
 
     it('should render the mocked `LogRowContextModal` after click', async () => {
-      setup({
-        data: {
-          series,
-          options: { showCommonLabels: false },
-          request: {
-            app: CoreApp.Dashboard,
-            targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.Dashboard,
+              targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
         await userEvent.click(screen.getByLabelText(/show context/i));
@@ -243,25 +441,59 @@ describe('LogsPanel', () => {
     });
 
     it('should call `getLogRowContext` if the user clicks the show context toggle', async () => {
-      setup({
-        data: {
-          series,
-          options: { showCommonLabels: false },
-          request: {
-            app: CoreApp.Dashboard,
-            targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+            request: {
+              ...defaultProps.data.request,
+              app: CoreApp.Dashboard,
+              targets: [{ refId: 'A', datasource: { uid: 'show-context' } }],
+            },
           },
         },
-      });
+        showControls
+      );
       await waitFor(async () => {
         await userEvent.hover(screen.getByText(/logline text/i));
         await userEvent.click(screen.getByLabelText(/show context/i));
 
         const getRowContextCb = logRowContextModalMock.mock.calls[0][0].getRowContext;
-        getRowContextCb();
+        getRowContextCb({}, {});
         expect(showContextDs.getLogRowContext).toBeCalled();
       });
     });
+
+    it('supports adding custom options to the log row menu', async () => {
+      const logRowMenuIconsBefore = [
+        <grafanaUI.IconButton name="eye-slash" tooltip="Addon before" aria-label="Addon before" key={1} />,
+      ];
+      const logRowMenuIconsAfter = [
+        <grafanaUI.IconButton name="rss" tooltip="Addon after" aria-label="Addon after" key={1} />,
+      ];
+
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            logRowMenuIconsBefore,
+            logRowMenuIconsAfter,
+          },
+        },
+        showControls
+      );
+
+      await waitFor(async () => {
+        await userEvent.hover(screen.getByText(/logline text/i));
+        expect(screen.getByLabelText('Addon before')).toBeInTheDocument();
+        expect(screen.getByLabelText('Addon after')).toBeInTheDocument();
+      });
+    });
   });
 
   describe('Performance regressions', () => {
@@ -270,20 +502,29 @@ describe('LogsPanel', () => {
         refId: 'A',
         fields: [
           {
-            name: 'time',
+            name: 'timestamp',
             type: FieldType.time,
             values: ['2019-04-26T09:28:11.352440161Z'],
           },
           {
-            name: 'message',
+            name: 'body',
             type: FieldType.string,
             values: ['logline text'],
-            labels: {
-              app: 'common_app',
-              job: 'common_job',
-            },
+          },
+          {
+            name: 'labels',
+            type: FieldType.other,
+            values: [
+              {
+                app: 'common_app',
+                job: 'common_job',
+              },
+            ],
           },
         ],
+        meta: {
+          type: DataFrameType.LogLines,
+        },
       }),
     ];
 
@@ -296,11 +537,15 @@ describe('LogsPanel', () => {
     });
 
     it('does not rerender without changes', async () => {
-      const { rerender, props } = setup({
-        data: {
-          series,
+      const { rerender, props } = setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
         },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -311,11 +556,15 @@ describe('LogsPanel', () => {
     });
 
     it('rerenders when prop changes', async () => {
-      const { rerender, props } = setup({
-        data: {
-          series,
+      const { rerender, props } = setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
         },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -324,6 +573,25 @@ describe('LogsPanel', () => {
       expect(await screen.findByRole('row')).toBeInTheDocument();
       expect(jest.mocked(styles.getLogRowStyles).mock.calls.length).toBeGreaterThan(3);
     });
+
+    it('does not re-render when data is loading', async () => {
+      const { rerender, props } = setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+        },
+        showControls
+      );
+
+      expect(await screen.findByRole('row')).toBeInTheDocument();
+
+      rerender(<LogsPanel {...props} data={{ ...props.data, state: LoadingState.Loading }} />);
+
+      expect(await screen.findByRole('row')).toBeInTheDocument();
+      expect(styles.getLogRowStyles).toHaveBeenCalledTimes(3);
+    });
   });
 
   describe('Filters', () => {
@@ -332,19 +600,28 @@ describe('LogsPanel', () => {
         refId: 'A',
         fields: [
           {
-            name: 'time',
+            name: 'timestamp',
             type: FieldType.time,
             values: ['2019-04-26T09:28:11.352440161Z'],
           },
           {
-            name: 'message',
+            name: 'body',
             type: FieldType.string,
             values: ['logline text'],
-            labels: {
-              app: 'common_app',
-            },
+          },
+          {
+            name: 'labels',
+            type: FieldType.other,
+            values: [
+              {
+                app: 'common_app',
+              },
+            ],
           },
         ],
+        meta: {
+          type: DataFrameType.LogLines,
+        },
       }),
     ];
 
@@ -352,24 +629,29 @@ describe('LogsPanel', () => {
       const filterForMock = jest.fn();
       const filterOutMock = jest.fn();
       const isFilterLabelActiveMock = jest.fn();
-      setup({
-        data: {
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            onClickFilterLabel: filterForMock,
+            onClickFilterOutLabel: filterOutMock,
+            isFilterLabelActive: isFilterLabelActiveMock,
+          },
         },
-        options: {
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          onClickFilterLabel: filterForMock,
-          onClickFilterOutLabel: filterOutMock,
-          isFilterLabelActive: isFilterLabelActiveMock,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -389,11 +671,19 @@ describe('LogsPanel', () => {
           eventBus: new EventBusSrv(),
         });
 
-        setup({
-          data: {
-            series,
+        setup(
+          {
+            data: {
+              ...defaultProps.data,
+              series,
+            },
+            options: {
+              ...defaultProps.options,
+              enableLogDetails: true,
+            },
           },
-        });
+          showControls
+        );
 
         expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -409,11 +699,19 @@ describe('LogsPanel', () => {
           onAddAdHocFilter: jest.fn(),
         });
 
-        setup({
-          data: {
-            series,
+        setup(
+          {
+            data: {
+              ...defaultProps.data,
+              series,
+            },
+            options: {
+              ...defaultProps.options,
+              enableLogDetails: true,
+            },
           },
-        });
+          showControls
+        );
 
         expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -433,41 +731,55 @@ describe('LogsPanel', () => {
         refId: 'A',
         fields: [
           {
-            name: 'time',
+            name: 'timestamp',
             type: FieldType.time,
             values: ['2019-04-26T09:28:11.352440161Z'],
           },
           {
-            name: 'message',
+            name: 'body',
             type: FieldType.string,
             values: ['logline text'],
-            labels: {
-              app: 'common_app',
-            },
+          },
+          {
+            name: 'labels',
+            type: FieldType.other,
+            values: [
+              {
+                app: 'common_app',
+              },
+            ],
           },
         ],
+        meta: {
+          type: DataFrameType.LogLines,
+        },
       }),
     ];
 
     it('displays the provided fields instead of the log line', async () => {
-      setup({
-        data: {
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            displayedFields: ['app'],
+            onClickHideField: undefined,
+            onClickShowField: undefined,
+          },
         },
-        options: {
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          displayedFields: ['app'],
-          onClickHideField: undefined,
-          onClickShowField: undefined,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
       expect(screen.queryByText('logline text')).not.toBeInTheDocument();
@@ -482,23 +794,28 @@ describe('LogsPanel', () => {
     });
 
     it('updates the provided fields instead of the log line', async () => {
-      const { rerender, props } = setup({
-        data: {
-          series,
+      const { rerender, props } = setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            onClickHideField: undefined,
+            onClickShowField: undefined,
+          },
         },
-        options: {
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          onClickHideField: undefined,
-          onClickShowField: undefined,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
       expect(screen.getByText('logline text')).toBeInTheDocument();
@@ -509,24 +826,29 @@ describe('LogsPanel', () => {
     });
 
     it('enables the behavior with a default implementation', async () => {
-      setup({
-        data: {
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            displayedFields: [],
+            onClickHideField: undefined,
+            onClickShowField: undefined,
+          },
         },
-        options: {
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          displayedFields: [],
-          onClickHideField: undefined,
-          onClickShowField: undefined,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -543,23 +865,28 @@ describe('LogsPanel', () => {
     it('overrides the default implementation when the callbacks are provided', async () => {
       const onClickShowFieldMock = jest.fn();
 
-      setup({
-        data: {
-          series,
+      setup(
+        {
+          data: {
+            ...defaultProps.data,
+            series,
+          },
+          options: {
+            ...defaultProps.options,
+            showLabels: false,
+            showTime: false,
+            wrapLogMessage: false,
+            showCommonLabels: false,
+            prettifyLogMessage: false,
+            sortOrder: LogsSortOrder.Descending,
+            dedupStrategy: LogsDedupStrategy.none,
+            enableLogDetails: true,
+            onClickHideField: jest.fn(),
+            onClickShowField: onClickShowFieldMock,
+          },
         },
-        options: {
-          showLabels: false,
-          showTime: false,
-          wrapLogMessage: false,
-          showCommonLabels: false,
-          prettifyLogMessage: false,
-          sortOrder: LogsSortOrder.Descending,
-          dedupStrategy: LogsDedupStrategy.none,
-          enableLogDetails: true,
-          onClickHideField: jest.fn(),
-          onClickShowField: onClickShowFieldMock,
-        },
-      });
+        showControls
+      );
 
       expect(await screen.findByRole('row')).toBeInTheDocument();
 
@@ -571,56 +898,16 @@ describe('LogsPanel', () => {
   });
 });
 
-const setup = (propsOverrides?: {}) => {
+const setup = (propsOverrides?: Partial<LogsPanelProps>, showControls = false) => {
   const props: LogsPanelProps = {
+    ...defaultProps,
     data: {
-      error: undefined,
-      request: {
-        panelId: 4,
-        app: 'dashboard',
-        requestId: 'A',
-        timezone: 'browser',
-        interval: '30s',
-        intervalMs: 30000,
-        maxDataPoints: 823,
-        targets: [],
-        range: getDefaultTimeRange(),
-        scopedVars: {},
-        startTime: 1,
-      },
-      series: [],
-      state: LoadingState.Done,
-      timeRange: getDefaultTimeRange(),
+      ...(propsOverrides?.data || defaultProps.data),
     },
-    timeZone: 'utc',
-    timeRange: getDefaultTimeRange(),
     options: {
-      showLabels: false,
-      showTime: false,
-      wrapLogMessage: false,
-      showCommonLabels: false,
-      prettifyLogMessage: false,
-      sortOrder: LogsSortOrder.Descending,
-      dedupStrategy: LogsDedupStrategy.none,
-      enableLogDetails: true,
-      showLogContextToggle: false,
+      ...(propsOverrides?.options || defaultProps.options),
+      showControls,
     },
-    title: 'Logs panel',
-    id: 1,
-    transparent: false,
-    width: 400,
-    height: 100,
-    renderCounter: 0,
-    fieldConfig: {
-      defaults: {},
-      overrides: [],
-    },
-    eventBus: new EventBusSrv(),
-    onOptionsChange: jest.fn(),
-    onFieldConfigChange: jest.fn(),
-    replaceVariables: jest.fn(),
-    onChangeTimeRange: jest.fn(),
-    ...propsOverrides,
   };
 
   return { ...render(<LogsPanel {...props} />), props };
