@@ -7,32 +7,48 @@ import { Options } from './panelcfg.gen';
 import { LogsPanelSuggestionsSupplier } from './suggestions';
 
 export const plugin = new PanelPlugin<Options>(LogsPanel)
-  .setPanelOptions((builder) => {
+  .setPanelOptions((builder, context) => {
     const category = [t('logs.category-logs', 'Logs')];
-    builder.addBooleanSwitch({
-      path: 'showTime',
-      name: t('logs.name-time', 'Time'),
-      category,
-      description: '',
-      defaultValue: false,
-    });
+    builder
+      .addBooleanSwitch({
+        path: 'showTime',
+        name: t('logs.name-time', 'Show timestamps'),
+        category,
+        description: '',
+        defaultValue: false,
+      })
+      .addBooleanSwitch({
+        path: 'showLabels',
+        name: t('logs.name-unique-labels', 'Unique labels'),
+        category,
+        description: '',
+      });
 
     if (!config.featureToggles.newLogsPanel) {
-      builder
-        .addBooleanSwitch({
-          path: 'showLabels',
-          name: t('logs.name-unique-labels', 'Unique labels'),
-          category,
-          description: '',
-          defaultValue: false,
-        })
-        .addBooleanSwitch({
-          path: 'showCommonLabels',
-          name: t('logs.name-common-labels', 'Common labels'),
-          category,
-          description: '',
-          defaultValue: false,
-        });
+      builder.addBooleanSwitch({
+        path: 'showCommonLabels',
+        name: t('logs.name-common-labels', 'Common labels'),
+        category,
+        description: '',
+        defaultValue: false,
+      });
+    } else if (context.options?.showTime) {
+      builder.addRadio({
+        path: 'timestampResolution',
+        name: t('logs.timestamp-format', 'Timestamp resolution'),
+        category,
+        description: '',
+        defaultValue: 'ms',
+        settings: {
+          options: [
+            { value: 'ms', label: t('logs.logs.timestamp-resolution.label-milliseconds', 'Milliseconds') },
+            {
+              value: 'ns',
+              label: t('logs.logs.timestamp-resolution.label-nanoseconds', 'Nanoseconds'),
+            },
+          ],
+        },
+      });
     }
 
     builder.addBooleanSwitch({
@@ -43,17 +59,8 @@ export const plugin = new PanelPlugin<Options>(LogsPanel)
       defaultValue: false,
     });
 
-    if (config.featureToggles.newLogsPanel) {
-      builder.addBooleanSwitch({
-        path: 'syntaxHighlighting',
-        name: t('logs.name-enable-syntax-highlighting', 'Enable syntax highlighting'),
-        category,
-        description: t(
-          'logs.description-enable-syntax-highlighting',
-          'Use a predefined syntax coloring grammar to highlight relevant parts of the log lines'
-        ),
-      });
-    } else {
+    // In the old panel this is an independent option, in the new panel is linked to wrapLogMessage
+    if (!config.featureToggles.newLogsPanel || context.options?.wrapLogMessage) {
       builder.addBooleanSwitch({
         path: 'prettifyLogMessage',
         name: t('logs.name-prettify-json', 'Prettify JSON'),
@@ -63,24 +70,67 @@ export const plugin = new PanelPlugin<Options>(LogsPanel)
       });
     }
 
-    builder
-      .addBooleanSwitch({
-        path: 'enableLogDetails',
-        name: t('logs.name-enable-log-details', 'Enable log details'),
-        category,
-        description: '',
-        defaultValue: true,
-      })
-      .addBooleanSwitch({
-        path: 'enableInfiniteScrolling',
-        name: t('logs.name-enable-infinite-scrolling', 'Enable infinite scrolling'),
+    if (config.featureToggles.newLogsPanel) {
+      builder.addBooleanSwitch({
+        path: 'syntaxHighlighting',
+        name: t('logs.name-enable-logs-highlighting', 'Enable logs highlighting'),
         category,
         description: t(
-          'logs.description-enable-infinite-scrolling',
-          'Experimental. Request more results by scrolling to the bottom of the logs list.'
+          'logs.description-enable-logs-highlighting',
+          'Use a predefined coloring scheme to highlight relevant parts of the log lines'
         ),
-        defaultValue: false,
       });
+    }
+
+    builder.addBooleanSwitch({
+      path: 'enableLogDetails',
+      name: t('logs.name-enable-log-details', 'Enable log details'),
+      category,
+      description: '',
+      defaultValue: true,
+    });
+
+    if (config.featureToggles.newLogsPanel && context.options?.enableLogDetails) {
+      builder.addRadio({
+        path: 'detailsMode',
+        name: t('logs.name-details-mode', 'Log details panel mode'),
+        category,
+        description: '',
+        settings: {
+          options: [
+            { value: 'inline', label: t('logs.name-details-options.label-inline', 'Inline') },
+            {
+              value: 'sidebar',
+              label: t('logs.name-details-options.label-sidebar', 'Sidebar'),
+            },
+          ],
+        },
+      });
+    }
+
+    builder.addBooleanSwitch({
+      path: 'enableInfiniteScrolling',
+      name: t('logs.name-enable-infinite-scrolling', 'Enable infinite scrolling'),
+      category,
+      description: t(
+        'logs.description-enable-infinite-scrolling',
+        'Experimental. Request more results by scrolling to the bottom of the logs list.'
+      ),
+      defaultValue: false,
+    });
+
+    if (config.featureToggles.otelLogsFormatting) {
+      builder.addBooleanSwitch({
+        path: 'showLogAttributes',
+        name: t('logs.show-log-attributes', 'Display log attributes for OTel logs'),
+        category,
+        description: t(
+          'logs.description-show-log-attributes',
+          'Experimental. When OTel logs are displayed, add an extra displayed field with relevant key-value pairs from labels and metadata.'
+        ),
+        defaultValue: true,
+      });
+    }
 
     if (config.featureToggles.newLogsPanel) {
       builder
@@ -108,22 +158,6 @@ export const plugin = new PanelPlugin<Options>(LogsPanel)
               },
             ],
           },
-        })
-        .addRadio({
-          path: 'detailsMode',
-          name: t('logs.name-details-mode', 'Log Details panel mode'),
-          category,
-          description: '',
-          settings: {
-            options: [
-              { value: 'inline', label: t('logs.name-details-options.label-inline', 'Inline') },
-              {
-                value: 'sidebar',
-                label: t('logs.name-details-options.label-sidebar', 'Sidebar'),
-              },
-            ],
-          },
-          defaultValue: 'inline',
         });
     }
 
