@@ -1,6 +1,6 @@
 import { StandardEditorProps, SelectableValue } from '@grafana/data';
 import { t } from '@grafana/i18n';
-import { HorizontalGroup, RadioButtonGroup } from '@grafana/ui';
+import { Stack, RadioButtonGroup } from '@grafana/ui';
 
 import { InputPrefix, NullsThresholdInput } from './NullsThresholdInput';
 
@@ -21,7 +21,7 @@ export const InsertNullsEditor = ({ value, onChange, item }: Props) => {
   DISCONNECT_OPTIONS[1].value = isThreshold ? value : 3600000; // 1h
 
   return (
-    <HorizontalGroup>
+    <Stack>
       <RadioButtonGroup value={value} options={DISCONNECT_OPTIONS} onChange={onChange} />
       {isThreshold && (
         <NullsThresholdInput
@@ -31,6 +31,6 @@ export const InsertNullsEditor = ({ value, onChange, item }: Props) => {
           isTime={item.settings?.isTime ?? false}
         />
       )}
-    </HorizontalGroup>
+    </Stack>
   );
 };
