@@ -1,19 +1,41 @@
-import { PanelModel, FieldConfigSource } from '@grafana/data';
-import { graphPanelChangedHandler } from './migrations';
 import { cloneDeep } from 'lodash';
 
+import { PanelModel, FieldConfigSource, FieldMatcherID, ReducerID } from '@grafana/data';
+import { TooltipDisplayMode, SortOrder } from '@grafana/schema';
+import { getDashboardSrv } from 'app/features/dashboard/services/DashboardSrv';
+import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
+import { PanelModel as PanelModelState } from 'app/features/dashboard/state/PanelModel';
+import { createDashboardModelFixture } from 'app/features/dashboard/state/__fixtures__/dashboardFixtures';
+import { dataLayersToAnnotations } from 'app/features/dashboard-scene/serialization/dataLayersToAnnotations';
+import { transformSaveModelToScene } from 'app/features/dashboard-scene/serialization/transformSaveModelToScene';
+import { dashboardSceneGraph } from 'app/features/dashboard-scene/utils/dashboardSceneGraph';
+import { GrafanaQueryType } from 'app/plugins/datasource/grafana/types';
+
+import { graphPanelChangedHandler } from './migrations';
+
 describe('Graph Migrations', () => {
   let prevFieldConfig: FieldConfigSource;
+  let dashboard: DashboardModel;
 
   beforeEach(() => {
     prevFieldConfig = {
       defaults: {},
       overrides: [],
     };
+
+    dashboard = createDashboardModelFixture({
+      id: 74,
+      version: 7,
+      annotations: {},
+      links: [],
+      panels: [],
+    });
+
+    getDashboardSrv().setCurrent(dashboard);
   });
 
   it('simple bars', () => {
-    const old: any = {
+    const old = {
       angular: {
         bars: true,
       },
@@ -24,7 +46,7 @@ describe('Graph Migrations', () => {
   });
 
   it('stairscase', () => {
-    const old: any = {
+    const old = {
       angular: stairscase,
     };
     const panel = {} as PanelModel;
@@ -42,7 +64,7 @@ describe('Graph Migrations', () => {
   });
 
   it('twoYAxis', () => {
-    const old: any = {
+    const old = {
       angular: twoYAxis,
     };
     const panel = {} as PanelModel;
@@ -51,7 +73,7 @@ describe('Graph Migrations', () => {
   });
 
   it('stepped line', () => {
-    const old: any = {
+    const old = {
       angular: stepedColordLine,
     };
     const panel = {} as PanelModel;
@@ -60,7 +82,7 @@ describe('Graph Migrations', () => {
   });
 
   it('preserves colors from series overrides', () => {
-    const old: any = {
+    const old = {
       angular: customColor,
     };
     const panel = {} as PanelModel;
@@ -69,17 +91,85 @@ describe('Graph Migrations', () => {
   });
 
   it('preserves series overrides using a regex alias', () => {
-    const old: any = {
+    const old = {
       angular: customColorRegex,
     };
     const panel = {} as PanelModel;
     panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
     expect(panel).toMatchSnapshot();
+    expect(panel.fieldConfig.overrides[0].matcher.id).toBe(FieldMatcherID.byRegexp);
+    expect(panel.fieldConfig.overrides[1].matcher.id).toBe(FieldMatcherID.byRegexp);
+  });
+
+  describe('time regions', () => {
+    test('should migrate', () => {
+      const old = {
+        angular: {
+          timeRegions: [
+            {
+              colorMode: 'red',
+              fill: true,
+              fillColor: 'rgba(234, 112, 112, 0.12)',
+              fromDayOfWeek: 1,
+              line: true,
+              lineColor: 'rgba(237, 46, 24, 0.60)',
+              op: 'time',
+            },
+          ],
+        },
+      };
+
+      const panel = { datasource: { type: 'datasource', uid: 'gdev-testdata' } } as PanelModel;
+      dashboard.panels.push(new PanelModelState(panel));
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(dashboard.panels).toHaveLength(1);
+      expect(dashboard.annotations.list).toHaveLength(2); // built-in + time region
+      expect(
+        dashboard.annotations.list.filter((annotation) => annotation.target?.queryType === GrafanaQueryType.TimeRegions)
+      ).toHaveLength(1);
+      expect(panel).toMatchSnapshot();
+    });
+
+    test('should migrate in scenes dashboard', () => {
+      const old = {
+        angular: {
+          timeRegions: [
+            {
+              colorMode: 'red',
+              fill: true,
+              fillColor: 'rgba(234, 112, 112, 0.12)',
+              fromDayOfWeek: 1,
+              line: true,
+              lineColor: 'rgba(237, 46, 24, 0.60)',
+              op: 'time',
+            },
+          ],
+        },
+      };
+
+      const panel = { datasource: { type: 'datasource', uid: 'gdev-testdata' } } as PanelModel;
+
+      dashboard.panels.push(new PanelModelState(panel));
+
+      const scene = transformSaveModelToScene({ dashboard, meta: {} });
+      window.__grafanaSceneContext = scene;
+
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+
+      const layers = dashboardSceneGraph.getDataLayers(scene).state.annotationLayers;
+      const annotations = dataLayersToAnnotations(layers);
+
+      expect(annotations).toHaveLength(2); // built-in + time region
+      expect(
+        annotations.filter((annotation) => annotation.target?.queryType === GrafanaQueryType.TimeRegions)
+      ).toHaveLength(1);
+      expect(panel).toMatchSnapshot();
+    });
   });
 
   describe('legend', () => {
     test('without values', () => {
-      const old: any = {
+      const old = {
         angular: {
           legend: {
             show: true,
@@ -97,7 +187,7 @@ describe('Graph Migrations', () => {
       expect(panel).toMatchSnapshot();
     });
     test('with single value', () => {
-      const old: any = {
+      const old = {
         angular: {
           legend: {
             show: true,
@@ -115,18 +205,145 @@ describe('Graph Migrations', () => {
       expect(panel).toMatchSnapshot();
     });
     test('with multiple values', () => {
-      const old: any = {
+      const old = {
         angular: legend,
       };
       const panel = {} as PanelModel;
       panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
       expect(panel).toMatchSnapshot();
     });
+    test('with sideWidth', () => {
+      const old = {
+        angular: {
+          legend: {
+            alignAsTable: true,
+            rightSide: true,
+            show: true,
+            sideWidth: 200,
+            total: true,
+            values: true,
+          },
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.options.legend.width).toBe(200);
+    });
+
+    test('hide allZeros', () => {
+      const old = {
+        angular: {
+          legend: {
+            show: true,
+            values: false,
+            min: false,
+            max: false,
+            current: false,
+            total: false,
+            avg: false,
+            hideZero: true,
+          },
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.fieldConfig.overrides).toHaveLength(1);
+      expect(panel.fieldConfig.overrides[0].matcher.options.reducer).toBe(ReducerID.allIsZero);
+      expect(panel.fieldConfig.overrides).toMatchInlineSnapshot(`
+        [
+          {
+            "matcher": {
+              "id": "byValue",
+              "options": {
+                "op": "gte",
+                "reducer": "allIsZero",
+                "value": 0,
+              },
+            },
+            "properties": [
+              {
+                "id": "custom.hideFrom",
+                "value": {
+                  "legend": true,
+                  "tooltip": true,
+                  "viz": false,
+                },
+              },
+            ],
+          },
+        ]
+      `);
+    });
+
+    test('hide allZeros allNulls', () => {
+      const old = {
+        angular: {
+          legend: {
+            show: true,
+            values: false,
+            min: false,
+            max: false,
+            current: false,
+            total: false,
+            avg: false,
+            hideEmpty: true,
+            hideZero: true,
+          },
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.fieldConfig.overrides).toHaveLength(2);
+      expect(panel.fieldConfig.overrides).toMatchInlineSnapshot(`
+        [
+          {
+            "matcher": {
+              "id": "byValue",
+              "options": {
+                "op": "gte",
+                "reducer": "allIsZero",
+                "value": 0,
+              },
+            },
+            "properties": [
+              {
+                "id": "custom.hideFrom",
+                "value": {
+                  "legend": true,
+                  "tooltip": true,
+                  "viz": false,
+                },
+              },
+            ],
+          },
+          {
+            "matcher": {
+              "id": "byValue",
+              "options": {
+                "op": "gte",
+                "reducer": "allIsNull",
+                "value": 0,
+              },
+            },
+            "properties": [
+              {
+                "id": "custom.hideFrom",
+                "value": {
+                  "legend": true,
+                  "tooltip": true,
+                  "viz": false,
+                },
+              },
+            ],
+          },
+        ]
+      `);
+    });
   });
 
   describe('stacking', () => {
     test('simple', () => {
-      const old: any = {
+      const old = {
         angular: stacking,
       };
       const panel = {} as PanelModel;
@@ -134,7 +351,7 @@ describe('Graph Migrations', () => {
       expect(panel).toMatchSnapshot();
     });
     test('groups', () => {
-      const old: any = {
+      const old = {
         angular: stackingGroups,
       };
       const panel = {} as PanelModel;
@@ -145,7 +362,7 @@ describe('Graph Migrations', () => {
 
   describe('thresholds', () => {
     test('Only gt thresholds', () => {
-      const old: any = {
+      const old = {
         angular: {
           thresholds: [
             {
@@ -171,16 +388,16 @@ describe('Graph Migrations', () => {
       panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
       expect(panel.fieldConfig.defaults.custom.thresholdsStyle.mode).toBe('area');
       expect(panel.fieldConfig.defaults.thresholds?.steps).toMatchInlineSnapshot(`
-        Array [
-          Object {
+        [
+          {
             "color": "transparent",
             "value": -Infinity,
           },
-          Object {
+          {
             "color": "orange",
             "value": 50,
           },
-          Object {
+          {
             "color": "red",
             "value": 80,
           },
@@ -189,7 +406,7 @@ describe('Graph Migrations', () => {
     });
 
     test('gt & lt thresholds', () => {
-      const old: any = {
+      const old = {
         angular: {
           thresholds: [
             {
@@ -216,16 +433,16 @@ describe('Graph Migrations', () => {
       panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
       expect(panel.fieldConfig.defaults.custom.thresholdsStyle.mode).toBe('line+area');
       expect(panel.fieldConfig.defaults.thresholds?.steps).toMatchInlineSnapshot(`
-        Array [
-          Object {
+        [
+          {
             "color": "orange",
             "value": -Infinity,
           },
-          Object {
+          {
             "color": "transparent",
             "value": 40,
           },
-          Object {
+          {
             "color": "red",
             "value": 80,
           },
@@ -234,7 +451,7 @@ describe('Graph Migrations', () => {
     });
 
     test('Only lt thresholds', () => {
-      const old: any = {
+      const old = {
         angular: {
           thresholds: [
             {
@@ -253,12 +470,12 @@ describe('Graph Migrations', () => {
       panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
       expect(panel.fieldConfig.defaults.custom.thresholdsStyle.mode).toBe('line+area');
       expect(panel.fieldConfig.defaults.thresholds?.steps).toMatchInlineSnapshot(`
-        Array [
-          Object {
+        [
+          {
             "color": "orange",
             "value": -Infinity,
           },
-          Object {
+          {
             "color": "transparent",
             "value": 40,
           },
@@ -308,6 +525,189 @@ describe('Graph Migrations', () => {
       expect(panel.fieldConfig.overrides[0].properties[0].value).toEqual({ viz: true, legend: false, tooltip: false });
     });
   });
+
+  describe('tooltip', () => {
+    test('tooltip mode', () => {
+      const single = {
+        angular: {
+          tooltip: {
+            shared: false,
+          },
+        },
+      };
+      const multi = {
+        angular: {
+          tooltip: {
+            shared: true,
+          },
+        },
+      };
+
+      const panel1 = {} as PanelModel;
+      const panel2 = {} as PanelModel;
+
+      panel1.options = graphPanelChangedHandler(panel1, 'graph', single, prevFieldConfig);
+      panel2.options = graphPanelChangedHandler(panel2, 'graph', multi, prevFieldConfig);
+
+      expect(panel1.options.tooltip.mode).toBe(TooltipDisplayMode.Single);
+      expect(panel2.options.tooltip.mode).toBe(TooltipDisplayMode.Multi);
+    });
+
+    test('sort order', () => {
+      const none = {
+        angular: {
+          tooltip: {
+            shared: true,
+            sort: 0,
+          },
+        },
+      };
+
+      const asc = {
+        angular: {
+          tooltip: {
+            shared: true,
+            sort: 1,
+          },
+        },
+      };
+
+      const desc = {
+        angular: {
+          tooltip: {
+            shared: true,
+            sort: 2,
+          },
+        },
+      };
+
+      const singleModeWithUnnecessaryOption = {
+        angular: {
+          tooltip: {
+            shared: false,
+            sort: 2,
+          },
+        },
+      };
+
+      const panel1 = {} as PanelModel;
+      const panel2 = {} as PanelModel;
+      const panel3 = {} as PanelModel;
+      const panel4 = {} as PanelModel;
+
+      panel1.options = graphPanelChangedHandler(panel1, 'graph', none, prevFieldConfig);
+      panel2.options = graphPanelChangedHandler(panel2, 'graph', asc, prevFieldConfig);
+      panel3.options = graphPanelChangedHandler(panel3, 'graph', desc, prevFieldConfig);
+      panel4.options = graphPanelChangedHandler(panel4, 'graph', singleModeWithUnnecessaryOption, prevFieldConfig);
+
+      expect(panel1.options.tooltip.sort).toBe(SortOrder.None);
+      expect(panel2.options.tooltip.sort).toBe(SortOrder.Ascending);
+      expect(panel3.options.tooltip.sort).toBe(SortOrder.Descending);
+      expect(panel4.options.tooltip.sort).toBe(SortOrder.None);
+    });
+  });
+
+  describe('x axis', () => {
+    test('should hide x axis', () => {
+      const old = {
+        angular: {
+          xaxis: {
+            show: false,
+            mode: 'time',
+          },
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.fieldConfig).toMatchSnapshot();
+    });
+  });
+
+  describe('transforms', () => {
+    test.each(['negative-Y', 'constant'])('should preserve %p transform', (transform) => {
+      const old = {
+        angular: {
+          seriesOverrides: [
+            {
+              alias: 'out',
+              transform,
+            },
+          ],
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.fieldConfig).toMatchSnapshot();
+    });
+  });
+
+  describe('null values', () => {
+    test('nullPointMode = null', () => {
+      const old = {
+        angular: {
+          nullPointMode: 'null',
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.fieldConfig.defaults.custom.spanNulls).toBeFalsy();
+    });
+    test('nullPointMode = connected', () => {
+      const old = {
+        angular: {
+          nullPointMode: 'connected',
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.fieldConfig.defaults.custom.spanNulls).toBeTruthy();
+    });
+  });
+
+  describe('seriesOverride lines: true', () => {
+    test('Should set displayMode', () => {
+      const old = {
+        angular: {
+          bars: true,
+          lines: false,
+          seriesOverrides: [
+            {
+              alias: 'A-series',
+              lines: true,
+            },
+          ],
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.fieldConfig.overrides[0]).toEqual({
+        matcher: { id: 'byName', options: 'A-series' },
+        properties: [{ id: 'custom.drawStyle', value: 'line' }],
+      });
+    });
+  });
+
+  describe('seriesOverride lines: false', () => {
+    test('Should set lineWidth 0', () => {
+      const old = {
+        angular: {
+          lines: true,
+          seriesOverrides: [
+            {
+              alias: 'A-series',
+              lines: false,
+            },
+          ],
+        },
+      };
+      const panel = {} as PanelModel;
+      panel.options = graphPanelChangedHandler(panel, 'graph', old, prevFieldConfig);
+      expect(panel.fieldConfig.overrides[0]).toEqual({
+        matcher: { id: 'byName', options: 'A-series' },
+        properties: [{ id: 'custom.lineWidth', value: 0 }],
+      });
+    });
+  });
 });
 
 const customColor = {
@@ -338,6 +738,11 @@ const customColor = {
       alias: 'A-series',
       color: 'rgba(165, 72, 170, 0.77)',
     },
+    {
+      $$hashKey: 'object:13',
+      alias: 'B-series',
+      color: 'rgba(16, 72, 170, 0.77)',
+    },
   ],
   spaceLength: 10,
   steppedLine: true,
@@ -395,6 +800,7 @@ const customColor = {
 
 const customColorRegex = cloneDeep(customColor);
 customColorRegex.seriesOverrides[0].alias = '/^A-/';
+customColorRegex.seriesOverrides[1].alias = '/.*Status: 2[0-9]+.*/i';
 
 const stairscase = {
   aliasColors: {},
